@@ -14,29 +14,34 @@
  * You should have received a copy of the GNU General Public License along
  * with this program; if not, write to the Free Software Foundation, Inc.,
  * 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
- * 
- * Contact information: Silicon Graphics, Inc., 1500 Crittenden Lane,
- * Mountain View, CA 94043, USA, or: http://www.sgi.com
- *
- * $Id: impl.h,v 1.9 2007/01/16 06:36:59 kimbrr Exp $
  */
 
 #ifndef _IMPL_H
 #define _IMPL_H
 
-#include <unistd.h>
+#include <time.h>
+#include <fcntl.h>
 #include <dirent.h>
+#include <signal.h>
+#include <unistd.h>
 #include <sys/types.h>
 #include <sys/param.h>
 #include <sys/time.h>
+#ifdef HAVE_SYS_SOCKET_H
 #include <sys/socket.h>
-#include <netinet/in.h>
-#include <arpa/inet.h>
-#include <netdb.h>
-#if (defined __sgi) && (defined mips) &&  (defined HAVE_NDBM_H)
-#include <ndbm.h>
 #endif
-#include <time.h>
+#ifdef HAVE_NETINET_TCP_H
+#include <netinet/tcp.h>
+#endif
+#ifdef HAVE_NETINET_IN_H
+#include <netinet/in.h>
+#endif
+#ifdef HAVE_ARPA_INET_H
+#include <arpa/inet.h> 
+#endif
+#ifdef HAVE_NETDB_H
+#include <netdb.h>
+#endif
 
 #ifdef __cplusplus
 extern "C" {
@@ -65,7 +70,6 @@ extern int __pmGetInternalState(void);
  * environment
  */
 #define SERVER_PORT 44321
-#define OLD_SERVER_PORT 4321
 
 /*
  * port that clients connect to pmproxy(1) on by default, over-ride with
@@ -218,8 +222,7 @@ extern void __pmNotifyErr(int, const char *, ...);
  * These ones are only for debugging and may not appear in the shipped
  * libpmapi ...
  */
-extern int	pmDebug;
-/* debug control bit fields */
+EXTERN int	pmDebug;
 #define  DBG_TRACE_PDU		1	/* PDU send and receive */
 #define  DBG_TRACE_FETCH	2	/* dump pmFetch results */
 #define  DBG_TRACE_PROFILE	4	/* trace profile changes */
@@ -417,12 +420,10 @@ extern void __pmFreeInResult(__pmInResult *);
  * Version and authorisation info for PDU exchanges
  */
 
+#define UNKNOWN_VERSION	0
 #define PDU_VERSION1	1
 #define PDU_VERSION2	2
-
-#define UNKNOWN_VERSION		0
-#define ILLEGAL_CONNECT		(128-1)
-#define PDU_VERSION		PDU_VERSION2
+#define PDU_VERSION	PDU_VERSION2
 
 #define PDU_OVERRIDE1	-1001
 #define PDU_OVERRIDE2	-1002
@@ -485,6 +486,7 @@ extern int __pmConnectLocal(void);
 extern int __pmAuxConnectPMCD(const char *);
 extern int __pmAuxConnectPMCDPort(const char *, int);
 extern int __pmCreateSocket(void);
+extern void __pmCloseSocket(int);
 extern int __pmAddHostPorts(pmHostSpec *, int *, int);
 extern void __pmDropHostPort(pmHostSpec *);
 extern void __pmConnectGetPorts(pmHostSpec *);
@@ -584,6 +586,9 @@ extern int __pmXmitAscii(int, const char *, int);
 extern int __pmGetPDU(int, int, int, __pmPDU **);
 extern int __pmGetPDUCeiling (void);
 extern int __pmSetPDUCeiling (int);
+
+EXTERN unsigned int *__pmPDUCntIn;
+EXTERN unsigned int *__pmPDUCntOut;
 extern void __pmSetPDUCntBuf(unsigned *, unsigned *);
 
 /* for __pmGetPDU */
@@ -697,20 +702,6 @@ typedef pmValueSet	__pmValueSet_PDU;
 bozo - unknown size of long !!!
 #endif
 
-#if (defined __sgi) && (defined mips) &&  (defined HAVE_NDBM_H)
-/*
- * If you use help files created via "newhelp -v1" and ndbm(3B), then
- * this is the key you should use, i.e. dptr -> __pmHelpKey and
- * dsize = sizeof(__pmHelpKey)
- */
-typedef struct {
-    int		ident;		/* PMID or InDom */
-    int		type;
-} __pmHelpKey;
-
-extern char *__pmGetText(DBM *, int, int);
-#endif
-
 /*
  * For the help text PDUs, the type (PM_TEXT_ONELINE or PM_TEXT_HELP)
  * is 'or'd with the following to encode the request for a PMID or
@@ -735,33 +726,11 @@ extern void __pmNoMem(const char *, size_t, int);
 #define PM_FATAL_ERR 1
 #define PM_RECOV_ERR 0
 
-/*
- * nodelock license check
- */
-/*
- * if license checking is enabled, the following two functions need
- * to be implemented in a static library, else they are stubs.
- */
-#ifdef HAVE_LICENSE_CHECK
-extern int __pmGetLicense(int, const char *, int);
-extern int __pmGetLicenseCap(void);
-#else
-#define __pmGetLicense(a, b, c) (a)
-#define __pmGetLicenseCap() (~0)
-#endif
-
-#define PM_LIC_COL      1
-#define PM_LIC_MON      2
-#define PM_LIC_PCP      4
-#define PM_LIC_WEB      8
-#ifdef PCP_DEBUG
-#define PM_LIC_DEV      16384   /* for development and testing */
-#endif
-
 /*
  * program name, as used in __pmNotifyErr() ... default is "pcp"
  */
-extern char	*pmProgname;
+EXTERN char *pmProgname;
+extern int __pmSetProgname(const char *);
 
 /* map Unix errno values to PMAPI errors */
 extern int __pmMapErrno(int);
@@ -933,14 +902,11 @@ extern void __pmEventTrace(const char *);
 typedef int (*__pmConnectHostType)(int, int);
 extern __pmConnectHostType __pmConnectHostMethod;
 
-typedef struct {
-    unsigned int        version;
-    void                *ext;
-} __pmIPC;
-
-extern int __pmAddIPC(int, __pmIPC);
-extern int __pmLookupIPC(__pmIPC **);
-extern int __pmFdLookupIPC(int, __pmIPC **);
+extern int __pmSetSocketIPC(int);
+extern int __pmSetVersionIPC(int, int);
+extern int __pmLastVersionIPC();
+extern int __pmVersionIPC(int);
+extern int __pmSocketIPC(int);
 extern void __pmOverrideLastFd(int);
 extern void __pmPrintIPC(void);
 extern void __pmResetIPC(int);
@@ -1088,7 +1054,6 @@ extern void __htonll(char *);		/* 64bit int */
 
 #endif /* HAVE_NETWORK_BYTEORDER */
 
-#ifdef HAVE_DEV_IN_LIBPCP
 /*
  * access control routines
  */
@@ -1104,6 +1069,15 @@ extern void __pmAccFreeSavedHosts(void);
 
 extern unsigned int __pmMakeAuthCookie(unsigned int, pid_t);
 
+/*
+ * platform independent process routines
+ */
+extern int __pmProcessExists(pid_t);
+extern int __pmProcessTerminate(pid_t, int);
+extern int __pmProcessCreate(char **, int *, int *);
+extern int __pmProcessDataSize(unsigned long *);
+extern int __pmProcessRunTimes(double *, double *);
+
 /*
  * AF - general purpose asynchronous event management routines
  */
@@ -1198,25 +1172,6 @@ extern int __pmControlLog(int, const pmResult *, int, int, int, pmResult **);
 #define PMLC_GET_DELTA(val) \
         (((val & ~0xf) >> 4) & PMLC_MAX_DELTA)
 
-/*
- * deprecated pmlc <-> pmlogger protocol interfaces
- */
-#define PMLC_PDU_STATUS_REQ	1
-#define PMLC_PDU_STATUS		2
-#define PMLC_PDU_NEWVOLUME	3
-#define PMLC_PDU_SYNC		4
-
-extern int __pmSendDataX(int, int, int, int, const void *);
-extern int __pmDecodeDataX(__pmPDU *, int, int *, int *, void **);
-extern int __pmSendControlReq(int, int, const pmResult *, int, int, int);
-extern int __pmDecodeControlReq(const __pmPDU *, int, pmResult **, int *, int *, int *);
-
-#endif /* HAVE_DEV_IN_LIBPCP */
-
-#ifdef HAVE_SEPARATE_MONS_H
-#include "impl_mon.h"
-#endif
-
 #ifdef __cplusplus
 }
 #endif
