@@ -14,13 +14,8 @@
  * You should have received a copy of the GNU General Public License along
  * with this program; if not, write to the Free Software Foundation, Inc.,
  * 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
- * 
- * Contact information: Silicon Graphics, Inc., 1500 Crittenden Lane,
- * Mountain View, CA 94043, USA, or: http://www.sgi.com
  */
 
-/* $Id: pmapi.h,v 1.8 2006/06/03 09:09:26 makc Exp $ */
-
 #ifndef _PMAPI_H
 #define _PMAPI_H
 
@@ -315,7 +310,6 @@ extern int pmGetInDomArchive(pmInDom, int **, char ***);
 /*
  * Given context ID, return a host name, associated with the id
  * or empty string if no name can be found
- * Note: in IRIX6.5, this is an optional symbol
  */
 extern const char *pmGetContextHostName(int);
 
@@ -574,7 +568,7 @@ extern struct tm *pmLocaltime(const time_t *, struct tm *);
 
 /* Parse host:metric[instances] or archive/metric[instances] */
 typedef struct {
-    int         isarch;         /* source type: 0 -> live host, 1 -> archive */
+    int         isarch;         /* source type: 0 -> live host, 1 -> archive, 2 -> local context */
     char        *source;        /* name of source host or archive */
     char        *metric;        /* name of metric */
     int         ninst;          /* number of instances, 0 -> all */
@@ -596,7 +590,6 @@ extern int pmflush(void);
  * Wrapper for config/environment variables. Warning: this will exit() with
  * a FATAL error if /etc/pcp.conf does not exist and $PCP_CONF is not set.
  * Return values point to strings in the environment.
- * Note: in IRIX6.5, this is an optional symbol
  */
 extern char *pmGetConfig(const char *);
 
@@ -651,64 +644,6 @@ extern int pmRequestStore (int, const pmResult *);
 extern int pmRequestText (int, pmID, int);
 extern int pmRequestTraversePMNS (int, const char *);
 
-#ifdef __sgi
-#ifndef _SGI_COMPILING_LIBPCP
-#pragma optional pmLoopRegisterInput
-#pragma optional pmLoopRegisterSignal
-#pragma optional pmLoopRegisterTimeout
-#pragma optional pmLoopRegisterChild
-#pragma optional pmLoopRegisterIdle
-#pragma optional pmLoopUnregisterInput
-#pragma optional pmLoopUnregisterSignal
-#pragma optional pmLoopUnregisterTimeout
-#pragma optional pmLoopUnregisterChild
-#pragma optional pmLoopUnregisterIdle
-#pragma optional pmLoopStop
-#pragma optional pmLoopMain
-
-#pragma optional pmGetContextFD
-#pragma optional pmGetContextTimeout
-#pragma optional pmContextConnectTo
-#pragma optional pmContextConnectChangeState
-#pragma optional pmContextUndef
-
-#pragma optional pmReceiveDesc
-#pragma optional pmReceiveFetch
-#pragma optional pmReceiveInDom
-#pragma optional pmReceiveInDomInst
-#pragma optional pmReceiveInDomName
-#pragma optional pmReceiveNameID
-#pragma optional pmReceiveNames
-#pragma optional pmReceiveNamesAll
-#pragma optional pmReceiveNamesOfChildren
-#pragma optional pmReceiveStore
-#pragma optional pmReceiveTraversePMNS
-#pragma optional pmReceiveText
-#pragma optional pmRequestDesc
-#pragma optional pmRequestFetch
-#pragma optional pmRequestInDom
-#pragma optional pmRequestInDomInst
-#pragma optional pmRequestInDomName
-#pragma optional pmRequestInDomText
-#pragma optional pmRequestNameID
-#pragma optional pmRequestNames
-#pragma optional pmRequestNamesOfChildern
-#pragma optional pmRequestStore
-#pragma optional pmRequestText
-#pragma optional pmRequestTraversePMNS
-
-#endif
-#endif
-
-
-#ifdef HAVE_SEPARATE_MONS_H
-#include "pmapi_mon.h"
-#endif
-
-#ifdef MALLOC_AUDIT
-#include "malloc-audit.h"
-#endif
-
 #ifdef __cplusplus
 }
 #endif
