@@ -14,78 +14,27 @@
  * You should have received a copy of the GNU Lesser General Public License
  * along with this library; if not, write to the Free Software Foundation,
  * Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA.
- * 
- * Contact information: Silicon Graphics, Inc., 1500 Crittenden Lane,
- * Mountain View, CA 94043, USA, or: http://www.sgi.com
  */
 
-#ident "$Id: connect.c,v 1.10 2006/05/02 05:57:28 makc Exp $"
-
 #include "pmapi.h"
 #include "impl.h"
 #include "pmda.h"
-#include <syslog.h>
+#include "dsotbl.h"
 
 #if defined(HAVE_DLFCN_H)
 #include <dlfcn.h>
 #endif
 
-#include "dsotbl.h"
-
-/*
- * for libpcp and unauthorized clients, __pmConnectHostMethod() leads
- * here and PMCD connection failure ...
- */
-/*ARGSUSED*/
-static int
-pcp_trustme(int fd, int what)
-{
-#ifndef HAVE_FLEXLM
-#ifdef HAVE_DLOPEN
-    char libpath[MAXPATHLEN];
-    void * dso;
-
-    snprintf (libpath, sizeof(libpath), "%s/libpcp_mon.so", pmGetConfig("PCP_LIB_DIR"));
-	
-    if ( (dso = dlopen (libpath, RTLD_LAZY)) != NULL ) {
-	void * sym;
-
-	if ( (sym = dlsym (dso, "__pmSetAuthClient")) != NULL ) {
-	    void (*f) (void) = (void (*) (void))sym;
-	    (*f)();
-	    /* No recursion here - __pmSetAuthClient MUST change the
-	     * pointer ... */
-	    return (__pmConnectHostMethod (fd, what));
-	} else {
-	    dlclose (dso);
-	}
-    }	    
-#endif
-#endif
-    return PM_ERR_PMCDLICENSE;
-}
-
-/*
- * Function pointer manipulation here is used to make the authorised
- * pmcd connect functionality accessible via a single call to
- * __pmConnectPMCD and in such a way that all subsequent calls will do
- * the right thing (always) when deciding which to call.
- */
-__pmConnectHostType __pmConnectHostMethod = pcp_trustme;
-
 /* MY_BUFLEN needs to big enough to hold "hostname port" */
 #define MY_BUFLEN (MAXHOSTNAMELEN+10)
 #define MY_VERSION "pmproxy-client 1\n"
 
-static int	proxy_version;
-
 static int
 negotiate_proxy(int fd, const char *hostname, int port)
 {
     char	buf[MY_BUFLEN];
     char	*bp;
     int		ok = 0;
-    extern int	errno;
 
     /*
      * version negotiation (converse to pmproxy logic)
@@ -94,7 +43,7 @@ negotiate_proxy(int fd, const char *hostname, int port)
      *   send hostname and port
      */
 
-    if (write(fd, MY_VERSION, strlen(MY_VERSION)) != strlen(MY_VERSION)) {
+    if (send(fd, MY_VERSION, strlen(MY_VERSION), 0) != strlen(MY_VERSION)) {
 	__pmNotifyErr(LOG_WARNING,
 	     "__pmConnectPMCD: send version string to pmproxy failed: %s\n",
 	     pmErrStr(-errno));
@@ -112,10 +61,8 @@ negotiate_proxy(int fd, const char *hostname, int port)
 	}
     }
     if (bp < &buf[MY_BUFLEN]) {
-	if (strcmp(buf, "pmproxy-server 1") == 0) {
-	    proxy_version = 1;
+	if (strcmp(buf, "pmproxy-server 1") == 0)
 	    ok = 1;
-	}
     }
 
     if (!ok) {
@@ -126,47 +73,25 @@ negotiate_proxy(int fd, const char *hostname, int port)
     }
 
     snprintf(buf, sizeof(buf), "%s %d\n", hostname, port);
-    if (write(fd, buf, strlen(buf)) != strlen(buf)) {
+    if (send(fd, buf, strlen(buf), 0) != strlen(buf)) {
 	__pmNotifyErr(LOG_WARNING,
 	     "__pmConnectPMCD: send hostname+port string to pmproxy failed: %s'\n",
 	     pmErrStr(-errno));
 	return PM_ERR_IPC;
     }
 
-    return 0;
+    return ok;
 }
 
-#ifndef HAVE_UNSETENV
-/*
- * don't have unsetenv() for IRIX, so do it the long-handed portable way
- */
-static int
-unsetenv(const char *name)
-{
-    extern char **_environ;
-    char	**ep;
-    int		len = (int)strlen(name);
-    int		found = 0;
-
-    for (ep = _environ; *ep != NULL; ep++) {
-	if (strncmp(*ep, name, len) == 0 && (*ep)[len] == '=') {
-	    found = 1;
-	}
-	if (found)
-	    ep[0] = ep[1];
-    }
-    return found;
-}
-#endif
-
 /*
  * client connects to pmcd handshake
  */
-static int
-do_handshake(int fd, __pmIPC *infop)
+int
+__pmConnectHandshake(int fd)
 {
     __pmPDU	*pb;
     int		ok;
+    int		version;
     int		challenge;
     int		sts;
 
@@ -174,7 +99,7 @@ do_handshake(int fd, __pmIPC *infop)
     sts = __pmGetPDU(fd, PDU_BINARY, TIMEOUT_DEFAULT, &pb);
     if (sts == PDU_ERROR) {
 	/*
-	 * see comments in pmcd ... we actually get an extended PDU
+	 * See comments in pmcd ... we actually get an extended PDU
 	 * from a 2.0 pmcd, of the form
 	 *
 	 *  :----------:-----------:
@@ -185,34 +110,32 @@ do_handshake(int fd, __pmIPC *infop)
 	 *     pmcd  licensed             0          bits
 	 *	     unlicensed       -1007          bits
 	 *
-	 *  -1007 is magic and is PM_ERR_LICENSE for PCP 1.x
-	 *
-	 * a 1.x pmcd will send us just the regular error PDU with
+	 * -1007 is magic and is PM_ERR_LICENSE for PCP 1.x.
+	 * A 1.x pmcd will send us just the regular error PDU with
 	 * a "status" value.
+	 *
+	 * NB: Licensing is a historical remnant from the earlier
+	 * days of PCP on IRIX.  Modern day, open source PCP has no
+	 * run-time licensing restrictions using this mechanism.
 	 */
 	ok = __pmDecodeXtendError(pb, PDU_BINARY, &sts, &challenge);
-	if (ok < 0) {
+	if (ok < 0)
 	    return ok;
-	}
 
 	/*
 	 * At this point, ok is PDU_VERSION1 or PDU_VERSION2 and
 	 * sts is a PCP 2.0 error code
 	 */
-	infop->version = ok;
-	infop->ext = NULL;
-	if ((ok = __pmAddIPC(fd, *infop)) < 0) {
+	version = ok;
+	if ((ok = __pmSetVersionIPC(fd, version)) < 0)
 	    return ok;
-	}
 
-	if (infop->version == PDU_VERSION1) {
+	if (version == PDU_VERSION1) {
 	    /* 1.x pmcd */
 	    ;
 	}
 	else if (sts < 0 && sts != PM_ERR_LICENSE) {
-	    /*
-	     * 2.0+ pmcd, but we have a fatal error on the connection ...
-	     */
+	    /* 2.0+ pmcd, but we have a fatal error on the connection ... */
 	    ;
 	}
 	else {
@@ -230,17 +153,11 @@ do_handshake(int fd, __pmIPC *infop)
 	    pduinfo = (__pmPDUInfo *)&challenge;
 	    *pduinfo = __ntohpmPDUInfo(*pduinfo);
 
-	    if (pduinfo->licensed == PM_LIC_COL) {
-		/* licensed pmcd, accept all */
-		handshake[0].c_type = CVERSION;
-		handshake[0].c_vala = PDU_VERSION;
-		handshake[0].c_valb = 0;
-		handshake[0].c_valc = 0;
-		sts = __pmSendCreds(fd, PDU_BINARY, 1, handshake);
-	    }
-	    else
-		/* pmcd not licensed, are you an authorized client? */
-		sts = __pmConnectHostMethod(fd, challenge);
+	    handshake[0].c_type = CVERSION;
+	    handshake[0].c_vala = PDU_VERSION;
+	    handshake[0].c_valb = 0;
+	    handshake[0].c_valc = 0;
+	    sts = __pmSendCreds(fd, PDU_BINARY, 1, handshake);
 	}
     }
     else
@@ -249,16 +166,9 @@ do_handshake(int fd, __pmIPC *infop)
     return sts;
 }
 
-int
-__pmConnectHandshake (int fd)
-{
-   __pmIPC	ipcinfo = { UNKNOWN_VERSION, NULL };
-   return (do_handshake (fd, &ipcinfo));
-}
-
 static int	global_nports;
 static int	*global_portlist;
-static int	default_portlist[] = { SERVER_PORT, OLD_SERVER_PORT };
+static int	default_portlist[] = { SERVER_PORT };
 
 static void
 load_pmcd_ports(void)
@@ -320,18 +230,17 @@ __pmConnectGetPorts(pmHostSpec *host)
 int
 __pmConnectPMCD(pmHostSpec *hosts, int nhosts)
 {
-    __pmIPC	ipcinfo = { UNKNOWN_VERSION, NULL };
     int		sts;
     int		fd;	/* Fd for socket connection to pmcd */
     int		*ports;
     int		nports;
     int		i;
+    int		version;
     int		proxyport;
     pmHostSpec	*proxyhost;
 
     static int first_time = 1;
     static pmHostSpec proxy;
-    extern int errno;
 
     if (first_time) {
 	/*
@@ -384,7 +293,7 @@ __pmConnectPMCD(pmHostSpec *hosts, int nhosts)
 	 */
 	for (i = 0; i < nports; i++) {
 	    if ((fd = __pmAuxConnectPMCDPort(hosts[0].name, ports[i])) >= 0) {
-		if ((sts = do_handshake(fd, &ipcinfo)) < 0) {
+		if ((sts = __pmConnectHandshake(fd)) < 0) {
 		    close(fd);
 		}
 		else
@@ -413,7 +322,7 @@ __pmConnectPMCD(pmHostSpec *hosts, int nhosts)
 #ifdef PCP_DEBUG
 	if (pmDebug & DBG_TRACE_CONTEXT) {
 	    fprintf(stderr, "__pmConnectPMCD(%s): pmcd connection port=%d fd=%d PDU version=%u\n",
-		    hosts[0].name, ports[i], fd, ipcinfo.version);
+		    hosts[0].name, ports[i], fd, __pmVersionIPC(fd));
 	    __pmPrintIPC();
 	}
 #endif
@@ -439,12 +348,10 @@ __pmConnectPMCD(pmHostSpec *hosts, int nhosts)
 #endif
 	    return fd;
 	}
-	if ((sts = negotiate_proxy(fd, hosts[0].name, ports[i])) < 0) {
+	if ((sts = version = negotiate_proxy(fd, hosts[0].name, ports[i])) < 0)
 	    close(fd);
-	}
-	if ((sts = do_handshake(fd, &ipcinfo)) < 0) {
+	else if ((sts = __pmConnectHandshake(fd)) < 0)
 	    close(fd);
-	}
 	else
 	    /* success */
 	    break;
@@ -468,12 +375,22 @@ __pmConnectPMCD(pmHostSpec *hosts, int nhosts)
 #ifdef PCP_DEBUG
     if (pmDebug & DBG_TRACE_CONTEXT) {
 	fprintf(stderr, "__pmConnectPMCD(%s): proxy connection host=%s port=%d fd=%d version=%d\n",
-	    hosts[0].name, proxyhost->name, ports[i], fd, proxy_version);
+	    hosts[0].name, proxyhost->name, ports[i], fd, version);
     }
 #endif
     return fd;
 }
 
+/*
+ * As of PCP version 2.1, we're no longer searching for DSO's;
+ * pmcd's config file should have full paths to each of 'em.
+ */
+const char *
+__pmFindPMDA(const char *name)
+{
+    return (access(name, F_OK) == 0) ? name : NULL;
+}
+
 __pmDSO *
 __pmLookupDSO(int domain)
 {
@@ -493,8 +410,10 @@ __pmConnectLocal(void)
     __pmDSO		*dp;
     char		pathbuf[MAXPATHLEN];
     const char		*path;
+#if defined(HAVE_DLOPEN)
     unsigned int	challenge;
     void		(*initp)(pmdaInterface *);
+#endif
 
     if (done_init)
 	return 0;
@@ -513,7 +432,7 @@ __pmConnectLocal(void)
 		continue;
 	    }
 	}
-#ifdef PROC_DSO
+#if defined(PROC_DSO)
 	/*
 	 * For Linux (and perhaps anything other than IRIX), the proc
 	 * PMDA is part of the OS PMDA, so this one cannot be optional
@@ -532,15 +451,23 @@ __pmConnectLocal(void)
 	    }
 	}
 #endif
-
-#ifdef __sgi
-	strcpy(pathbuf, dsoprefix);
-	strcat(pathbuf, dp->name);
-#else
-        snprintf (pathbuf, sizeof(pathbuf), "%s/%s",pmGetConfig("PCP_PMDAS_DIR"), dp->name);
+#if defined(IB_DSO)
+	if (dp->domain == IB_DSO) {
+	    /*
+	     * only attach infiniband pmda dso if env var PMDA_LOCAL_IB is
+	     * set
+	     */
+	    if (getenv("PMDA_LOCAL_IB") == NULL) {
+		/* no infiniband pmda */
+		dp->domain = -1;
+		continue;
+	    }
+	}
 #endif
-	if ((path = __pmFindPMDA(pathbuf)) == NULL) {
 
+        snprintf(pathbuf, sizeof(pathbuf), "%s/%s",
+		 pmGetConfig("PCP_PMDAS_DIR"), dp->name);
+	if ((path = __pmFindPMDA(pathbuf)) == NULL) {
 	    pmprintf("__pmConnectLocal: Warning: cannot find DSO \"%s\"\n", 
 		     pathbuf);
 	    pmflush();
@@ -548,12 +475,8 @@ __pmConnectLocal(void)
 	    dp->handle = NULL;
 	}
 	else {
-#ifdef HAVE_DLOPEN
-#ifdef __sgi
-	    dp->handle = dlopen(path, RTLD_LAZY);
-#else
+#if defined(HAVE_DLOPEN)
             dp->handle = dlopen(path, RTLD_NOW);
-#endif
 	    if (dp->handle == NULL) {
 		pmprintf("__pmConnectLocal: Warning: error attaching DSO "
 			 "\"%s\"\n%s\n\n", path, dlerror());
@@ -562,7 +485,8 @@ __pmConnectLocal(void)
 	    }
 #else	/* ! HAVE_DLOPEN */
 	    dp->handle = NULL;
-	    pmprintf("__pmConnectLocal: Warning: error attaching DSO \"%s\"\n", path);
+	    pmprintf("__pmConnectLocal: Warning: error attaching DSO \"%s\"\n",
+		     path);
 	    pmprintf("No dynamic DSO/DLL support on this platform\n\n");
 	    pmflush();
 	    dp->domain = -1;
@@ -572,7 +496,7 @@ __pmConnectLocal(void)
 	if (dp->handle == NULL)
 	    continue;
 
-#ifdef HAVE_DLOPEN
+#if defined(HAVE_DLOPEN)
 	/*
 	 * rest of this only makes sense if the dlopen() worked
 	 */
@@ -660,7 +584,6 @@ __pmConnectLocal(void)
 	    }
 	}
 #endif	/* HAVE_DLOPEN */
-
     }
 
     done_init = 1;
