@@ -1,6 +1,6 @@
 /*
- * Copyright (c) 1995-2002,2004 Silicon Graphics, Inc.  All Rights Reserved.
- * Copyright (c) 2007 Aconex.  All Rights Reserved.
+ * Copyright (c) 1995-2002,2004,2006,2008 Silicon Graphics, Inc.  All Rights Reserved.
+ * Copyright (c) 2007-2008 Aconex.  All Rights Reserved.
  * 
  * This library is free software; you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as published
@@ -15,18 +15,8 @@
  * You should have received a copy of the GNU Lesser General Public License
  * along with this library; if not, write to the Free Software Foundation,
  * Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA.
- * 
- * Contact information: Silicon Graphics, Inc., 1500 Crittenden Lane,
- * Mountain View, CA 94043, USA, or: http://www.sgi.com
  */
 
-#ident "$Id: context.c,v 1.4 2006/05/02 05:57:28 makc Exp $"
-
-#include <sys/param.h>
-#include <sys/socket.h>
-#include <stdio.h>
-#include <errno.h>
-#include <syslog.h>
 #include "pmapi.h"
 #include "impl.h"
 
@@ -67,7 +57,6 @@ waitawhile(__pmPMCDCtl *ctl)
 		}
 		if ((backoff = (int *)realloc(backoff, (n_backoff+1) * sizeof(backoff[0]))) == NULL) {
 		    __pmNoMem("pmReconnectContext", (n_backoff+1) * sizeof(backoff[0]), PM_FATAL_ERR);
-		    /*NOTREACHED*/
 		}
 		backoff[n_backoff++] = val;
 		if (*pend == '\0')
@@ -116,10 +105,6 @@ pmGetContextHostName (int ctxid)
     return ("");
 }
 
-#if defined(IRIX6_5)
-#pragma optional pmGetContextHostName
-#endif
-
 int
 pmWhichContext(void)
 {
@@ -142,6 +127,30 @@ pmWhichContext(void)
 }
 
 
+static int
+__pmConvertTimeout (int timeo)
+{
+    int tout_msec;
+    const struct timeval *tv;
+
+    switch (timeo) {
+    case TIMEOUT_NEVER:
+        tout_msec = -1;
+        break;
+    case TIMEOUT_DEFAULT:
+        tv = __pmDefaultRequestTimeout();
+
+        tout_msec = tv->tv_sec *1000 + tv->tv_usec / 1000;
+        break;
+
+    default:
+        tout_msec = timeo  * 1000;
+        break;
+    }
+
+    return tout_msec;
+}
+
 int
 pmNewContext(int type, const char *name)
 {
@@ -161,27 +170,12 @@ pmNewContext(int type, const char *name)
 	}
     }
 
-#ifdef MALLOC_AUDIT
-/* contexts are persistent, and no memory leak here */
-#include "no-malloc-audit.h"
-#endif
-
     /* Create a new one */
     if (contexts == NULL)
 	list = (__pmContext *)malloc(sizeof(__pmContext));
     else
 	list = (__pmContext *)realloc((void *)contexts, (1+contexts_len) * sizeof(__pmContext));
 
-#ifdef MALLOC_AUDIT
-/*
- * but other code may contain memory leaks ...
- * note { } 'cause prototypes in the include file
- */
-{
-#include "malloc-audit.h"
-}
-#endif
-
     if (list == NULL) {
 	/* fail : nothing changed */
 	sts = -errno;
@@ -255,8 +249,8 @@ INIT_CONTEXT:
 
 	    new->c_pmcd = (__pmPMCDCtl *)calloc(1,sizeof(__pmPMCDCtl));
 	    if (new->c_pmcd == NULL) {
-		close(sts);
 		sts = -errno;
+		__pmCloseSocket(sts);
 		__pmFreeHostSpec(hosts, nhosts);
 		goto FAILED;
 	    }
@@ -264,14 +258,11 @@ INIT_CONTEXT:
 	    new->c_pmcd->pc_state = inistate;
 	    new->c_pmcd->pc_hosts = hosts;
 	    new->c_pmcd->pc_nhosts = nhosts;
+	    new->c_pmcd->pc_tout_sec = __pmConvertTimeout(TIMEOUT_DEFAULT) / 1000;
 	}
 	new->c_pmcd->pc_refcnt++;
     }
     else if (type == PM_CONTEXT_LOCAL) {
-#if defined(HAVE_OBJECT_STYLE)
-	if ((sts = __pmCheckObjectStyle()) != 0)
-	    goto FAILED;
-#endif
 	if ((sts = __pmConnectLocal()) != 0)
 	    goto FAILED;
     }
@@ -378,14 +369,14 @@ pmReconnectContext(int handle)
 #ifdef PCP_DEBUG
 	if (pmDebug & DBG_TRACE_CONTEXT)
 	    fprintf(stderr, "pmReconnectContext(%d) -> %d, too soon (need wait another %d secs)\n",
-		handle, -ETIMEDOUT, (int)(ctl->pc_again - time(NULL)));
+		handle, (int)-ETIMEDOUT, (int)(ctl->pc_again - time(NULL)));
 #endif
 	    return -ETIMEDOUT;
 	}
 
 	if (ctl->pc_fd >= 0) {
 	    /* don't care if this fails */
-	    close(ctl->pc_fd);
+	    __pmCloseSocket(ctl->pc_fd);
 	    ctl->pc_fd = -1;
 	}
 
@@ -572,7 +563,7 @@ pmDestroyContext(int handle)
 		/* before close, unsent data should be flushed */
 		setsockopt(ctxp->c_pmcd->pc_fd, SOL_SOCKET,
 		    SO_LINGER, (char *) &dolinger, (mysocklen_t)sizeof(dolinger));
-		close(ctxp->c_pmcd->pc_fd);
+		__pmCloseSocket(ctxp->c_pmcd->pc_fd);
 	    }
 	    __pmFreeHostSpec(ctxp->c_pmcd->pc_hosts, ctxp->c_pmcd->pc_nhosts);
 	    free(ctxp->c_pmcd);
@@ -711,11 +702,10 @@ pmGetContextFD (int ctxid)
     return (ctxp->c_pmcd->pc_fd);
 }
 
-int
+int 
 pmGetContextTimeout (int ctxid, int *tout_msec)
 {
     __pmContext *ctxp = __pmHandleToPtr(ctxid);
-    const struct timeval *tv;
 
     if (ctxp == NULL) {
 	return (PM_ERR_NOCONTEXT);
@@ -725,20 +715,7 @@ pmGetContextTimeout (int ctxid, int *tout_msec)
 	return (-EINVAL);
     }
 
-    switch (ctxp->c_pmcd->pc_tout_sec) {
-    case TIMEOUT_NEVER:
-	*tout_msec = -1;
-	break;
-    case TIMEOUT_DEFAULT:
-	tv = __pmDefaultRequestTimeout();
-
-	*tout_msec = tv->tv_sec *1000 + tv->tv_usec / 1000;
-	break;
-
-    default:
-	*tout_msec = ctxp->c_pmcd->pc_tout_sec * 1000;
-	break;
-    }
+    *tout_msec = __pmConvertTimeout(ctxp->c_pmcd->pc_tout_sec);
 
     return (0);
 }
@@ -776,7 +753,7 @@ pmContextConnectTo (int ctxid, const struct sockaddr *addr)
         return (0);
     }
 
-    close (pc->pc_fd);
+    __pmCloseSocket(pc->pc_fd);
     pc->pc_fd = -1;
     
     return (f);
@@ -810,12 +787,14 @@ pmContextConnectChangeState (int ctxid)
 	    f = 0;
 	} else if (pc->pc_hosts[0].nports > 1) {
 	    int fd;
-	    close (pc->pc_fd);
+	    __pmCloseSocket(pc->pc_fd);
 
-	    if ((fd = __pmCreateSocket ()) >= 0) {
+	    if ((fd = __pmCreateSocket()) >= 0) {
 		if (fd != pc->pc_fd) {
-		    if ((f = dup2 (fd, pc->pc_fd)) == pc->pc_fd) {
-			close (fd);
+		    if ((f = dup2(fd, pc->pc_fd)) == pc->pc_fd) {
+			__pmSetVersionIPC(pc->pc_fd, __pmVersionIPC(fd));
+			__pmSetSocketIPC(pc->pc_fd);
+			__pmCloseSocket(fd);
 		    } else {
 			fd = -errno;
 		    }
@@ -843,7 +822,7 @@ pmContextConnectChangeState (int ctxid)
 	break;
 
     case PC_WAIT_FOR_PMCD:
-	if ((f = __pmConnectHandshake (pc->pc_fd)) >= 0) {
+	if ((f = __pmConnectHandshake(pc->pc_fd)) >= 0) {
 	    pc->pc_state = PC_READY;
 	    f = 0;
 	}
@@ -863,7 +842,7 @@ pmContextConnectChangeState (int ctxid)
     }
 
     if (f) {
-	close (pc->pc_fd);
+	__pmCloseSocket(pc->pc_fd);
 	pc->pc_fd = -1;
     } else if (pc->pc_state != PC_READY) {
 	f = PM_ERR_AGAIN;
