@@ -14,18 +14,8 @@
  * You should have received a copy of the GNU Lesser General Public License
  * along with this library; if not, write to the Free Software Foundation,
  * Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA.
- * 
- * Contact information: Silicon Graphics, Inc., 1500 Crittenden Lane,
- * Mountain View, CA 94043, USA, or: http://www.sgi.com
  */
 
-#ident "$Id: interp.c,v 1.4 2005/07/01 03:44:49 kenmcd Exp $"
-
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
-#include <syslog.h>
-#include <errno.h>
 #include <limits.h>
 #include "pmapi.h"
 #include "impl.h"
@@ -40,8 +30,6 @@
 #define SIGN_64_MASK 0x8000000000000000
 #endif
 
-extern int	errno;
-
 typedef union {				/* value from pmResult */
     pmValueBlock	*pval;
     int			lval;
@@ -588,7 +576,6 @@ __pmLogFetchInterp(__pmContext *ctxp, int numpmid, pmID pmidlist[], pmResult **r
 	    /* first time we've been asked for this one in this context */
 	    if ((pcp = (pmidcntl_t *)malloc(sizeof(pmidcntl_t))) == NULL) {
 		__pmNoMem("__pmLogFetchInterp.pmidcntl_t", sizeof(pmidcntl_t), PM_FATAL_ERR);
-		/*NOTREACHED*/
 	    }
 	    pcp->valfmt = -1;
 	    pcp->first = NULL;
@@ -611,7 +598,6 @@ __pmLogFetchInterp(__pmContext *ctxp, int numpmid, pmID pmidlist[], pmResult **r
 		    sts = 1;
 		    if ((instlist = (int *)malloc(sizeof(int))) == NULL) {
 			__pmNoMem("__pmLogFetchInterp.instlist", sizeof(int), PM_FATAL_ERR);
-			/*NOTREACHED*/
 		    }
 		    instlist[0] = PM_IN_NULL;
 		}
@@ -622,7 +608,6 @@ __pmLogFetchInterp(__pmContext *ctxp, int numpmid, pmID pmidlist[], pmResult **r
 		for (i = 0; i < sts; i++) {
 		    if ((icp = (instcntl_t *)malloc(sizeof(instcntl_t))) == NULL) {
 			__pmNoMem("__pmLogFetchInterp.instcntl_t", sizeof(instcntl_t), PM_FATAL_ERR);
-			/*NOTREACHED*/
 		    }
 		    if (lcp)
 			lcp->next = icp;
@@ -1014,7 +999,6 @@ retry_forw:
 
 	if (rp->vset[j] == NULL) {
 	    __pmNoMem("__pmLogFetchInterp.vset", sizeof(pmValueSet), PM_FATAL_ERR);
-	    /*NOTREACHED*/
 	}
 
 	rp->vset[j]->pmid = pmidlist[j];
