@@ -14,22 +14,11 @@
  * You should have received a copy of the GNU Lesser General Public License
  * along with this library; if not, write to the Free Software Foundation,
  * Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA.
- * 
- * Contact information: Silicon Graphics, Inc., 1500 Crittenden Lane,
- * Mountain View, CA 94043, USA, or: http://www.sgi.com
  */
 
-#ident "$Id: logmeta.c,v 1.2 2004/08/02 07:11:43 kenmcd Exp $"
-
-#include <stdio.h>
 #include "pmapi.h"
 #include "impl.h"
 #include <stddef.h>
-#include <string.h>
-#include <syslog.h>
-#include <errno.h>
-
-extern int	errno;
 
 /* bytes for a length field in a header/trailer, or a string length field */
 #define LENSIZE	4
@@ -862,11 +851,9 @@ pmGetInDomArchive(pmInDom indom, int **instlist, char ***namelist)
 		    numinst++;
 		    if ((ilist = (int *)realloc(ilist, numinst*sizeof(ilist[0]))) == NULL) {
 			__pmNoMem("pmGetInDomArchive: ilist", numinst*sizeof(ilist[0]), PM_FATAL_ERR);
-			/*NOTREACHED*/
 		    }
 		    if ((nlist = (char **)realloc(nlist, numinst*sizeof(nlist[0]))) == NULL) {
 			__pmNoMem("pmGetInDomArchive: nlist", numinst*sizeof(nlist[0]), PM_FATAL_ERR);
-			/*NOTREACHED*/
 		    }
 		    ilist[numinst-1] = idp->instlist[j];
 		    nlist[numinst-1] = idp->namelist[j];
@@ -876,7 +863,6 @@ pmGetInDomArchive(pmInDom indom, int **instlist, char ***namelist)
 	}
 	if ((olist = (char **)malloc(numinst*sizeof(olist[0]) + strsize)) == NULL) {
 	    __pmNoMem("pmGetInDomArchive: olist", numinst*sizeof(olist[0]) + strsize, PM_FATAL_ERR);
-	    /*NOTREACHED*/
 	}
 	p = (char *)olist;
 	p += numinst * sizeof(olist[0]);
