@@ -14,26 +14,12 @@
  * You should have received a copy of the GNU Lesser General Public License
  * along with this library; if not, write to the Free Software Foundation,
  * Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA.
- * 
- * Contact information: Silicon Graphics, Inc., 1500 Crittenden Lane,
- * Mountain View, CA 94043, USA, or: http://www.sgi.com
  */
 
-#ident "$Id: logutil.c,v 1.12 2006/11/13 03:47:31 kimbrr Exp $"
-
-#include <unistd.h>
-#include <stdio.h>
-#include <string.h>
-#include <syslog.h>
-#include <errno.h>
-#include <dirent.h>
-#include <sys/types.h>
-#include <sys/param.h>
 #include <sys/stat.h>
 #include "pmapi.h"
 #include "impl.h"
 
-extern int	errno;
 int		__pmLogReads = 0;
 
 static char	*logfilename = NULL;
@@ -201,18 +187,13 @@ __pmLogChkLabel(__pmLogCtl *lcp, FILE *f, __pmLogLabel *lp, int vol)
 	return PM_ERR_LABEL;
     }
     else {
-	__pmIPC	ipc;
-
+	if (__pmSetVersionIPC(fileno(f), version) < 0)
+	    return -errno;
 #ifdef PCP_DEBUG
 	if (pmDebug & DBG_TRACE_LOG)
 	    fprintf(stderr, " [magic=%8x version=%d vol=%d pid=%d host=%s]\n",
 		lp->ill_magic, version, lp->ill_vol, (int)lp->ill_pid, lp->ill_hostname);
 #endif
-
-	ipc.version = version;
-	ipc.ext = NULL;
-	if ((__pmAddIPC(fileno(f), ipc)) < 0)
-	    return -errno;
     }
 
     if (vol >= 0 && vol < lcp->l_numseen)
@@ -351,7 +332,6 @@ __pmLogName(const char *base, int vol)
 	    free(tbuf);
 	if ((tbuf = (char *)malloc(len)) == NULL) {
 	    __pmNoMem("__pmLogName", len, PM_FATAL_ERR);
-	    /*NOTREACHED*/
 	}
 	tlen = len;
     }
@@ -397,16 +377,12 @@ __pmLogNewFile(const char *base, int vol)
 	setoserror(save_errno);
 	return NULL;
     }
-    else {
-	__pmIPC	ipc = { PDU_VERSION, NULL };
 
-	if ((__pmAddIPC(fileno(f), ipc)) < 0) {
-	    save_errno = oserror();
-	    pmprintf("__pmLogNewFile: failed to create \"%s\": %s\n", fname, strerror(save_errno));
-	    pmflush();
-	    setoserror(save_errno);
-	    return NULL;
-	}
+    if ((save_errno = __pmSetVersionIPC(fileno(f), PDU_VERSION)) < 0) {
+	pmprintf("__pmLogNewFile: failed to setup \"%s\": %s\n", fname, strerror(save_errno));
+	pmflush();
+	setoserror(save_errno);
+	return NULL;
     }
 
     return f;
@@ -456,7 +432,6 @@ __pmLogCreate(const char *host, const char *base, int log_version,
 	    if ((lcp->l_mfp = __pmLogNewFile(base, 0)) != NULL) {
 		char *tz = __pmTimezone();
                 int             sts;
-                __pmIPC         *ipc;
 
 		lcp->l_label.ill_magic = PM_LOG_MAGIC | log_version;
 		/*
@@ -476,20 +451,14 @@ __pmLogCreate(const char *host, const char *base, int log_version,
                  * __pmLogNewFile sets the IPC version to PDU_VERSION
                  * we want log_version instead
                  */
-
-                if ((sts=__pmFdLookupIPC(fileno(lcp->l_tifp), &ipc)) < 0)
+		sts = __pmSetVersionIPC(fileno(lcp->l_tifp), log_version);
+		if (sts < 0)
                     return sts;
-                ipc->version=log_version;
-
-                if ((sts=__pmFdLookupIPC(fileno(lcp->l_mdfp), &ipc)) < 0)
+		sts = __pmSetVersionIPC(fileno(lcp->l_mdfp), log_version);
+		if (sts < 0)
                     return sts;
-                ipc->version=log_version;
-
-                if ((sts=__pmFdLookupIPC(fileno(lcp->l_mfp), &ipc)) < 0)
-                    return sts;
-                ipc->version=log_version;
-
-		return 0;
+		sts = __pmSetVersionIPC(fileno(lcp->l_mfp), log_version);
+		return sts;
 	    }
 	    else {
 		save_errno = oserror();
@@ -1542,7 +1511,6 @@ more:
 	    i = (int)sizeof(pmResult) + numpmid * (int)sizeof(pmValueSet *);
 	    if ((newres = (pmResult *)malloc(i)) == NULL) {
 		__pmNoMem("__pmLogFetch.newres", i, PM_FATAL_ERR);
-		/*NOTREACHED*/
 	    }
 	    newres->numpmid = numpmid;
 	    newres->timestamp = (*result)->timestamp;
@@ -1553,7 +1521,6 @@ more:
 		    /* first time we've been asked for this one */
 		    if ((pcp = (pmid_ctl *)malloc(sizeof(pmid_ctl))) == NULL) {
 			__pmNoMem("__pmLogFetch.pmid_ctl", sizeof(pmid_ctl), PM_FATAL_ERR);
-			/*NOTREACHED*/
 		    }
 		    pcp->pc_pmid = pmidlist[j];
 		    pcp->pc_numval = 0;
