@@ -14,13 +14,8 @@
  * You should have received a copy of the GNU Lesser General Public License
  * along with this library; if not, write to the Free Software Foundation,
  * Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA.
- * 
- * Contact information: Silicon Graphics, Inc., 1500 Crittenden Lane,
- * Mountain View, CA 94043, USA, or: http://www.sgi.com
  */
 
-#ident "$Id: optfetch.c,v 1.1 2000/12/05 03:49:43 max Exp $"
-
 /*
  * Generic routines to provide the "optimized" pmFetch bundling
  * services ... the optimization is driven by the crude heuristics
@@ -32,9 +27,6 @@
 #define DEBUG
 #endif
 
-#include <stdio.h>
-#include <string.h>
-#include <syslog.h>
 #include "pmapi.h"
 #include "impl.h"
 
@@ -54,8 +46,6 @@
 /* default costs */
 static optcost_t	optcost = { 4, 1, 15, 10, 2, 0 };
 
-extern int	errno;
-
 static int
 addpmid(fetchctl_t *fp, pmID pmid)
 {
@@ -72,7 +62,6 @@ addpmid(fetchctl_t *fp, pmID pmid)
     fp->f_pmidlist = (pmID *)realloc(fp->f_pmidlist, fp->f_numpmid*sizeof(pmID));
     if (fp->f_pmidlist == NULL) {
 	__pmNoMem("addpmid", fp->f_numpmid*sizeof(pmID), PM_FATAL_ERR);
-	/*NOTREACHED*/
     }
 
     for (j = fp->f_numpmid-1; j > i; j--)
@@ -109,7 +98,6 @@ addinst(int *numinst, int **instlist, optreq_t *new)
     ilist = (int *)realloc(*instlist, (numi + new->r_numinst)*sizeof(int));
     if (ilist == NULL) {
 	__pmNoMem("addinst.up", (numi + new->r_numinst)*sizeof(int), PM_FATAL_ERR);
-	/*NOTREACHED*/
     }
 
     for (j = 0; j < new->r_numinst; j++) {
@@ -133,7 +121,6 @@ addinst(int *numinst, int **instlist, optreq_t *new)
     ilist = (int *)realloc(ilist, numi*sizeof(int));
     if (ilist == NULL) {
 	__pmNoMem("addinst.down", numi*sizeof(int), PM_FATAL_ERR);
-	/*NOTREACHED*/
     }
     
     *numinst = numi;
@@ -375,7 +362,6 @@ __pmOptFetchAdd(fetchctl_t **root, optreq_t *new)
     /* add new fetch as first option ... will be reclaimed later if not used */
     if ((fp = (fetchctl_t *)calloc(1, sizeof(fetchctl_t))) == NULL) {
 	__pmNoMem("optAddFetch.fetch", sizeof(fetchctl_t), PM_FATAL_ERR);
-	/*NOTREACHED*/
     }
     fp->f_next = *root;
     *root = fp;
@@ -403,7 +389,6 @@ __pmOptFetchAdd(fetchctl_t **root, optreq_t *new)
 	if (change & OPT_STATE_XINDOM) {
 	    if ((idp = (indomctl_t *)calloc(1, sizeof(indomctl_t))) == NULL) {
 		__pmNoMem("optAddFetch.indomctl", sizeof(indomctl_t), PM_FATAL_ERR);
-		/*NOTREACHED*/
 	    }
 	    idp->i_indom = indom;
 	    idp->i_next = fp->f_idp;
@@ -413,7 +398,6 @@ __pmOptFetchAdd(fetchctl_t **root, optreq_t *new)
 	if (change & OPT_STATE_XPMID) {
 	    if ((pmp = (pmidctl_t *)calloc(1, sizeof(pmidctl_t))) == NULL) {
 		__pmNoMem("optAddFetch.pmidctl", sizeof(pmidctl_t), PM_FATAL_ERR);
-		/*NOTREACHED*/
 	    }
 	    pmp->p_next = idp->i_pmp;
 	    idp->i_pmp = pmp;
