@@ -14,20 +14,12 @@
  * You should have received a copy of the GNU Lesser General Public License
  * along with this library; if not, write to the Free Software Foundation,
  * Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA.
- * 
- * Contact information: Silicon Graphics, Inc., 1500 Crittenden Lane,
- * Mountain View, CA 94043, USA, or: http://www.sgi.com
  */
 
-#ident "$Id: p_instance.c,v 1.3 2004/08/02 07:11:43 kenmcd Exp $"
-
 #include <ctype.h>
-#include <syslog.h>
 #include "pmapi.h"
 #include "impl.h"
 
-extern int	errno;
-
 /*
  * PDU for pm*InDom request (PDU_INSTANCE_REQ)
  */
