@@ -14,27 +14,15 @@
  * You should have received a copy of the GNU Lesser General Public License
  * along with this library; if not, write to the Free Software Foundation,
  * Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA.
- * 
- * Contact information: Silicon Graphics, Inc., 1500 Crittenden Lane,
- * Mountain View, CA 94043, USA, or: http://www.sgi.com
  */
 
-#ident "$Id: p_pmns.c,v 1.1 2000/12/05 03:49:43 max Exp $"
-
 #include <ctype.h>
-#include <syslog.h>
 #include "pmapi.h"
 #include "impl.h"
 
-extern int	errno;
-
-
-/*********************************************************************/
-
 /*
  * PDU for id list (PDU_PMNS_IDS)
  */
-
 typedef struct {
     __pmPDUHdr   hdr;
     int		sts;      /* to encode status of pmns op */
