@@ -14,39 +14,13 @@
  * You should have received a copy of the GNU Lesser General Public License
  * along with this library; if not, write to the Free Software Foundation,
  * Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA.
- * 
- * Contact information: Silicon Graphics, Inc., 1500 Crittenden Lane,
- * Mountain View, CA 94043, USA, or: http://www.sgi.com
  */
 
-#ident "$Id: pdu.c,v 1.13 2006/05/02 05:57:28 makc Exp $"
-
-#include <stdio.h>
-#include <unistd.h>
-#include <sys/types.h>
-#include <sys/time.h>
 #include <signal.h>
-#include <syslog.h>
-#include <errno.h>
-#if defined(sgi)
-#include <bstring.h>
-#endif
-
 #include "pmapi.h"
 #include "impl.h"
 
-#ifdef MALLOC_AUDIT
-/*
- * PDU buffer allocations here are permanent, and do not cause any
- * memory leaks
- */
-#include "no-malloc-audit.h"
-#endif
-
-extern int	errno;
-extern int	__pmLastUsedFd;
-
-int		pmDebug = 0;		/* the real McCoy */
+INTERN int	pmDebug = 0;		/* the real McCoy */
 
 #define ABUF_SIZE	1024	/* read buffer for reading ascii PDUs */
 
@@ -57,8 +31,8 @@ int		pmDebug = 0;		/* the real McCoy */
 
 static unsigned int	inctrs[PDU_MAX+1] = { 0 };
 static unsigned int	outctrs[PDU_MAX+1] = { 0 };
-unsigned int	*__pmPDUCntIn = inctrs;
-unsigned int	*__pmPDUCntOut = outctrs;
+INTERN unsigned int	*__pmPDUCntIn = inctrs;
+INTERN unsigned int	*__pmPDUCntOut = outctrs;
 
 /*
  * unit of space allocation for PDU buffer ... actually defined in pdubuf.c,
@@ -79,20 +53,19 @@ static ascii_ctl	ac;
 
 static int              ceiling = PDU_CHUNK * 64;
 
-/*ARGSUSED*/
 int
 __pmMoreInput(int fd)
 {
     return 0;
 }
 
-/*ARGSUSED*/
 void
 __pmNoMoreInput(int fd)
 {
 }
 
 static struct timeval	def_wait = { 10, 0 };
+static double		def_timeout = 10.0;
 
 const struct timeval *
 __pmDefaultRequestTimeout(void)
@@ -100,7 +73,6 @@ __pmDefaultRequestTimeout(void)
     static int		done_default = 0;
 
     if (!done_default) {
-	double	def_timeout;
 	char	*timeout_str;
 	char	*end_ptr;
 	if ((timeout_str = getenv("PMCD_REQUEST_TIMEOUT")) != NULL) {
@@ -123,12 +95,13 @@ __pmDefaultRequestTimeout(void)
     return (&def_wait);
 }
 
-static int
+int
 pduread(int fd, char *buf, int len, int mode, int timeout)
 {
     /*
-     * handle short reads that may spilt a PDU ...
+     * handle short reads that may split a PDU ...
      */
+    int			socketipc = __pmSocketIPC(fd);
     int			status = 0;
     int			have = 0;
     fd_set		onefd;
@@ -144,8 +117,11 @@ pduread(int fd, char *buf, int len, int mode, int timeout)
 	     * Also assumes buf is aligned on a __pmPDU boundary.
 	     */
 	    __pmPDU	*lp;
-	    status = (int)read(fd, buf, (int)sizeof(__pmPDU));
-	    __pmLastUsedFd = fd;
+
+	    status = socketipc ?
+		recv(fd, buf, (int)sizeof(__pmPDU), 0) :
+		read(fd, buf, (int)sizeof(__pmPDU));
+	    __pmOverrideLastFd(fd);
 	    if (status <= 0)
 		/* EOF or error */
 		return status;
@@ -154,7 +130,9 @@ pduread(int fd, char *buf, int len, int mode, int timeout)
 		return PM_ERR_IPC;
 	    lp = (__pmPDU *)buf;
 	    have = ntohl(*lp);
-	    status = (int)read(fd, &buf[sizeof(__pmPDU)], have - (int)sizeof(__pmPDU));
+	    status = socketipc ?
+		recv(fd, &buf[sizeof(__pmPDU)], have - (int)sizeof(__pmPDU), 0):
+		read(fd, &buf[sizeof(__pmPDU)], have - (int)sizeof(__pmPDU));
 	    if (status <= 0)
 		/* EOF or error */
 		return status;
@@ -165,6 +143,20 @@ pduread(int fd, char *buf, int len, int mode, int timeout)
 	}
 	else {
 	    struct timeval	wait;
+
+#if defined(IS_MINGW)	/* cannot select on a pipe on Win32 - yay! */
+	    if (!__pmSocketIPC(fd)) {
+		COMMTIMEOUTS cwait = { 0 };
+
+		if (timeout != TIMEOUT_NEVER)
+		    cwait.ReadTotalTimeoutConstant = timeout * 1000.0;
+		else
+		    cwait.ReadTotalTimeoutConstant = def_timeout * 1000.0;
+		SetCommTimeouts((HANDLE)_get_osfhandle(fd), &cwait);
+	    }
+	    else
+#endif
+
 	    /*
 	     * either never timeout (i.e. block forever), or timeout
 	     */
@@ -181,8 +173,8 @@ pduread(int fd, char *buf, int len, int mode, int timeout)
 		if (status == 0) {
 		    if (__pmGetInternalState() != PM_STATE_APPL) {
 			/* special for PMCD and friends 
-			 * Note, on Linux select would return 'time remaing' in
-			 * timeout value, so report the expected timeout
+			 * Note, on Linux select would return 'time remaining'
+			 * in timeout value, so report the expected timeout
 			 */
 			int tosec, tomsec;
 
@@ -209,8 +201,8 @@ pduread(int fd, char *buf, int len, int mode, int timeout)
 		    return status;
 		}
 	    }
-	    status = (int)read(fd, buf, len);
-	    __pmLastUsedFd = fd;
+	    status = socketipc ? recv(fd, buf, len, 0) : read(fd, buf, len);
+	    __pmOverrideLastFd(fd);
 	    if (status <= 0 || mode == PDU_ASCII)
 		/* ASCII, EOF or error */
 		return status;
@@ -259,33 +251,44 @@ __pmPDUTypeStr(int type)
     }
 }
 
-/* Because the default handler for SIGPIPE is to exit, we always want a handler
-   installed to override that so that the write() just returns an error.  The
-   problem is that the user might have installed one prior to the first write()
-   or may install one at some later stage.  This doesn't matter.  As long as a
-   handler other than SIG_DFL is there, all will be well.  The first time that
-   __pmXmitPDU is called, install SIG_IGN as the handler for SIGPIPE.  If the
-   user had already changed the handler from SIG_DFL, put back what was there
-   before. */
-
+#if defined(HAVE_SIGPIPE)
+/*
+ * Because the default handler for SIGPIPE is to exit, we always want a handler
+ * installed to override that so that the write() just returns an error.  The
+ * problem is that the user might have installed one prior to the first write()
+ * or may install one at some later stage.  This doesn't matter.  As long as a
+ * handler other than SIG_DFL is there, all will be well.  The first time that
+ * __pmXmitPDU is called, install SIG_IGN as the handler for SIGPIPE.  If the
+ * user had already changed the handler from SIG_DFL, put back what was there
+ * before.
+ */
 static int sigpipe_done = 0;		/* First time check for installation of
 					   non-default SIGPIPE handler */
+static void setup_sigpipe()
+{
+    if (!sigpipe_done) {       /* Make sure SIGPIPE is handled */
+	SIG_PF  user_onpipe;
+	user_onpipe = signal(SIGPIPE, SIG_IGN);
+	if (user_onpipe != SIG_DFL)     /* Put user handler back */
+	     signal(SIGPIPE, user_onpipe);
+	sigpipe_done = 1;
+    }
+}
+#else
+static void setup_sigpipe() { }
+#endif
 
 int
 __pmXmitPDU(int fd, __pmPDU *pdubuf)
 {
+    int		socketipc = __pmSocketIPC(fd);
     int		off = 0;
     int		len;
     __pmPDUHdr	*php = (__pmPDUHdr *)pdubuf;
 
     /* assume PDU_BINARY ... should not be here, otherwise */
-    if (!sigpipe_done) {	/* Make sure SIGPIPE is handled */
-	SIG_PF	user_onpipe;
-	user_onpipe = signal(SIGPIPE, SIG_IGN);
-	if (user_onpipe != SIG_DFL)	/* Put user handler back */
-	    signal(SIGPIPE, user_onpipe);
-	sigpipe_done = 1;
-    }
+
+    setup_sigpipe();
 
     if (mypid == -1)
 	mypid = getpid();
@@ -322,9 +325,9 @@ __pmXmitPDU(int fd, __pmPDU *pdubuf)
 
 	p += off;
 
-	if ((n = (int)write(fd, p, len-off)) < 0) {
+	n = socketipc ? send(fd, p, len-off, 0) : write(fd, p, len-off);
+	if (n < 0)
 	    break;
-	}
 	off += n;
     }
     php->len = ntohl(php->len);
@@ -334,7 +337,7 @@ __pmXmitPDU(int fd, __pmPDU *pdubuf)
     if (off != len)
 	return (errno) ? -errno : PM_ERR_IPC;
 
-    __pmLastUsedFd = fd;
+    __pmOverrideLastFd(fd);
     if (php->type >= PDU_START && php->type <= PDU_FINISH)
 	__pmPDUCntOut[php->type-PDU_START]++;
 
@@ -344,6 +347,9 @@ __pmXmitPDU(int fd, __pmPDU *pdubuf)
 int
 __pmXmitAscii(int fd, const char *buf, int nbytes)
 {
+    int		socketipc = __pmSocketIPC(fd);
+    int		bytes;
+
 #ifdef PCP_DEBUG
     if (pmDebug & DBG_TRACE_PDU) {
 	fprintf(stderr, "[%d]pmXmitPDU: fd=%d ASCII (%d bytes): %s",
@@ -352,18 +358,13 @@ __pmXmitAscii(int fd, const char *buf, int nbytes)
 	    putc('\n', stderr);
     }
 #endif
-    if (!sigpipe_done) {	/* Make sure SIGPIPE is handled */
-	SIG_PF	user_onpipe;
-	user_onpipe = signal(SIGPIPE, SIG_IGN);
-	if (user_onpipe != SIG_DFL)	/* Put user handler back */
-	    signal(SIGPIPE, user_onpipe);
-	sigpipe_done = 1;
-    }
 
-    if (write(fd, buf, nbytes) != nbytes)
+    setup_sigpipe();
+
+    bytes = socketipc ? send(fd, buf, nbytes, 0) : write(fd, buf, nbytes);
+    __pmOverrideLastFd(fd);
+    if (bytes != nbytes)
 	return -errno;
-
-    __pmLastUsedFd = fd;
     return 0;
 }
 
@@ -390,10 +391,7 @@ __pmGetPDU(int fd, int mode, int timeout, __pmPDU **result)
 
 	if (len < (int)sizeof(__pmPDUHdr)) {
 	    if (len == -1) {
-		if (errno == ECONNRESET ||
-#ifndef __sgi
-		    errno == EPIPE || 
-#endif
+		if (errno == ECONNRESET || errno == EPIPE || 
 		    errno == ETIMEDOUT || errno == ENETDOWN ||
 		    errno == ENETUNREACH || errno == EHOSTDOWN ||
 		    errno == EHOSTUNREACH || errno == ECONNREFUSED)
@@ -691,9 +689,3 @@ __pmSetPDUCntBuf(unsigned *in, unsigned *out)
     __pmPDUCntIn = in;
     __pmPDUCntOut = out;
 }
-
-#ifdef IRIX6_5
-#pragma optional __pmGetPDUCeiling
-#pragma optional __pmSetPDUCeiling
-#pragma optional __pmSetPDUCntBuf
-#endif
