@@ -14,21 +14,10 @@
  * You should have received a copy of the GNU Lesser General Public License
  * along with this library; if not, write to the Free Software Foundation,
  * Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA.
- * 
- * Contact information: Silicon Graphics, Inc., 1500 Crittenden Lane,
- * Mountain View, CA 94043, USA, or: http://www.sgi.com
  */
 
-#ident "$Id: rtime.c,v 1.3 2005/02/23 09:55:12 kenmcd Exp $"
-
-#include <stdio.h>
 #include <limits.h>
 #include <ctype.h>
-#include <stdlib.h>
-#include <strings.h>
-#include <time.h>
-#include <sys/time.h>
-
 #include "pmapi.h"
 #include "impl.h"
 
