@@ -14,16 +14,8 @@
  * You should have received a copy of the GNU Lesser General Public License
  * along with this library; if not, write to the Free Software Foundation,
  * Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA.
- * 
- * Contact information: Silicon Graphics, Inc., 1500 Crittenden Lane,
- * Mountain View, CA 94043, USA, or: http://www.sgi.com
  */
 
-#ident "$Id: units.c,v 1.4 2004/08/02 07:11:43 kenmcd Exp $"
-
-#include <stdio.h>
-#include <string.h>
-#include <syslog.h>
 #include "pmapi.h"
 #include "impl.h"
 
@@ -33,8 +25,6 @@
 #define SIGN_64_MASK 0x8000000000000000
 #endif
 
-extern int	errno;
-
 /* pmAtomValue -> string, max length is 40 bytes */
 const char *
 pmAtomStr(const pmAtomValue *avp, int type)
@@ -935,7 +925,6 @@ pmExtractValue(int valfmt, const pmValue *ival, int itype,
 		}
 		if ((oval->cp = (char *)malloc(len + 1)) == NULL) {
 		    __pmNoMem("pmConvValue.string", len + 1, PM_FATAL_ERR);
-		    /*NOTREACHED*/
 		}
 		memcpy(oval->cp, ival->value.pval->vbuf, len);
 		oval->cp[len] = '\0';
@@ -966,7 +955,6 @@ pmExtractValue(int valfmt, const pmValue *ival, int itype,
 		}
 		if ((oval->vp = (void *)malloc(len)) == NULL) {
 		    __pmNoMem("pmConvValue.aggr", len, PM_FATAL_ERR);
-		    /*NOTREACHED*/
 		}
 		memcpy(oval->vp, ival->value.pval->vbuf, len);
 		break;
