@@ -16,31 +16,21 @@
  * You should have received a copy of the GNU Lesser General Public License
  * along with this library; if not, write to the Free Software Foundation,
  * Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA.
- * 
- * Contact information: Silicon Graphics, Inc., 1500 Crittenden Lane,
- * Mountain View, CA 94043, USA, or: http://www.sgi.com
  */
 
-#ident "$Id: util.c,v 1.8 2004/08/02 07:11:43 kenmcd Exp $"
-
-#include <stdio.h>
-#include <stdlib.h>
-#include <unistd.h>
 #include <stdarg.h>
-#include <sys/types.h>
-#include <sys/param.h>
-#include <fcntl.h>
-#include <time.h>
-#include <syslog.h>
-#include <string.h>
-#include <errno.h>
+#include <sys/stat.h> 
 #include <ctype.h>
 #include <limits.h>
 #include <math.h>
+
 #include "pmapi.h"
 #include "impl.h"
 #include "pmdbg.h"
 
+#if defined(HAVE_SYS_TIMES_H)
+#include <sys/times.h>
+#endif
 #if defined(HAVE_IEEEFP_H)
 #include <ieeefp.h>
 #endif
@@ -50,14 +40,39 @@ static int	nfilelog = 0;
 static int	dosyslog = 0;
 static int	pmState = PM_STATE_APPL;
 static int	done_exit = 0;
-#if defined(IRIX5_3)
-static pid_t	lucky_pid;
-#endif
 
-char		*pmProgname = "pcp";		/* the real McCoy */
+INTERN char	*pmProgname = "pcp";		/* the real McCoy */
 
 static int vpmprintf(const char *, va_list);
 
+int
+__pmSetProgname(const char *program)
+{
+    char	*p;
+
+    /* Trim command name of leading directory components */
+    if (program)
+	pmProgname = (char *)program;
+    for (p = pmProgname; pmProgname && *p; p++) {
+	if (*p == '/')
+	    pmProgname = p+1;
+    }
+#if defined(IS_MINGW)
+    _fmode = O_BINARY;
+
+    int sts;
+    WORD wVersionRequested = MAKEWORD(2, 2);
+    WSADATA wsaData;
+
+    /* If Windows networking is not setup, all networking calls fail;
+     * this even includes gethostname(2), if you can believe that. :[
+     */
+    if ((sts = WSAStartup(wVersionRequested, &wsaData)) != 0)
+	return sts;
+#endif
+    return 0;
+}
+
 /*
  * if onoff == 1, logging is to syslog and stderr, else logging is
  * just to stderr (this is the default)
@@ -99,9 +114,6 @@ __pmNotifyErr(int priority, const char *message, ...)
      * do the stderr equivalent
      */
 
-#if defined(sgi)
-    priority = LOG_PRI(priority);
-#endif
     switch (priority) {
     	case LOG_EMERG :
 	    level = "Emergency";
@@ -176,12 +188,6 @@ logonexit(void)
      */
     if (++done_exit != 1)
 	return;
-#if defined(IRIX5_3)
-    if (lucky_pid != getpid()) {
-	done_exit--;
-	return;
-    }
-#endif
 
     for (i = 0; i < nfilelog; i++)
 	logfooter(filelog[i], "finished");
@@ -195,7 +201,6 @@ logreopen(const char *progname, const char *logname, FILE *oldstream,
     int		oldfd;
     int		dupoldfd;
     FILE	*dupoldstream = oldstream;
-    extern int	errno;
 
     /*
      * Do our own version of freopen() because the standard one closes the
@@ -252,22 +257,13 @@ __pmOpenLog(const char *progname, const char *logname, FILE *oldstream,
     oldstream = logreopen(progname, logname, oldstream, status);
     logheader(progname, oldstream, "started");
 
-    /*
-     * atexit() race condition in IRIX 5.3 measn we have to be very careful
-     * about who is allowed to try and write the log termination messages.
-     */
     nfilelog++;
-    if (nfilelog == 1) {
+    if (nfilelog == 1)
 	atexit(logonexit);
-#if defined(IRIX5_3)
-	lucky_pid = getpid();
-#endif
-    }
 
     filelog = (FILE **)realloc(filelog, nfilelog * sizeof(FILE *));
     if (filelog == NULL) {
 	__pmNoMem("__pmOpenLog", nfilelog * sizeof(FILE *), PM_FATAL_ERR);
-	/*NOTREACHED*/
     }
     filelog[nfilelog-1] = oldstream;
     return oldstream;
@@ -581,8 +577,6 @@ pmPrintValue(FILE *f,			/* output stream */
 void
 __pmNoMem(const char *where, size_t size, int fatal)
 {
-    extern int	errno;
-
     __pmNotifyErr(fatal ? LOG_ERR : LOG_WARNING,
 		 "%s: malloc(%d) failed: %s", where, size, strerror(errno));
     if (fatal)
@@ -981,7 +975,8 @@ dirname(char *name)
 #endif
 
 #ifndef HAVE_ISNAND
-int isnand (double d)
+int
+isnand(double d)
 {
 #ifdef HAVE_ISNANF
     float	f = (float)d;
@@ -993,3 +988,206 @@ int isnand (double d)
 #endif
 }
 #endif
+
+#ifndef HAVE_UNSETENV
+int
+unsetenv(const char *name)
+{
+    extern char **_environ;
+    char	**ep;
+    int		len = (int)strlen(name);
+    int		found = 0;
+
+    for (ep = _environ; *ep != NULL; ep++) {
+	if (strncmp(*ep, name, len) == 0 && (*ep)[len] == '=') {
+	    found = 1;
+	}
+	if (found)
+	    ep[0] = ep[1];
+    }
+    return found;
+}
+#endif
+
+#ifndef HAVE_SCANDIR
+/*
+ * Scan the directory dirname, building an array of pointers to
+ * dirent entries using malloc(3C).  select() and compare() are
+ * used to optionally filter and sort directory entries.
+ */
+int
+scandir(const char *dirname, struct dirent ***namelist,
+        int(*select)(const_dirent *),
+        int(*compare)(const_dirent **, const_dirent **))
+{
+    DIR			*dirp;
+    int			n = 0;
+    struct dirent	**names = NULL;
+    struct dirent	*dp;
+    struct dirent	*tp;
+
+    if ((dirp = opendir(dirname)) == NULL)
+	return -1;
+
+    while ((dp = readdir(dirp)) != NULL) {
+	if (select && (*select)(dp) == 0)
+	    continue;
+
+	n++;
+	if ((names = (struct dirent **)realloc(names, n * sizeof(dp))) == NULL)
+	    return -1;
+
+	if ((names[n-1] = tp = (struct dirent *)malloc(
+		sizeof(*dp)-sizeof(dp->d_name)+strlen(dp->d_name)+1)) == NULL)
+	    return -1;
+
+	tp->d_ino = dp->d_ino;
+#if defined(HAVE_DIRENT_D_OFF)
+	tp->d_off = dp->d_off;
+#else
+	tp->d_reclen = dp->d_reclen;
+#endif
+	memcpy(tp->d_name, dp->d_name, strlen(dp->d_name)+1);
+    }
+    closedir(dirp);
+    *namelist = names;
+
+    if (n && compare)
+	qsort(names, n, sizeof(names[0]),
+			(int(*)(const void *, const void *))compare);
+    return n;
+}
+
+/* 
+ * Alphabetical sort for default use
+ */
+int
+alphasort(const_dirent **p, const_dirent **q)
+{
+    return strcmp((*p)->d_name, (*q)->d_name);
+}
+#endif
+
+#define PROCFS_ENTRY_SIZE 40	/* encompass any size of entry for pid */
+
+#if defined(IS_DARWIN)	/* No procfs on Mac OS X */
+#include <sys/sysctl.h>
+int
+__pmProcessExists(pid_t pid)
+{
+    struct kinfo_proc kp;
+    size_t len = sizeof(kp);
+    int mib[4];
+
+    mib[0] = CTL_KERN;
+    mib[1] = KERN_PROC;
+    mib[2] = KERN_PROC_PID;
+    mib[3] = pid;
+    if (sysctl(mib, 4, &kp, &len, NULL, 0) == -1)
+       return 0;
+    return (len > 0);
+}
+#elif defined(HAVE_PROCFS)
+#define PROCFS			"/proc"
+#define PROCFS_PATH_SIZE	(sizeof(PROCFS)+PROCFS_ENTRY_SIZE)
+int 
+__pmProcessExists(pid_t pid)
+{
+    char proc_buf[PROCFS_PATH_SIZE];
+    snprintf(proc_buf, sizeof(proc_buf), "%s/%d", PROCFS, (int)pid);
+    return (access(proc_buf, F_OK) == 0);
+}
+#elif !defined(IS_MINGW)
+!bozo!
+#endif
+
+#if defined(HAVE_KILL)
+int
+__pmProcessTerminate(pid_t pid, int force)
+{
+    return kill(pid, force ? SIGKILL : SIGTERM);
+}
+#elif !defined(IS_MINGW)
+!bozo!
+#endif
+
+#if defined(HAVE_SBRK)
+int
+__pmProcessDataSize(unsigned long *size)
+{
+    static void *base;
+
+    if (size && base)
+	*size = (sbrk(0) - base) / 1024;
+    else {
+	base = sbrk(0);
+	if (size)
+	    *size = 0;
+    }
+    return 0;
+}
+#elif !defined(IS_MINGW)
+#warning "Platform does not define a process datasize interface?"
+int __pmProcessDataSize(unsigned long *) { return -1; }
+#endif
+
+#if !defined(IS_MINGW)
+int
+__pmProcessRunTimes(double *usr, double *sys)
+{
+    struct tms tms;
+    double ticks = (double)sysconf(_SC_CLK_TCK);
+
+    if (times(&tms) == (clock_t)-1) {
+	*usr = *sys = 0.0;
+	return -1;
+    }
+    *usr = (double)tms.tms_utime / ticks;
+    *sys = (double)tms.tms_stime / ticks;
+    return 0;
+}
+#endif
+
+#if !defined(IS_MINGW)
+int
+__pmProcessCreate(char **argv, int *infd, int *outfd)
+{
+    int		in[2];
+    int		out[2];
+    pid_t	pid;
+
+    pipe(in);
+    pipe(out);
+
+    pid = fork();
+    if (pid < 0) {
+	return -1;
+    }
+    else if (pid) {
+	/* parent */
+	close(in[0]);
+	close(out[1]);
+	*infd = out[0];
+	*outfd = in[1];
+    }
+    else {
+	/* child */
+	close(in[1]);
+	close(out[0]);
+	if (in[0] != 0) {
+	    close(0);
+	    dup2(in[0], 0);
+	    close(in[0]);
+	}
+	if (out[1] != 1) {
+	    close(1);
+	    dup2(out[1], 1);
+	    close(out[1]);
+	}
+	execvp(argv[0], argv);
+	fprintf(stderr, "execvp: %s\n", strerror(errno));
+	exit(1);
+    }
+    return 0;
+}
+#endif
