@@ -19,13 +19,8 @@
  * You should have received a copy of the GNU Lesser General Public License
  * along with this library; if not, write to the Free Software Foundation,
  * Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA.
- * 
- * Contact information: Silicon Graphics, Inc., 1500 Crittenden Lane,
- * Mountain View, CA 94043, USA, or: http://www.sgi.com
  */
 
-#ident "$Id: Bool.h,v 1.2 2005/05/10 00:46:37 kenmcd Exp $"
-
 enum PMC_Bool { PMC_false = 0, PMC_true = 1 };
 
 #endif /* _PMC_DESC_H_ */
