@@ -19,13 +19,8 @@
  * You should have received a copy of the GNU Lesser General Public License
  * along with this library; if not, write to the Free Software Foundation,
  * Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA.
- * 
- * Contact information: Silicon Graphics, Inc., 1500 Crittenden Lane,
- * Mountain View, CA 94043, USA, or: http://www.sgi.com
  */
 
-#ident "$Id: PMC.h,v 1.3 2006/05/18 06:48:48 makc Exp $"
-
 #ifndef PCP_DEBUG
 #ifndef NDEBUG
 #define NDEBUG
