@@ -14,25 +14,14 @@
  * You should have received a copy of the GNU Lesser General Public License
  * along with this library; if not, write to the Free Software Foundation,
  * Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA.
- * 
- * Contact information: Silicon Graphics, Inc., 1500 Crittenden Lane,
- * Mountain View, CA 94043, USA, or: http://www.sgi.com
  */
 
-#ident "$Id: cache.c,v 1.7 2005/08/31 01:50:24 kenmcd Exp $"
-
-#include <stdio.h>
-#include <sys/types.h>
-#include <sys/times.h>
-#include <sys/stat.h>
-#include <string.h>
-#include <errno.h>
-#include <syslog.h>
-#include <fcntl.h>
-#include <ctype.h>
 #include "pmapi.h"
 #include "impl.h"
 #include "pmda.h"
+#include <fcntl.h>
+#include <ctype.h>
+#include <sys/stat.h>
 
 static __uint32_t hash(char *, int, __uint32_t);
 
@@ -78,7 +67,7 @@ typedef struct hdr {
 static hdr_t	*base;		/* start of cache headers */
 static char 	filename[MAXPATHLEN];
 				/* for load/save ops */
-static char	*vdp = NULL;	/* first trip mkdir for load/save */
+static char	*vdp;		/* first trip mkdir for load/save */
 
 /*
  * count character to end of string or first space, whichever comes
@@ -628,7 +617,7 @@ load_cache(hdr_t *h)
     if (vdp == NULL) {
 	vdp = pmGetConfig("PCP_VAR_DIR");
 	snprintf (filename, sizeof(filename), "%s/config/pmda", vdp);
-	mkdir(filename, 0755);
+	mkdir2(filename, 0755);
     }
 
     snprintf (filename, sizeof(filename), "%s/config/pmda/%s", vdp, pmInDomStr(h->indom));
@@ -710,7 +699,7 @@ save_cache(hdr_t *h, int hstate)
     if (vdp == NULL) {
 	vdp = pmGetConfig("PCP_VAR_DIR");
 	snprintf (filename, sizeof(filename), "%s/config/pmda", vdp);
-	mkdir(filename, 0755);
+	mkdir2(filename, 0755);
     }
 
     snprintf (filename, sizeof(filename), "%s/config/pmda/%s", vdp, pmInDomStr(h->indom));
@@ -934,8 +923,6 @@ int pmdaCacheOp(pmInDom indom, int op)
 	default:
 	    return -EINVAL;
     }
-
-    /*NOTREACHED*/
 }
 
 int pmdaCacheLookupName(pmInDom indom, char *name, int *inst, void **private)
@@ -1012,16 +999,6 @@ int pmdaCachePurge(pmInDom indom, time_t recent)
     return cnt;
 }
 
-#if defined(IRIX6_5)
-#pragma optional __pmdaCacheDumpAll
-#pragma optional __pmdaCacheDump
-#pragma optional pmdaCacheStore
-#pragma optional pmdaCacheLookup
-#pragma optional pmdaCacheLookupName
-#pragma optional pmdaCacheOp
-#pragma optional pmdaCachePurge
-#endif
-
 /*
 --------------------------------------------------------------------
 lookup2.c, by Bob Jenkins, December 1996, Public Domain.
