@@ -14,21 +14,12 @@
  * You should have received a copy of the GNU Lesser General Public License
  * along with this library; if not, write to the Free Software Foundation,
  * Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA.
- * 
- * Contact information: Silicon Graphics, Inc., 1500 Crittenden Lane,
- * Mountain View, CA 94043, USA, or: http://www.sgi.com
  */
 
-#ident "$Id: mainloop.c,v 1.8 2006/10/31 06:53:56 kimbrr Exp $"
-
-#include <unistd.h>
-#include <stdio.h>
-#include <stdlib.h>
-#include <syslog.h>
 #include "pmapi.h"
 #include "impl.h"
 #include "pmda.h"
-#include "./libdefs.h"
+#include "libdefs.h"
 
 extern int __pmdaSetupPDU(int, int, char *);
 
@@ -297,21 +288,6 @@ pmdaMain(pmdaInterface *dispatch)
     }
 }
 
-#ifdef IRIX6_5
-/* 
- * This function serves no useful purpose and could be removed.
- * It is left here only to preserve the IRIX 6.5 API 
- */
-/*ARGSUSED*/
-void
-pmdaMainLoopFreeResultCallback(void (*callback)(pmResult *res))
-{
-    __pmNotifyErr(LOG_CRIT, 
-		 "pmdaMainLoopFreeResultCallback() not supported. Use pmdaSetResultCallBack().");
-    exit(1);
-}
-#endif
-
 void
 pmdaSetResultCallBack(pmdaInterface *dispatch, pmdaResultCallBack callback)
 {
