@@ -14,28 +14,21 @@
  * You should have received a copy of the GNU Lesser General Public License
  * along with this library; if not, write to the Free Software Foundation,
  * Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA.
- * 
- * Contact information: Silicon Graphics, Inc., 1500 Crittenden Lane,
- * Mountain View, CA 94043, USA, or: http://www.sgi.com
  */
 
-#ident "$Id: open.c,v 1.5 2004/07/22 07:00:57 kenmcd Exp $"
-
-#include <stdio.h>
-#include <sys/types.h>
-#include <sys/socket.h>
-#include <netinet/in.h>
-#include <netinet/tcp.h>
-#include <sys/un.h>
-#include <netdb.h>
-#include <string.h>
-#include <errno.h>
-#include <syslog.h>
-#include <fcntl.h>
 #include "pmapi.h"
 #include "impl.h"
 #include "pmda.h"
-#include "./libdefs.h"
+#include "libdefs.h"
+#ifdef HAVE_SYS_UN_H
+#include <sys/un.h>
+#endif
+#ifdef HAVE_NETINET_IN_H
+#include <netinet/in.h>
+#endif
+#ifdef HAVE_NETINET_TCP_H
+#include <netinet/tcp.h>
+#endif
 
 /*
  * Open an inet port to PMCD
@@ -44,12 +37,11 @@
 void
 __pmdaOpenInet(char *sockname, int myport, int *infd, int *outfd)
 {
-    int			i, sts;
+    int			sts;
     int			sfd;
     struct sockaddr_in	myaddr;
     struct sockaddr_in	from;
     struct servent	*service;
-    struct linger	nolinger = {1, 0};
     mysocklen_t		addrlen;
     int			one = 1;
 
@@ -63,21 +55,11 @@ __pmdaOpenInet(char *sockname, int myport, int *infd, int *outfd)
 	myport = service->s_port;
     }
 
-    sfd = socket(AF_INET, SOCK_STREAM, 0);
+    sfd = __pmCreateSocket();
     if (sfd < 0) {
 	__pmNotifyErr(LOG_CRIT, "__pmdaOpenInet: inet socket: %s\n", strerror(errno));
 	exit(1);
     }
-    i = 1;
-    if (setsockopt(sfd, IPPROTO_TCP, TCP_NODELAY, (char *) &i, (mysocklen_t)sizeof(i)) < 0) {
-	__pmNotifyErr(LOG_CRIT, "__pmdaOpenInet: setsockopt(nodelay): %s\n", strerror(errno));
-	exit(1);
-    }
-    if (setsockopt(sfd, SOL_SOCKET, SO_LINGER,
-		   (char *) &nolinger, (mysocklen_t)sizeof(nolinger)) < 0) {
-	__pmNotifyErr(LOG_CRIT, "__pmdaOpenInet: setsockopt(nolinger): %s\n", strerror(errno));
-	exit(1);
-    }
     /*
      * allow port to be quickly re-used, e.g. when Install and PMDA already
      * installed, this becomes terminate and restart in a hurry ...
@@ -107,10 +89,11 @@ __pmdaOpenInet(char *sockname, int myport, int *infd, int *outfd)
 	__pmNotifyErr(LOG_CRIT, "__pmdaOpenInet: inet accept: %s\n", strerror(errno));
 	exit(1);
     }
-    close(sfd);
+    __pmCloseSocket(sfd);
     *outfd = *infd;
 }
 
+#if !defined(IS_MINGW)
 /*
  * Open a unix port to PMCD
  */
@@ -172,6 +155,15 @@ __pmdaOpenUnix(char *sockname, int *infd, int *outfd)
     *outfd = *infd;
 }
 
+#else	/* MINGW */
+void
+__pmdaOpenUnix(char *sockname, int *infd, int *outfd)
+{
+    __pmNotifyErr(LOG_CRIT, "__pmdaOpenUnix: Not supported on Windows");
+    exit(1);
+}
+#endif
+
 /*
  * capture PMDA args from getopts 
  */
@@ -457,8 +449,8 @@ __pmdaSetupPDU(int infd, int outfd, char *agentname)
     __pmCred	handshake[1];
     __pmCred	*credlist = NULL;
     __pmPDU	*pb;
-    __pmIPC	ipc = { UNKNOWN_VERSION, NULL };
-    int		i, sts, credcount=0, sender=0, vflag=0;
+    int		i, sts, vflag = 0;
+    int		version = UNKNOWN_VERSION, credcount = 0, sender = 0;
 
     handshake[0].c_type = CVERSION;
     handshake[0].c_vala = PDU_VERSION;
@@ -483,7 +475,7 @@ __pmdaSetupPDU(int infd, int outfd, char *agentname)
 	for (i = 0; i < credcount; i++) {
 	    switch (credlist[i].c_type) {
 	    case CVERSION:
-		ipc.version = credlist[i].c_vala;
+		version = credlist[i].c_vala;
 		vflag = 1;
 		break;
 	    default:
@@ -491,9 +483,8 @@ __pmdaSetupPDU(int infd, int outfd, char *agentname)
 	    }
 	}
 	if (vflag) {
-	    __pmAddIPC(infd, ipc);
-	    if (outfd != infd)
-		__pmAddIPC(outfd, ipc);
+	    __pmSetVersionIPC(infd, version);
+	    __pmSetVersionIPC(outfd, version);
 	}
 	if (credlist != NULL)
 	    free(credlist);
@@ -501,7 +492,7 @@ __pmdaSetupPDU(int infd, int outfd, char *agentname)
     else
 	__pmNotifyErr(LOG_CRIT, "__pmdaSetupPDU: PMDA %s: version exchange failure\n", agentname);
 
-    return ipc.version;
+    return version;
 }
 
 /* 
@@ -582,14 +573,14 @@ pmdaConnect(pmdaInterface *dispatch)
  */
 
 void
-__pmdaSetup(pmdaInterface *dispatch, int interface, char *name)
+__pmdaSetup(pmdaInterface *dispatch, int version, char *name)
 {
     pmdaExt	*pmda = NULL;
     e_ext_t	*extp;
 
-    if (!HAVE_V_TWO(interface)) {
+    if (!HAVE_V_TWO(version)) {
 	__pmNotifyErr(LOG_CRIT, "__pmdaSetup: %s PMDA: interface version %d not supported (domain=%d)",
-		     name, interface, dispatch->domain);
+		     name, version, dispatch->domain);
 	dispatch->status = PM_ERR_GENERIC;
 	return;
     }
@@ -605,7 +596,7 @@ __pmdaSetup(pmdaInterface *dispatch, int interface, char *name)
 
     dispatch->status = 0;
 
-    dispatch->comm.pmda_interface = interface;
+    dispatch->comm.pmda_interface = version;
     dispatch->comm.pmapi_version = PMAPI_VERSION;
     dispatch->comm.flags = 0;
 
@@ -649,7 +640,7 @@ __pmdaSetup(pmdaInterface *dispatch, int interface, char *name)
 	dispatch->status = PM_ERR_GENERIC;
 	return;
     }
-    extp->pmda_interface = interface;
+    extp->pmda_interface = version;
     extp->res = NULL;
     extp->maxnpmids = 0;
     pmda->e_ext = (void *)extp;
@@ -666,13 +657,13 @@ __pmdaSetup(pmdaInterface *dispatch, int interface, char *name)
  */
 
 void
-pmdaDaemon(pmdaInterface *dispatch, int interface, char *name, int domain, 
+pmdaDaemon(pmdaInterface *dispatch, int version, char *name, int domain, 
 	   char *logfile, char *helptext)
 {
     pmdaExt	*pmda = NULL;
 
     dispatch->domain = domain;
-    __pmdaSetup(dispatch, interface, name);
+    __pmdaSetup(dispatch, version, name);
 
     if (dispatch->status < 0)
 	return;
@@ -690,9 +681,9 @@ pmdaDaemon(pmdaInterface *dispatch, int interface, char *name, int domain,
  */
 
 void
-pmdaDSO(pmdaInterface *dispatch, int interface, char *name, char *helptext)
+pmdaDSO(pmdaInterface *dispatch, int version, char *name, char *helptext)
 {
-    __pmdaSetup(dispatch, interface, name);
+    __pmdaSetup(dispatch, version, name);
 
     if (dispatch->status < 0)
 	return;
