@@ -1,5 +1,4 @@
 #! /bin/sh
-#Tag 0x00010D14
 # 
 # Copyright (c) 1997,2003 Silicon Graphics, Inc.  All Rights Reserved.
 # 
@@ -17,16 +16,11 @@
 # with this program; if not, write to the Free Software Foundation, Inc.,
 # 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 # 
-# Contact information: Silicon Graphics, Inc., 1500 Crittenden Lane,
-# Mountain View, CA 94043, USA, or: http://www.sgi.com
-# 
-# $Id: pcp.sh,v 1.24 2003/02/20 05:28:13 kenmcd Exp $
-#
 # displays the Performance Co-Pilot configuration for a host running pmcd(1)
 #
 
 # Get standard environment
-. /etc/pcp.env
+. $PCP_DIR/etc/pcp.env
 
 sts=2
 tmp=/tmp/$$
@@ -42,7 +36,7 @@ do
 done
 
 # metrics
-metrics="pmcd.numagents pmcd.numclients pmcd.simabi pmcd.version pmcd.build pmcd.license pmcd.timezone pmcd.agent.status pmcd.pmlogger.archive pmcd.pmlogger.pmcd_host hinv.ncpu hinv.ndisk hinv.nnode hinv.nrouter hinv.nxbow hinv.ncell hinv.physmem hinv.cputype pmda.uname pmcd.pmie.pmcd_host pmcd.pmie.configfile pmcd.pmie.numrules pmcd.pmie.logfile"
+metrics="pmcd.numagents pmcd.numclients pmcd.simabi pmcd.version pmcd.build pmcd.timezone pmcd.agent.status pmcd.pmlogger.archive pmcd.pmlogger.pmcd_host hinv.ncpu hinv.ndisk hinv.nnode hinv.nrouter hinv.nxbow hinv.ncell hinv.physmem hinv.cputype pmda.uname pmcd.pmie.pmcd_host pmcd.pmie.configfile pmcd.pmie.numrules pmcd.pmie.logfile"
 pmiemetrics="pmcd.pmie.actions pmcd.pmie.eval.true pmcd.pmie.eval.false pmcd.pmie.eval.unknown pmcd.pmie.eval.expected"
 
 _usage()
@@ -192,7 +186,6 @@ mode == 3		{ inst(); next }
 /pmcd.numclients/	{ mode = 1; quote="numclients"; next }
 /pmcd.simabi/		{ mode = 1; quote="simabi"; next }
 /pmcd.timezone/		{ mode = 1; quote="timezone"; next }
-/pmcd.license/		{ mode = 1; quote="license"; next }
 /pmcd.agent.status/	{ mode = 2; count = 0; quote="status"; next }
 /pmcd.pmlogger.archive/	{ mode = 3; count = 0; quote="log_archive"; next }
 /pmcd.pmlogger.pmcd_host/ { mode = 3; count = 0; quote="log_host"; next }
@@ -364,20 +357,6 @@ echo " platform: ${uname}$simabi"
 echo " hardware: "`echo $hardware | _fmt`
 echo " timezone: $timezone"
 
-$PCP_ECHO_PROG $PCP_ECHO_N " licenses: ""$PCP_ECHO_C"
-if [ "$license" = $unknown ]
-then
-    echo "unknown"
-elif [ "$license" -eq 0 ]
-then
-    echo "none"
-else
-    [ `expr $license %  2` -gt 0 ] && collector="Collector"
-    [ `expr $license %  4` -gt 1 ] && monitor="Monitor"
-    [ `expr $license % 16` -gt 4 ] && webmeter="WebMeter"
-    echo $collector $monitor $webmeter
-fi
-
 echo "     pmcd: ${version},${numagents}$numclients"
 
 [ -n "$agents" ] && echo "     pmda: $agents"
