@@ -1,8 +1,8 @@
 # Common sh(1) procedures to be used in the Performance Co-Pilot
 # PMDA Install and Remove scripts
 #
-# $Id: pmdaproc.sh,v 1.17 2006/06/30 05:47:11 makc Exp $
 # Copyright (c) 1995-2001,2003 Silicon Graphics, Inc.  All Rights Reserved.
+# Portions Copyright (c) 2008 Aconex.  All Rights Reserved.
 # 
 # This program is free software; you can redistribute it and/or modify it
 # under the terms of the GNU General Public License as published by the
@@ -17,12 +17,9 @@
 # You should have received a copy of the GNU General Public License along
 # with this program; if not, write to the Free Software Foundation, Inc.,
 # 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
-# 
-# Contact information: Silicon Graphics, Inc., 1500 Crittenden Lane,
-# Mountain View, CA 94043, USA, or: http://www.sgi.com
 
 # source the PCP configuration environment variables
-. /etc/pcp.env
+. $PCP_DIR/etc/pcp.env
 
 tmp=/var/tmp/$$
 trap "rm -f $tmp; exit" 0 1 2 3 15
@@ -73,7 +70,7 @@ rm -f $tmp
 
 # chown/chmod is not always helpful
 #
-if [ "$PCP_PLATFORM" = cygwin -o "$PCP_PLATFORM" = interix ]
+if [ "$PCP_PLATFORM" = cygwin -o "$PCP_PLATFORM" = mingw ]
 then
     CHOWN=": skip chown"
     CHMOD=chmod
@@ -109,13 +106,6 @@ fi
 NAMESPACE=${PMNS_DEFAULT-$PMNSDIR/root}
 PMNSROOT=`basename $NAMESPACE`
 
-# install your DSO PMDAs here
-DSOPMDADIR=/var/pcp/lib
-[ "$PCP_PLATFORM" = linux ] && DSOPMDADIR=$PCP_PMDAS_DIR
-
-# install your daemon PMDAs here
-PMDADIR=$PCP_PMDAS_DIR
-
 # echo without newline - deprecated - use the $PCP_ECHO_* ones from
 # /etc/pcp.conf instead, however some old Install and Remove scripts may
 # still use $ECHONL, so keep it here
@@ -125,6 +115,8 @@ ECHONL="echo -n"
 # Install control variables
 #	Can install as DSO?
 dso_opt=false
+#	Can install as perl script?
+perl_opt=false
 #	Can install as daemon?
 daemon_opt=true
 #	If daemon, pipe?
@@ -764,10 +756,33 @@ END		{ if (warn) printf "%d warnings, ",warn
 
 _setup()
 {
+    # some more configuration controls
+    pmns_name=${pmns_name-$iam}
+    pmda_name=pmda$iam
+    dso_suffix=so
+    [ "$PCP_PLATFORM" = darwin ] && dso_suffix=dylib
+    [ "$PCP_PLATFORM" = cygwin -o "$PCP_PLATFORM" = mingw ] && dso_suffix=dll
+    dso_name="${PCP_PMDAS_DIR}/${iam}/pmda_${iam}.${dso_suffix}"
+    dso_entry=${iam}_init
+    pmda_dir="${PCP_PMDAS_DIR}/${iam}"
+
     # check the user is root 
     #
     _check_userroot
 
+    # automatically generate files for those lazy Perl programmers
+    #
+    if $perl_opt
+    then
+	perl_name="${PCP_PMDAS_DIR}/${iam}/pmda${iam}.pl"
+	perl_pmns="${PCP_PMDAS_DIR}/${iam}/pmns"
+	perl_dom="${PCP_PMDAS_DIR}/${iam}/domain.h"
+	test -s "$perl_dom" || \
+		eval PCP_PERL_DOMAIN=1 perl "$perl_name" > "$perl_dom"
+	test -s "$perl_pmns" || \
+		eval PCP_PERL_PMNS=1 perl "$perl_name" > "$perl_pmns"
+    fi
+
     # Set $domain and $SYMDOM from domain.h
     #
     __check_domain
@@ -782,28 +797,16 @@ _setup()
 	    __choose_mode
 	    ;;
     esac
-
-    # some more configuration controls
-    pmns_name=${pmns_name-$iam}
-    pmda_name=pmda$iam
-    if [ "$PCP_PLATFORM" = linux ]
-    then
-	dso_name=${DSOPMDADIR}/${iam}/pmda_${iam}.so
-    else
-	dso_name=pmda_${iam}.so
-    fi
-    dso_entry=${iam}_init
-    pmda_dir=$PMDADIR/$iam
 }
 
 # Configurable PMDA installation
 #
 # before calling _install,
 # 1. set $iam
-# 2. set one or both of $dso_opt or $daemon_opt true (optional, $daemon_opt
-#    is true by default)
-# 3. if $dso_opt set one or both of $pipe_opt or $socket_opt true (optional,
-#    $pipe_opt is true by default)
+# 2. set one/some/all of $dso_opt, $perl_opt, or $daemon_opt to true
+#    (optional, $daemon_opt is true by default)
+# 3. if $daemon_opt set one or both of $pipe_opt or $socket_opt true
+#    (optional, $pipe_opt is true by default)
 # 4. if $socket_opt and there is an default Internet socket, set
 #    $socket_inet_def
 
@@ -811,17 +814,17 @@ _install()
 {
     if [ -z "$iam" ]
     then
-	echo 'Botch: must define $iam before calling _install_preamble()'
+	echo 'Botch: must define $iam before calling _install()'
 	exit 1
     fi
 
     if $do_pmda
     then
-	if $dso_opt || $daemon_opt
+	if $dso_opt || $perl_opt || $daemon_opt
 	then
 	    :
 	else
-	    echo 'Botch: must set at least one of $dso_opt or $daemon_opt to "true"'
+	    echo 'Botch: must set at least one of $dso_opt, $perl_opt or $daemon_opt to "true"'
 	    exit 1
 	fi
 	if $daemon_opt
@@ -904,9 +907,15 @@ _install()
         cd $__here
     done
 
+    trap "rm -f $tmp $tmp.*; exit" 0 1 2 3 15
+    $PCP_SHARE_DIR/lib/unlockpmns $NAMESPACE
+
     if [ -d $PCP_VAR_DIR/config/pmchart ]
     then
-	echo "Installing pmchart view(s) ..."
+	if [ `echo *.pmchart` != "*.pmchart" ]
+	then
+	    echo "Installing pmchart view(s) ..."
+	fi
 	for __i in *.pmchart
 	do
 	    if [ "$__i" != "*.pmchart" ]
@@ -920,31 +929,81 @@ _install()
 	echo "Skip installing pmchart view(s) ... no \"$PCP_VAR_DIR/config/pmchart\" directory"
     fi
 
-    # Prompt for command line arguments to the PMDA
-    #
+    if [ -d $PCP_VAR_DIR/config/kmchart ]
+    then
+	if [ `echo *.kmchart` != "*.kmchart" ]
+	then
+	    echo "Installing kmchart view(s) ..."
+	fi
+	for __i in *.kmchart
+	do
+	    if [ "$__i" != "*.kmchart" ]
+	    then
+		__dest=$PCP_VAR_DIR/config/kmchart/`basename $__i .kmchart`
+		rm -f $__dest
+		cp $__i $__dest
+	    fi
+	done
+    else
+	echo "Skip installing kmchart view(s) ... no \"$PCP_VAR_DIR/config/kmchart\" directory"
+    fi
+
     if $do_pmda
     then
-	# Select an IPC method for communication between PMCD and PMDA
+	# Select a PMDA style (dso/perl/deamon), and for daemons the
+	# IPC method for communication between PMCD and the PMDA.
 	#
-	pmda_type=''
-	$dso_opt && pmda_type=dso
-	$daemon_opt && pmda_type=daemon
-	$dso_opt && $daemon_opt && pmda_type=''
-	if [ -z "$pmda_type" ]
-        then
+	pmda_options=''
+	pmda_default_option=''
+	pmda_multiple_options=false
+
+	if $dso_opt
+	then
+	    pmda_options="dso"
+	    pmda_default_option="dso"
+	fi
+	if $perl_opt
+	then
+	    pmda_default_option="perl"
+	    if test -n "$pmda_options"
+	    then
+		pmda_options="perl or $pmda_options"
+		pmda_multiple_options=true
+	    else
+		pmda_options="perl"
+	    fi
+	fi
+	if $daemon_opt
+	then
+	    pmda_default_option="daemon"
+	    if test -n "$pmda_options"
+	    then
+		pmda_options="daemon or $pmda_options"
+		pmda_multiple_options=true
+	    else
+		pmda_options="daemon"
+	    fi
+	fi
+
+	pmda_type="$pmda_default_option"
+	if $pmda_multiple_options
+	then
 	    while true
 	    do
-		$PCP_ECHO_PROG $PCP_ECHO_N "Install $iam as a daemon or dso agent? [daemon] ""$PCP_ECHO_C"
+		$PCP_ECHO_PROG $PCP_ECHO_N "Install $iam as a $pmda_options agent? [$pmda_default_option] ""$PCP_ECHO_C"
 		read pmda_type
 		if [ "X$pmda_type" = Xdaemon -o "X$pmda_type" = X ]
 		then
 		    pmda_type=daemon
 		    break
 		elif [ "X$pmda_type" = Xdso ]
+		then
+		    break
+		elif [ "X$pmda_type" = Xperl ]
 		then
 		    break
 		else
-		    echo "Must choose one of \"daemon\" or \"dso\", please try again"
+		    echo "Must choose one of $pmda_options, please try again"
 		fi
 	    done
 	fi
@@ -952,6 +1011,10 @@ _install()
 	then
 	    __choose_ipc $pmda_dir
 	    args="-d $domain $args"
+	elif [ "$pmda_type" = perl ]
+	then
+	    type="pipe	binary		perl $perl_name"
+	    args=""
 	else
 	    type="dso	$dso_entry	$dso_name"
 	    args=""
@@ -1011,9 +1074,6 @@ _install()
     else
 	echo "Skipping PMDA install and PMCD re-configuration"
     fi
-
-    trap "rm -f $tmp $tmp.*; exit" 0 1 2 3 15
-    $PCP_SHARE_DIR/lib/unlockpmns $NAMESPACE
 }
 
 _remove()
@@ -1072,6 +1132,14 @@ _remove()
 		rm -f $__dest
 	    fi
 	done
+	for __i in *.kmchart
+	do
+	    if [ "$__i" != "*.kmchart" ]
+	    then
+		__dest=$PCP_VAR_DIR/config/kmchart/`basename $__i .kmchart`
+		rm -f $__dest
+	    fi
+	done
 
 	if $do_check
 	then
@@ -1099,7 +1167,7 @@ _check_userroot()
 {
     case "$PCP_PLATFORM"
     in
-	cygwin|interix)
+	cygwin|mingw)
 	    # nothing we can usefully do here, skip the test
 	    #
 	    ;;
