@@ -17,12 +17,9 @@
 # with this program; if not, write to the Free Software Foundation, Inc.,
 # 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 # 
-# Contact information: Silicon Graphics, Inc., 1500 Crittenden Lane,
-# Mountain View, CA 94043, USA, or: http://www.sgi.com
-# 
 
 # source the PCP configuration environment variables
-. /etc/pcp.env
+. $PCP_DIR/etc/pcp.env
 
 # These functions use chkconfig if available, else tolerate missing chkconfig
 # command (as on SUSE) by manipulating symlinks in /etc/rc.d directly.
@@ -139,7 +136,7 @@ is_chkconfig_on()
     _cmds_exist $_flag
     $_have_runlevel && _rl=`runlevel | $PCP_AWK_PROG '{print $2}'`
 
-    if [ "$PCP_PLATFORM" = cygwin -o "$PCP_PLATFORM" = interix ]
+    if [ "$PCP_PLATFORM" = cygwin -o "$PCP_PLATFORM" = mingw ]
     then
 	# no chkconfig, just do it
 	#
@@ -195,7 +192,7 @@ chkconfig_on()
     _cmds_exist $_flag
     $_have_flag || return 1 # fail
 
-    if [ "$PCP_PLATFORM" = cygwin -o "$PCP_PLATFORM" = interix ]
+    if [ "$PCP_PLATFORM" = cygwin -o "$PCP_PLATFORM" = mingw ]
     then
 	# no chkconfig, just pretend
 	#
@@ -248,7 +245,7 @@ chkconfig_off()
     _cmds_exist $_flag
     $_have_flag || return 1 # fail
 
-    if [ "$PCP_PLATFORM" = cygwin -o "$PCP_PLATFORM" = interix ]
+    if [ "$PCP_PLATFORM" = cygwin -o "$PCP_PLATFORM" = mingw ]
     then
 	# no chkconfig, just pretend
 	#
@@ -283,7 +280,7 @@ chkconfig_on_msg()
     _cmds_exist $_flag
     $_have_flag || return 1 # fail
 
-    if [ "$PCP_PLATFORM" = cygwin -o "$PCP_PLATFORM" = interix ]
+    if [ "$PCP_PLATFORM" = cygwin -o "$PCP_PLATFORM" = mingw ]
     then
 	# no chkconfig, just pretend
 	#
