@@ -14,70 +14,31 @@
  * You should have received a copy of the GNU General Public License along
  * with this program; if not, write to the Free Software Foundation, Inc.,
  * 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
- * 
- * Contact information: Silicon Graphics, Inc., 1500 Crittenden Lane,
- * Mountain View, CA 94043, USA, or: http://www.sgi.com
  *
  * PMCD routines for reading config file, creating children and
  * attaching to DSOs.
  */
 
-#ident "$Id: config.c,v 1.15 2007/01/16 06:50:10 kimbrr Exp $"
-
-#include <stdio.h>
-#include <string.h>
-#include <ctype.h>
-#include <stdlib.h>
-#include <sys/types.h>
-#include <sys/socket.h>
-#include <sys/types.h>
-#include <sys/param.h>
-#include <sys/stat.h>
-#include <netdb.h>
-#include <netinet/in.h>
-#include <netinet/tcp.h>
-#include <sys/un.h>
-#include <unistd.h>
-#include <syslog.h>
-#include <fcntl.h>
-#include <errno.h>
-
-#include <sys/wait.h>
-
-#if defined(sgi)
-#include <sgidefs.h>
-#include <rld_interface.h>
-#endif
-
-#include "pmapi.h"
-
-/*
- * INCLUDE_STATIC_DSO_AGENTS controls the support for a "DSO" PMDA that
- * is actually linked into the pmcd binary ... this might be needed if
- * the support for dynamic shared libraries, in particular dlopen() or
- * equivalent, is weak or missing.
- */
-#if defined(sgi)
-#define INCLUDE_STATIC_DSO_AGENTS 1
-#else
-#define INCLUDE_STATIC_DSO_AGENTS 0
-#endif
-
 #include "pmapi.h"
 #include "impl.h"
 #include "pmcd.h"
-
+#include <ctype.h>
+#include <sys/stat.h>
+#if defined(HAVE_SYS_WAIT_H)
+#include <sys/wait.h>
+#endif
+#if defined(HAVE_SYS_UN_H)
+#include <sys/un.h>
+#endif
 #if defined(HAVE_DLFCN_H)
 #include <dlfcn.h>
 #elif defined(HAVE_DL_H)
 #include <dl.h>
 #endif
 
-
 #define MIN_AGENTS_ALLOC	3	/* Number to allocate first time */
 #define LINEBUF_SIZE 200
 
-extern int	errno;
 extern int	_creds_timeout;
 
 /* Config file modification time */
@@ -174,7 +135,6 @@ GetNextLine(void)
 	linebuf = (char *)malloc(szLineBuf);
 	if (linebuf == NULL)
 	    __pmNoMem("pmcd config: GetNextLine init", szLineBuf, PM_FATAL_ERR);
-	/* NOTREACHED */
     }
 
     linebuf[0] = '\0';
@@ -587,10 +547,6 @@ GetNewAgent(void)
 	    perror("GetNewAgentIndex: malloc");
 	    exit(1);
 	}
-#ifdef MALLOC_AUDIT
-	_persistent_(agent);
-#endif
-
 	szAgents = MIN_AGENTS_ALLOC;
     }
     else if (nAgents >= szAgents) {
@@ -685,7 +641,6 @@ ParseDso(char *pmDomainLabel, int pmDomainId)
 			 "pmcd config: line %d, couldn't copy DSO entry point\n",
 			 nLines);
 	    __pmNoMem("pmcd config", tokenend - token + 1, PM_FATAL_ERR);
-	    /* NOTREACHED */
 	}
 
     FindNextToken();
@@ -699,7 +654,6 @@ ParseDso(char *pmDomainLabel, int pmDomainId)
 		     "pmcd config: line %d, couldn't copy DSO pathname\n",
 		     nLines);
 	__pmNoMem("pmcd config", tokenend - token + 1, PM_FATAL_ERR);
-	/* NOTREACHED */
     }
 
 #ifdef __host_mips
@@ -717,7 +671,6 @@ ParseDso(char *pmDomainLabel, int pmDomainId)
 			 "pmcd config: line %d, couldn't construct DSO pathname\n",
 			 nLines);
 	    __pmNoMem("pmcd config", need, PM_FATAL_ERR);
-	    /* NOTREACHED */
 	}
 	strcpy(newPath, dsoPrefix);
 	strcat(newPath, pathName);
@@ -756,12 +709,6 @@ ParseDso(char *pmDomainLabel, int pmDomainId)
     newAgent->ipc.dso.xlatePath = xlatePath;
     newAgent->ipc.dso.entryPoint = entryPoint;
 
-#ifdef MALLOC_AUDIT
-    _persistent_(pmDomainLabel);
-    _persistent_(pathName);
-    _persistent_(entryPoint);
-#endif
-
     return 0;
 }
 
@@ -800,7 +747,6 @@ ParseSocket(char *pmDomainLabel, int pmDomainId)
 	    fprintf(stderr, "pmcd: line %d, couldn't copy port name\n",
 			 nLines);
 	    __pmNoMem("pmcd config", tokenend - token + 1, PM_FATAL_ERR);
-	    /* NOTREACHED */
 	}
     FindNextToken();
 
@@ -847,18 +793,6 @@ ParseSocket(char *pmDomainLabel, int pmDomainId)
     }
     newAgent->ipc.socket.agentPid = (pid_t) -1;
 
-#ifdef MALLOC_AUDIT
-    _persistent_(pmDomainLabel);
-    if (socketName != NULL) _persistent_(socketName);
-    if (commandLine != NULL) {
-	char	**argv = newAgent->ipc.socket.argv;
-
-	_persistent_(commandLine);
-	for (i = 0; argv[i] != NULL; i++)
-	    _persistent_(argv[i]);
-    }
-#endif
-
     return 0;
 }
 
@@ -916,17 +850,6 @@ ParsePipe(char *pmDomainLabel, int pmDomainId)
     }
     newAgent->ipc.pipe.commandLine = BuildCmdLine(newAgent->ipc.pipe.argv);
 
-#ifdef MALLOC_AUDIT
-    _persistent_(pmDomainLabel);
-    if (commandLine != NULL) {
-	char	**argv = newAgent->ipc.pipe.argv;
-
-	_persistent_(commandLine);
-	for (i = 0; argv[i] != NULL; i++)
-	    _persistent_(argv[i]);
-    }
-#endif
-
     return 0;
 }
 
@@ -1353,8 +1276,8 @@ DoAgentCreds(AgentInfo* aPtr, __pmPDU *pb)
     int			credcount = 0;
     int			sender = 0;
     int			vflag = 0;
+    int			version = UNKNOWN_VERSION;
     __pmCred		*credlist = NULL;
-    __pmIPC		ipc = { UNKNOWN_VERSION, NULL };
 
     if ((sts = __pmDecodeCreds(pb, PDU_BINARY, &sender, &credcount, &credlist)) < 0)
 	return sts;
@@ -1365,7 +1288,7 @@ DoAgentCreds(AgentInfo* aPtr, __pmPDU *pb)
 	switch (credlist[i].c_type) {
 	case CVERSION:
 	    aPtr->pduVersion = credlist[i].c_vala;
-	    ipc.version = credlist[i].c_vala;
+	    version = credlist[i].c_vala;
 	    vflag = 1;
 #ifdef PCP_DEBUG
 	    if (pmDebug & DBG_TRACE_CONTEXT)
@@ -1378,8 +1301,8 @@ DoAgentCreds(AgentInfo* aPtr, __pmPDU *pb)
     if (credlist != NULL)
 	free(credlist);
 
-    if (((sts = __pmAddIPC(aPtr->inFd, ipc)) < 0) ||
-	((sts = __pmAddIPC(aPtr->outFd, ipc)) < 0))
+    if (((sts = __pmSetVersionIPC(aPtr->inFd, version)) < 0) ||
+	((sts = __pmSetVersionIPC(aPtr->outFd, version)) < 0))
 	return sts;
 
     if (vflag) {	/* complete the version exchange - respond to agent */
@@ -1403,8 +1326,8 @@ static int
 AgentNegotiate(AgentInfo *aPtr)
 {
     int		sts;
+    int		version;
     __pmPDU	*ack;
-    __pmIPC	ipc = { UNKNOWN_VERSION, NULL };
 
     if (aPtr->pduProtocol == PDU_BINARY) {
 	sts = __pmGetPDU(aPtr->outFd, PDU_BINARY, _creds_timeout, &ack);
@@ -1439,9 +1362,9 @@ AgentNegotiate(AgentInfo *aPtr)
      * Either (PDU_ASCII _is_ version 1 ONLY), or timed out in PDU exchange
      */
     aPtr->pduVersion = PDU_VERSION1;
-    ipc.version = PDU_VERSION1;
-    if ((sts = __pmAddIPC(aPtr->inFd, ipc)) >= 0)
-	sts = __pmAddIPC(aPtr->outFd, ipc);
+    version = PDU_VERSION1;
+    if ((sts = __pmSetVersionIPC(aPtr->inFd, version)) >= 0)
+	sts = __pmSetVersionIPC(aPtr->outFd, version);
     return sts;
 }
 
@@ -1449,35 +1372,19 @@ AgentNegotiate(AgentInfo *aPtr)
 static int
 ConnectSocketAgent(AgentInfo *aPtr)
 {
-    int		len;
     int		sts = 0;
     int		fd;
 
-    fd = socket(aPtr->ipc.socket.addrDomain, SOCK_STREAM, 0);
-    if (fd < 0) {
-	fprintf(stderr,
-		     "pmcd: Error creating socket for \"%s\" agent : %s\n",
-		     aPtr->pmDomainLabel, strerror(errno));
-	return -1;
-    }
-
     if (aPtr->ipc.socket.addrDomain == AF_INET) {
 	struct sockaddr_in	addr;
 	struct hostent		*hostInfo;
-	int			i;
-	struct linger		noLinger = {1, 0};
 
-	i = 1;
-	if (setsockopt(fd, IPPROTO_TCP, TCP_NODELAY, (char *) &i,
-		(mysocklen_t)sizeof(i)) < 0) {
-	    fprintf(stderr, "ConnectSocketAgent setsockopt(nodelay): %s\n",
-			 strerror(errno));
-	    goto error;
-	}
-	if (setsockopt(fd, SOL_SOCKET, SO_LINGER, (char *) &noLinger, (mysocklen_t)sizeof(noLinger)) < 0) {
-	    fprintf(stderr, "ConnectSocketAgent setsockopt(nolinger): %s\n",
-			 strerror(errno));
-	    goto error;
+	fd = __pmCreateSocket();
+	if (fd < 0) {
+	    fprintf(stderr,
+		     "pmcd: Error creating socket for \"%s\" agent : %s\n",
+		     aPtr->pmDomainLabel, strerror(errno));
+	    return -1;
 	}
 	hostInfo = gethostbyname("localhost");
 	if (hostInfo == NULL) {
@@ -1491,13 +1398,25 @@ ConnectSocketAgent(AgentInfo *aPtr)
 	sts = connect(fd, (struct sockaddr *) &addr, sizeof(addr));
     }
     else {
+#if defined(HAVE_SYS_UN_H)
 	struct sockaddr_un	addr;
+	int			len;
 
+	fd = socket(aPtr->ipc.socket.addrDomain, SOCK_STREAM, 0);
+	if (fd < 0) {
+	    fprintf(stderr,
+		     "pmcd: Error creating socket for \"%s\" agent : %s\n",
+		     aPtr->pmDomainLabel, strerror(errno));
+	    return -1;
+	}
 	memset(&addr, 0, sizeof(addr));
 	addr.sun_family = AF_UNIX;
 	strcpy(addr.sun_path, aPtr->ipc.socket.name);
 	len = (int)sizeof(addr.sun_family) + (int)strlen(addr.sun_path);
 	sts = connect(fd, (struct sockaddr *) &addr, len);
+#else
+	errno = EOPNOTSUPP;
+#endif
     }
     if (sts < 0) {
 	fprintf(stderr, "pmcd: Error connecting to \"%s\" agent : %s\n",
@@ -1516,7 +1435,10 @@ ConnectSocketAgent(AgentInfo *aPtr)
     return 0;
 
 error:
-    close(fd);
+    if (aPtr->ipc.socket.addrDomain == AF_INET)
+	__pmCloseSocket(fd);
+    else
+	close(fd);
     return -1;
 }
 
@@ -1524,7 +1446,9 @@ error:
 static int
 CreateAgent(AgentInfo *aPtr)
 {
+#ifndef IS_MINGW
     int		i;
+#endif
     int		sts;
     int		inPipe[2];	/* Pipe for input to child */
     int		outPipe[2];	/* For output to child */
@@ -1560,8 +1484,14 @@ CreateAgent(AgentInfo *aPtr)
     if (argv != NULL) {			/* Start a new agent if required */
 	fflush(stderr);
 	fflush(stdout);
-	if ((childPid = fork()) == (pid_t) -1) {
-	    fprintf(stderr, "pmcd: fork failed for \"%s\" agent: %s\n",
+
+#ifdef IS_MINGW
+	childPid = __pmProcessCreate(argv, &aPtr->inFd, &aPtr->outFd);
+#else
+	childPid = fork();
+#endif
+	if (childPid == (pid_t)-1) {
+	    fprintf(stderr, "pmcd: creating child for \"%s\" agent: %s\n",
 			 aPtr->pmDomainLabel, strerror(errno));
 	    if (aPtr->ipcType == AGENT_PIPE) {
 		close(inPipe[0]);
@@ -1572,6 +1502,12 @@ CreateAgent(AgentInfo *aPtr)
 	    return -1;
 	}
 
+#ifdef IS_MINGW
+	if (aPtr->ipcType == AGENT_SOCKET) {
+	    close(aPtr->inFd);
+	    close(aPtr->outFd);
+	}
+#else
 	if (childPid) {
 	    /* This is the parent (PMCD) */
 	    if (aPtr->ipcType == AGENT_PIPE) {
@@ -1617,6 +1553,7 @@ CreateAgent(AgentInfo *aPtr)
 	    /* avoid atexit() processing, so _exit not exit */
 	    _exit(1);
 	}
+#endif
 
 	/* Only pmcd (parent) executes this */
 
@@ -1646,8 +1583,7 @@ CreateAgent(AgentInfo *aPtr)
 void
 PrintAgentInfo(FILE *stream)
 {
-    int		i, ver=0;
-    __pmIPC	*ipc = NULL;
+    int		i, version;
     AgentInfo	*aPtr;
 
     fputs("\nactive agent dom   pid  in out ver protocol parameters\n", stream);
@@ -1670,12 +1606,9 @@ PrintAgentInfo(FILE *stream)
 	    break;
 
 	case AGENT_SOCKET:
-	    if (__pmFdLookupIPC(aPtr->inFd, &ipc) < 0)
-		ver = UNKNOWN_VERSION;
-	    else
-		ver = ipc->version;
+	    version = __pmVersionIPC(aPtr->inFd);
 	    fprintf(stream, " %3d %5d %3d %3d %3d ",
-		aPtr->pmDomainId, (int)aPtr->ipc.socket.agentPid, aPtr->inFd, aPtr->outFd, ver);
+		aPtr->pmDomainId, (int)aPtr->ipc.socket.agentPid, aPtr->inFd, aPtr->outFd, version);
 	    fputs("bin ", stream);
 	    fputs("sock ", stream);
 	    if (aPtr->ipc.socket.addrDomain == AF_UNIX)
@@ -1698,12 +1631,9 @@ PrintAgentInfo(FILE *stream)
 	    break;
 
 	case AGENT_PIPE:
-	    if (__pmFdLookupIPC(aPtr->inFd, &ipc) < 0)
-		ver = UNKNOWN_VERSION;
-	    else
-		ver = ipc->version;
+	    version = __pmVersionIPC(aPtr->inFd);
 	    fprintf(stream, " %3d %5d %3d %3d %3d ",
-		aPtr->pmDomainId, (int)aPtr->ipc.pipe.agentPid, aPtr->inFd, aPtr->outFd, ver);
+		aPtr->pmDomainId, (int)aPtr->ipc.pipe.agentPid, aPtr->inFd, aPtr->outFd, version);
 	    if (aPtr->pduProtocol == PDU_BINARY)
 		fputs("bin ", stream);
 	    else
@@ -1723,37 +1653,6 @@ PrintAgentInfo(FILE *stream)
     fflush(stream);			/* Ensure that it appears now */
 }
 
-#if INCLUDE_STATIC_DSO_AGENTS
-/*
- * Like a DSO, but the library is already linked into my address space
- * Warning: this code is only known to work for IRIX, expect some porting
- *	effort to be required elsewhere.
- */
-static int
-GetAgentInline(AgentInfo *aPtr)
-{
-    DsoInfo		*dso = &aPtr->ipc.dso;
-
-    dso->pathName = strdup("-");
-    dso->dlHandle = NULL;
-
-    /* Get a pointer to the DSO's init function and call it to get the agent's
-     dispatch table for the DSO. */
-
-    dso->initFn = (void (*)(pmdaInterface*))_rld_new_interface(_RLD_NAME_TO_ADDR, dso->entryPoint);
-
-    if (dso->initFn == NULL) {
-	fprintf(stderr, "Couldn't find init function `%s' for DSO agent %s in pmcd executable\n",
-		     dso->entryPoint, aPtr->pmDomainLabel);
-	aPtr->status.connected = 0;
-	aPtr->reason = REASON_NOSTART;
-	return -1;
-    }
-	
-    return 0;
-}
-#endif
-
 /* Load the DSO for a specified agent and initialise it. */
 static int
 GetAgentDso(AgentInfo *aPtr)
@@ -1765,18 +1664,7 @@ GetAgentDso(AgentInfo *aPtr)
     aPtr->status.connected = 0;
     aPtr->reason = REASON_NOSTART;
 
-#if INCLUDE_STATIC_DSO_AGENTS
-    if (strcmp(dso->pathName, "-") == 0) {
-	int	sts;
-	sts = GetAgentInline(aPtr);
-	if (sts < 0)
-	    return sts;
-	goto setup;
-    }
-#endif
-
     name = __pmFindPMDA(dso->pathName);
-
     if (name == NULL) {
 	fprintf(stderr, "Cannot find %s DSO at \"%s\"\n", 
 		     aPtr->pmDomainLabel, dso->pathName);
@@ -1790,7 +1678,6 @@ GetAgentDso(AgentInfo *aPtr)
 	dso->pathName = strdup(name);
 	if (dso->pathName == NULL) {
 	    __pmNoMem("pmcd config: pathName", strlen(name), PM_FATAL_ERR);
-	    /* NOTREACHED */
 	}
 	dso->xlatePath = 1;
     }
@@ -1805,14 +1692,11 @@ GetAgentDso(AgentInfo *aPtr)
      * these circumstances.
      */
     dso->dlHandle = dlopen(dso->pathName, RTLD_LAZY);
-#elif defined(HAVE_SHL_LOAD)
-    dso->dlHandle = shl_load(dso->pathName, BIND_IMMEDIATE | DYNAMIC_PATH | BIND_VERBOSE, 0);
 #else
     fprintf(stderr, "Error attaching %s DSO at \"%s\"\n",
 		     aPtr->pmDomainLabel, dso->pathName);
     fprintf(stderr, "No dynamic DSO/DLL support on this platform\n");
     return -1;
-    /* NOTREACHED */
 #endif
 
     if (dso->dlHandle == NULL) {
@@ -1837,18 +1721,8 @@ GetAgentDso(AgentInfo *aPtr)
 	dlclose(dso->dlHandle);
 	return -1;
     }
-#elif defined(HAVE_SHL_LOAD)
-    if (shl_findsym((shl_t *)&dso->dlHandle, dso->entryPoint, TYPE_PROCEDURE, &dso->initFn) != 0) {
-	fprintf(stderr, "Couldn't find init function `%s' in %s DSO\n",
-		     dso->entryPoint, aPtr->pmDomainLabel);
-	shl_unload((shl_t)dso->dlHandle);
-	return -1;
-    }
 #endif
 
-#if INCLUDE_STATIC_DSO_AGENTS
-setup:
-#endif
     /*
      * Pass in the expected domain id.
      * The PMDA initialization routine can (a) ignore it, (b) check it
@@ -1878,8 +1752,6 @@ setup:
 		     pmErrStr(dso->dispatch.status));
 #if defined(HAVE_DLOPEN)
 	    dlclose(dso->dlHandle);
-#elif defined(HAVE_SHL_LOAD)
-	    shl_unload((shl_t)dso->dlHandle);
 #endif
 	    return -1;
     }
@@ -1913,8 +1785,6 @@ setup:
 		 dso->dispatch.comm.pmda_interface, aPtr->pmDomainLabel);
 #if defined(HAVE_DLOPEN)
 	dlclose(dso->dlHandle);
-#elif defined(HAVE_SHL_LOAD)
-	shl_unload((shl_t)dso->dlHandle);
 #endif
 	return -1;
     }
@@ -1929,8 +1799,6 @@ setup:
 		 dso->dispatch.comm.pmapi_version, aPtr->pmDomainLabel);
 #if defined(HAVE_DLOPEN)
 	dlclose(dso->dlHandle);
-#elif defined(HAVE_SHL_LOAD)
-	shl_unload((shl_t)dso->dlHandle);
 #endif
 	return -1;
     }
