@@ -14,26 +14,15 @@
  * You should have received a copy of the GNU General Public License along
  * with this program; if not, write to the Free Software Foundation, Inc.,
  * 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
- * 
- * Contact information: Silicon Graphics, Inc., 1500 Crittenden Lane,
- * Mountain View, CA 94043, USA, or: http://www.sgi.com
  */
 
-#ident "$Id: dofetch.c,v 1.2 2006/05/02 05:57:28 makc Exp $"
-
-#include <syslog.h>
-#include <errno.h>
-#include <string.h>
-#if defined(sgi)
-#include <bstring.h>
-#endif
 #include "pmapi.h"
 #include "impl.h"
 #include "pmcd.h"
 
 /* Freq. histogram: pmids for each agent in current fetch request */
 
-static int	*aFreq = NULL;
+static int	*aFreq;
 
 /* Routine to break a list of pmIDs up into sublists of metrics within the
  * same metric domain.  The resulting lists are returned via a pointer to an
@@ -79,7 +68,6 @@ SplitPmidList(int nPmids, pmID *pmidList)
 	aFreq = (int *)malloc((nAgents + 1) * sizeof(int));
 	if (resIndex == NULL || aFreq == NULL) {
 	    __pmNoMem("SplitPmidList.resIndex", 2 * (nAgents + 1) * sizeof(int), PM_FATAL_ERR);
-	    /*NOTREACHED*/
 	}
     }
 
@@ -135,7 +123,6 @@ doit:
 	result = (DomPmidList *)malloc(resultSize);
 	if (result == NULL) {
 	    __pmNoMem("SplitPmidList.result", resultSize, PM_FATAL_ERR);
-	    /*NOTREACHED*/
 	}
 	currentSize = resultSize;
     }
@@ -193,14 +180,12 @@ MakeBadResult(int npmids, pmID *list, int sts)
     result = (pmResult *)malloc(need);
     if (result == NULL) {
 	__pmNoMem("MakeBadResult.result", need, PM_FATAL_ERR);
-	/*NOTREACHED*/
     }
     result->numpmid = npmids;
     for (i = 0; i < npmids; i++) {
 	vSet = (pmValueSet *)malloc(sizeof(pmValueSet));
 	if (vSet == NULL) {
 	    __pmNoMem("MakeBadResult.vSet", sizeof(pmValueSet), PM_FATAL_ERR);
-	    /*NOTREACHED*/
 	}
 	result->vset[i] = vSet;
 	vSet->pmid = list[i];
@@ -357,7 +342,6 @@ DoFetch(ClientInfo *cip, __pmPDU* pb)
     int			nWait;
     int			maxFd;
     struct timeval	timeout;
-    __pmIPC		*ipc;
 
     if (nAgents > nDoms) {
 	if (results != NULL)
@@ -368,7 +352,6 @@ DoFetch(ClientInfo *cip, __pmPDU* pb)
 	resIndex = (int *)malloc((nAgents + 1) * sizeof(int));
 	if (results == NULL || resIndex == NULL) {
 	    __pmNoMem("DoFetch.results", (nAgents + 1) * sizeof (pmResult *) + (nAgents + 1) * sizeof(int), PM_FATAL_ERR);
-	    /*NOTREACHED*/
 	}
 	nDoms = nAgents;
     }
@@ -392,7 +375,6 @@ DoFetch(ClientInfo *cip, __pmPDU* pb)
 	need = (int)sizeof(pmResult) + (nPmids - 1) * (int)sizeof(pmValueSet *);
 	if ((endResult = (pmResult *)malloc(need)) == NULL) {
 	    __pmNoMem("DoFetch.endResult", need, PM_FATAL_ERR);
-	    /*NOTREACHED*/
 	}
 	maxnpmids = nPmids;
     }
@@ -457,7 +439,6 @@ DoFetch(ClientInfo *cip, __pmPDU* pb)
 		__pmNotifyErr(LOG_ERR, "DoFetch: fatal select failure: %s\n", strerror(errno));
 		Shutdown();
 		exit(1);
-		/*NOTREACHED*/
 	    }
 	}
 
@@ -512,10 +493,10 @@ DoFetch(ClientInfo *cip, __pmPDU* pb)
 		    int s, k;
 		    extern int CheckError(AgentInfo *ap, int sts);
 
-		    s = PM_ERR_AGAIN;
-		    if ((__pmFdLookupIPC(cip->fd, &ipc) >= 0) &&
-					(ipc->version == PDU_VERSION1))
+		    if (__pmVersionIPC(cip->fd) == PDU_VERSION1)
 			s = PM_ERR_V1(PM_ERR_AGAIN);
+		    else
+			s = PM_ERR_AGAIN;
 
 		    for (k = 0; k < dList[j].listSize; k++)
 			results[i]->vset[k]->numval = s;
@@ -552,8 +533,7 @@ DoFetch(ClientInfo *cip, __pmPDU* pb)
 
     sts = 0;
     if (cip->status.changes) {
-	if (__pmFdLookupIPC(cip->fd, &ipc) >= 0 &&
-					ipc->version != PDU_VERSION1) {
+	if (__pmVersionIPC(cip->fd) >= PDU_VERSION2) {
 	    /* notify PCP >= 2.0 client of PMCD state change */
 	    sts = __pmSendError(cip->fd, PDU_BINARY, (int)cip->status.changes);
 	    if (sts > 0)
