@@ -14,24 +14,12 @@
  * You should have received a copy of the GNU General Public License along
  * with this program; if not, write to the Free Software Foundation, Inc.,
  * 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
- * 
- * Contact information: Silicon Graphics, Inc., 1500 Crittenden Lane,
- * Mountain View, CA 94043, USA, or: http://www.sgi.com
  */
 
-#ident "$Id: dopdus.c,v 1.3 2002/07/23 10:47:31 kenmcd Exp $"
-
-#include <syslog.h>
-#include <errno.h>
 #include "pmapi.h"
 #include "impl.h"
 #include "pmcd.h"
 
-extern int	errno;
-extern int	pmcdLicensed;
-
-extern unsigned int	__pmMakeAuthCookie(unsigned int, pid_t);
-
 /* Check returned error from a client.
  * If client returns ready/not_ready status change, check then update agent
  * status.
@@ -586,7 +574,6 @@ done:
     if (name) free(name);
     if (travNL) free(travNL);
     return sts;
-
 }
 
 /*************************************************************************/
@@ -594,11 +581,11 @@ done:
 int
 DoCreds(ClientInfo *cp, __pmPDU *pb)
 {
-    int			i, sts, credcount=0;
+    int			i, sts, credcount = 0;
+    int			version = UNKNOWN_VERSION;
     int			sender = 0;
     unsigned int	cookie = 0;
     __pmCred		*credlist = NULL;
-    __pmIPC		ipc = { UNKNOWN_VERSION, NULL };
 
     if ((sts = __pmDecodeCreds(pb, PDU_BINARY, &sender, &credcount, &credlist)) < 0)
 	return sts;
@@ -609,11 +596,11 @@ DoCreds(ClientInfo *cp, __pmPDU *pb)
     for (i = 0; i < credcount; i++) {
 	switch(credlist[i].c_type) {
 	    case CVERSION:
-		ipc.version = credlist[i].c_vala;
-		sts = __pmAddIPC(cp->fd, ipc);
+		version = credlist[i].c_vala;
+		sts = __pmSetVersionIPC(cp->fd, version);
 #ifdef PCP_DEBUG
 		if (pmDebug & DBG_TRACE_CONTEXT)
-		    fprintf(stderr, "pmcd: version cred (%u)\n", ipc.version);
+		    fprintf(stderr, "pmcd: version cred (%u)\n", version);
 #endif
 		break;
 	    case CAUTH:
