@@ -14,18 +14,8 @@
  * You should have received a copy of the GNU General Public License along
  * with this program; if not, write to the Free Software Foundation, Inc.,
  * 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
- * 
- * Contact information: Silicon Graphics, Inc., 1500 Crittenden Lane,
- * Mountain View, CA 94043, USA, or: http://www.sgi.com
  */
 
-#ident "$Id: dostore.c,v 1.2 2002/07/23 10:47:31 kenmcd Exp $"
-
-#include <syslog.h>
-#include <errno.h>
-#if defined(sgi)
-#include <bstring.h>
-#endif
 #include "pmapi.h"
 #include "impl.h"
 #include "pmcd.h"
@@ -67,7 +57,6 @@ SplitResult(pmResult *res)
 	resIndex = (int *)malloc((nAgents + 1) * sizeof(int));
 	if (aFreq == NULL || resIndex == NULL) {
 	    __pmNoMem("SplitResult.freq", 2 * (nAgents + 1) * sizeof(int), PM_FATAL_ERR);
-	    /*NOTREACHED*/
 	}
     }
 
@@ -97,7 +86,6 @@ SplitResult(pmResult *res)
     need *= sizeof(pmResult *);
     if ((results = (pmResult **) malloc(need)) == NULL) {
 	__pmNoMem("SplitResult.results", need, PM_FATAL_ERR);
-	/*NOTREACHED*/
     }
     j = 0;
     for (i = 0; i <= nAgents; i++)
@@ -106,7 +94,6 @@ SplitResult(pmResult *res)
 	    results[j] = (pmResult *) malloc(need);
 	    if (results[j] == NULL) {
 		__pmNoMem("SplitResult.domain", need, PM_FATAL_ERR);
-		/*NOTREACHED*/
 	    }
 	    results[j]->numpmid = aFreq[i];
 	    j++;
@@ -115,7 +102,6 @@ SplitResult(pmResult *res)
     /* Make the "end of list" pmResult */
     if ((results[j] = (pmResult *) malloc(sizeof(pmResult))) == NULL) {
 	__pmNoMem("SplitResult.domain", sizeof(pmResult), PM_FATAL_ERR);
-	/*NOTREACHED*/
     }
     results[j]->numpmid = 0;
 
@@ -247,7 +233,6 @@ DoStore(ClientInfo *cp, __pmPDU* pb)
 		__pmNotifyErr(LOG_ERR, "DoStore: fatal select failure: %s\n", strerror(errno));
 		Shutdown();
 		exit(1);
-		/*NOTREACHED*/
 	    }
 	}
 
