@@ -14,60 +14,27 @@
  * You should have received a copy of the GNU General Public License along
  * with this program; if not, write to the Free Software Foundation, Inc.,
  * 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
- * 
- * Contact information: Silicon Graphics, Inc., 1500 Crittenden Lane,
- * Mountain View, CA 94043, USA, or: http://www.sgi.com
  */
 
-#ident "$Id: pmcd.c,v 1.15 2007/08/22 02:31:54 kimbrr Exp $"
-
-#include <stdio.h>
-#include <unistd.h>
-#include <string.h>
-#include <sys/wait.h>
-#include <sys/param.h>
-#include <sys/types.h>
-#include <sys/stat.h>
-#include <netdb.h>
-#include <signal.h>
-#include <errno.h>
-#include <ctype.h>
-#include <syslog.h>
-#ifdef IRIX6_5
-#include <optional_sym.h>
-#endif
-#include <netinet/tcp.h>
-#include <arpa/inet.h>
-
 #include "pmcd.h"
 #include "impl.h"
-
-extern int      errno;
+#include <sys/stat.h>
 
 extern int  ParseInitAgents(char *);
 extern void ParseRestartAgents(char *);
 extern void PrintAgentInfo(FILE *);
+extern void ResetBadHosts(void);
 extern void StartDaemon(void);
 
-
 #define PIDFILE "/pmcd.pid"
 #define SHUTDOWNWAIT 12 /* < PMDAs wait previously used in rc_pcp */
 
-extern int	pmDebug;
-
-int 		pmcd_hi_openfds = -1;   /* Highest known file descriptor for pmcd */
-int		_pmcd_done;		/* flag from pmcd pmda */
-char		*_pmcd_data;    	/* base size of data */
-
-int		pmcdLicense = 0;	/* no license found yet */
 int		AgentDied = 0;		/* for updating mapdom[] */
 static int	timeToDie = 0;		/* For SIGINT handling */
 static int	restart = 0;		/* For SIGHUP restart */
 static char	configFileName[MAXPATHLEN]; /* path to pmcd.conf */
 static char	*logfile = "pmcd.log";	/* log file name */
 static int	run_daemon = 1;		/* run as a daemon, see -f */
-int		_pmcd_timeout = 5;	/* Timeout for hung agents */
-					/* NOTE: may be set by pmcd pmda */
 int		_creds_timeout = 3;	/* Timeout for agents credential PDU */
 static char	*fatalfile = "/dev/tty";/* fatal messages at startup go here */
 static char	*pmnsfile = PM_NS_DEFAULT;
@@ -143,7 +110,6 @@ GrowReqPorts(void)
     reqPorts = (ReqPortInfo*)realloc(reqPorts, need);
     if (reqPorts == NULL) {
 	__pmNoMem("pmcd: can't grow request port array", need, PM_FATAL_ERR);
-	/*NOTREACHED*/
     }
 }
 
@@ -200,8 +166,6 @@ ParseOptions(int argc, char *argv[])
 {
     int		c;
     int		sts;
-    extern char	*optarg;
-    extern int	optind;
     int		errflag = 0;
     int		usage = 0;
     char	*endptr;
@@ -209,12 +173,7 @@ ParseOptions(int argc, char *argv[])
     int		port;
     char	*p;
 
-    /* trim command name of leading directory components */
-    pmProgname = argv[0];
-    for (p = pmProgname; *p; p++) {
-	if (*p == '/')
-	    pmProgname = p+1;
-    }
+    __pmSetProgname(argv[0]);
 
     strcpy(configFileName, pmGetConfig("PCP_PMCDCONF_PATH"));
 
@@ -250,7 +209,6 @@ ParseOptions(int argc, char *argv[])
 		nintf++;
 		if ((intflist = (char **)realloc(intflist, nintf * sizeof(char *))) == NULL) {
 		    __pmNoMem("pmcd: can't grow interface list", nintf * sizeof(char *), PM_FATAL_ERR);
-		    /*NOTREACHED*/
 		}
 		intflist[nintf-1] = optarg;
 		break;
@@ -266,19 +224,7 @@ ParseOptions(int argc, char *argv[])
 		    fputs ("pmcd: -L require a posivite value\n", stderr);
 		    errflag++;
 		} else {
-#ifdef IRIX6_5
-		    if ( _MIPS_SYMBOL_PRESENT(__pmSetPDUCeiling)) {
-			__pmSetPDUCeiling (val);
-		    } else {
-			fputs ("Cannot restrict incoming PDU size - current "
-			       "libpcp.so does not support this feature",
-				 stderr);
-			errflag++;
-		    }
-#else
 		    __pmSetPDUCeiling (val);
-#endif
-
 		}
 		break;
 
@@ -305,7 +251,6 @@ ParseOptions(int argc, char *argv[])
 			nport++;
 			if ((portlist = (int *)realloc(portlist, nport * sizeof(int))) == NULL) {
 			    __pmNoMem("pmcd: can't grow port list", nport * sizeof(int), PM_FATAL_ERR);
-			    /*NOTREACHED*/
 			}
 			portlist[nport-1] = port;
 		    }
@@ -380,9 +325,7 @@ ParseOptions(int argc, char *argv[])
 	    exit(0);
 	else
 	    DontStart();
-	/*NOTREACHED*/
     }
-    return;
 }
 
 /* Create socket for incoming connections and bind to it an address for
@@ -395,12 +338,10 @@ static int
 OpenRequestSocket(int port, __uint32_t ipAddr)
 {
     int			fd;
-    int			i, sts;
+    int			one, sts;
     struct sockaddr_in	myAddr;
-    struct linger	noLinger = {1, 0};
-    int			one = 1;
 
-    fd = socket(AF_INET, SOCK_STREAM, 0);
+    fd = __pmCreateSocket();
     if (fd < 0) {
 	__pmNotifyErr(LOG_ERR, "OpenRequestSocket(%d, 0x%x) socket: %s\n", port, ipAddr, strerror(errno));
 	return -1;
@@ -408,20 +349,9 @@ OpenRequestSocket(int port, __uint32_t ipAddr)
     if (fd > maxClientFd)
 	maxClientFd = fd;
     FD_SET(fd, &clientFds);
-    i = 1;
-    if (setsockopt(fd, IPPROTO_TCP, TCP_NODELAY, (char *) &i,
-		   (mysocklen_t)sizeof(i)) < 0) {
-	__pmNotifyErr(LOG_ERR, "OpenRequestSocket(%d, 0x%x) setsockopt(nodelay): %s\n", port, ipAddr, strerror(errno));
-	close(fd);
-	return -1;
-    }
-
-    /* Don't linger on close */
-    if (setsockopt(fd, SOL_SOCKET, SO_LINGER, (char *)&noLinger, (mysocklen_t)sizeof(noLinger)) < 0) {
-	__pmNotifyErr(LOG_ERR, "OpenRequestSocket(%d, 0x%x) setsockopt(nolinger): %s\n", port, ipAddr, strerror(errno));
-    }
 
     /* Ignore dead client connections */
+    one = 1;
     if (setsockopt(fd, SOL_SOCKET, SO_REUSEADDR, (char *)&one, (mysocklen_t)sizeof(one)) < 0) {
 	__pmNotifyErr(LOG_ERR, "OpenRequestSocket(%d, 0x%x) setsockopt(SO_REUSEADDR): %s\n", port, ipAddr, strerror(errno));
     }
@@ -440,14 +370,14 @@ OpenRequestSocket(int port, __uint32_t ipAddr)
 	__pmNotifyErr(LOG_ERR, "OpenRequestSocket(%d, 0x%x) bind: %s\n", port, ipAddr, strerror(errno));
 	if (errno == EADDRINUSE)
 	    __pmNotifyErr(LOG_ERR, "pmcd may already be running\n");
-	close(fd);
+	__pmCloseSocket(fd);
 	return -1;
     }
 
     sts = listen(fd, 5);	/* Max. of 5 pending connection requests */
     if (sts == -1) {
 	__pmNotifyErr(LOG_ERR, "OpenRequestSocket(%d, 0x%x) listen: %s\n", port, ipAddr, strerror(errno));
-	close(fd);
+	__pmCloseSocket(fd);
 	return -1;
     }
     return fd;
@@ -477,7 +407,6 @@ HandleClientInput(fd_set *fdsPtr)
     __pmPDU	*pb;
     __pmPDUHdr	*php;
     ClientInfo	*cp;
-    __pmIPC	*ipcptr;
 
     for (i = 0; i < nClients; i++) {
 	if (!client[i].status.connected || !FD_ISSET(client[i].fd, fdsPtr))
@@ -494,39 +423,8 @@ HandleClientInput(fd_set *fdsPtr)
 	}
 
 	php = (__pmPDUHdr *)pb;
-
-	__pmFdLookupIPC(cp->fd, &ipcptr);
-
-	if (ipcptr == NULL || ipcptr->version == UNKNOWN_VERSION) {
-	    if (php->type != (int)PDU_CREDS) {
-		__pmIPC	ipc = { PDU_VERSION1, NULL };
-		if (pmcdLicense != PM_LIC_COL) {
-		    /* Need to wait for an appropriate PDU before sending
-		     * an error PDU back to 1.x clients - flag as suspect
-		     * for now and cleanup later.
-		     */
-		    ipc.version = ILLEGAL_CONNECT;
-		}
-		sts = __pmAddIPC(cp->fd, ipc);
-	    }
-	}
-	else if (ipcptr->version == ILLEGAL_CONNECT) {
-	    if (php->type != PDU_PROFILE) {
-		__pmIPC	ipc = { PDU_VERSION1, NULL };
-
-		/* send error to 1.x client and close connection */
-		sts = __pmAddIPC(cp->fd, ipc);
-		if (sts >= 0)
-		    sts = __pmSendError(cp->fd, PDU_BINARY, PM_ERR_LICENSE);
-		if (sts < 0)
-		    __pmNotifyErr(LOG_ERR,
-				 "pmcd: error sending Error PDU to client[%d] %s\n",
-				 i, pmErrStr(sts));
-		CleanupClient(cp, PM_ERR_LICENSE);
-	    }
-	    /* else ignore message & wait for a message that has an ACK */
-	    continue;
-	}
+	if (__pmVersionIPC(cp->fd) == UNKNOWN_VERSION && php->type != PDU_CREDS)
+	    __pmSetVersionIPC(cp->fd, PDU_VERSION1);
 
 #ifdef PCP_DEBUG
 	    if (pmDebug & DBG_TRACE_APPL0)
@@ -584,10 +482,9 @@ HandleClientInput(fd_set *fdsPtr)
 		break;
 
 	    case PDU_CREDS:
-		if ((sts = __pmFdLookupIPC(cp->fd, &ipcptr)) < 0)
+		if ((sts = __pmVersionIPC(cp->fd)) < 0)
 		    break;
-		if (ipcptr->version == PDU_VERSION1 ||
-					ipcptr->version == ILLEGAL_CONNECT) {
+		if (sts == PDU_VERSION1) {
 		    __pmNotifyErr(LOG_ERR, "pmcd: protocol version error on fd=%d\n", cp->fd);
 		    sts = PM_ERR_V1(PM_ERR_IPC);
 		}
@@ -630,10 +527,18 @@ Shutdown(void)
 	AgentInfo *ap = &agent[i];
 	if (!ap->status.connected)
 	    continue;
-	if (ap->inFd != -1)
-	    close(ap->inFd);
-	if (ap->outFd != -1)
-	    close(ap->outFd);
+	if (ap->inFd != -1) {
+	    if (__pmSocketIPC(ap->inFd))
+		__pmCloseSocket(ap->inFd);
+	    else
+		close(ap->inFd);
+	}
+	if (ap->outFd != -1) {
+	    if (__pmSocketIPC(ap->outFd))
+		__pmCloseSocket(ap->outFd);
+	    else
+		close(ap->outFd);
+	}
 	if (ap->ipcType == AGENT_SOCKET &&
 	    ap->ipc.socket.addrDomain == AF_UNIX) {
 	    /* remove the Unix domain socket */
@@ -645,18 +550,18 @@ Shutdown(void)
 	for (i = 0; i < nAgents; i++) {
 	    AgentInfo *ap = &agent[i];
 	    if (ap->status.connected) {
-		kill((ap->ipcType == AGENT_SOCKET) 
-		     ? ap->ipc.socket.agentPid 
-		     : ap->ipc.pipe.agentPid, SIGKILL);
+		pid_t pid = ap->ipcType == AGENT_SOCKET ?
+			    ap->ipc.socket.agentPid : ap->ipc.pipe.agentPid;
+		__pmProcessTerminate(pid, 1);
 	    }
 	}
     }
     for (i = 0; i < nClients; i++)
 	if (client[i].status.connected)
-	    close(client[i].fd);
+	    __pmCloseSocket(client[i].fd);
     for (i = 0; i < nReqPorts; i++)
 	if ((fd = reqPorts[i].fd) != -1)
-	    close(fd);
+	    __pmCloseSocket(fd);
     __pmNotifyErr(LOG_INFO, "pmcd Shutdown\n");
     fflush(stderr);
 }
@@ -806,18 +711,14 @@ ClientLoop(void)
 		    	continue;
 
 		    sts = __pmAccAddClient(&cp->addr.sin_addr, &cp->denyOps);
-
 		    if (sts >= 0) {
 			cp->pduInfo.zero = 0;
 			cp->pduInfo.version = PDU_VERSION;
-			cp->pduInfo.licensed = pmcdLicense;
-			cp->pduInfo.authorize = (!pmcdLicense)?((int)lrand48()):(0);
+			cp->pduInfo.licensed = 1;
+			cp->pduInfo.authorize = 0;
 			challenge = *(int*)(&cp->pduInfo);
-			if (!pmcdLicense)
-			    sts = PM_ERR_LICENSE;
-			else
-			    sts = 0;
-			/* reset this (no meaning - use __pmIPC* interface to version) */
+			sts = 0;
+			/* reset (no meaning, use fd table to version) */
 			cp->pduInfo.version = UNKNOWN_VERSION;
 		    }
 		    else {
@@ -865,7 +766,6 @@ ClientLoop(void)
 	}
 	if (restart) {
 	    time_t	now;
-	    extern void	ResetBadHosts(void);
 
 	    reload_ns = 1;
 	    restart = 0;
@@ -873,27 +773,8 @@ ClientLoop(void)
 	    __pmNotifyErr(LOG_INFO, "\n\npmcd RESTARTED at %s", ctime(&now));
 	    fprintf(stderr, "\nCurrent PMCD clients ...\n");
 	    ShowClients(stderr);
-
-	    if (__pmGetLicense(PM_LIC_COL, "pmcd", GET_LICENSE_SHOW_EXP) != PM_LIC_COL) {
-		if (pmcdLicense) {
-		    /* no collector license, but continue */
-		    fprintf(stderr, "Warning: PCP collector license vanished.\n");
-		    fprintf(stderr, "         New connections will only be accepted from authorized clients.\n");
-		    fputc('\n', stderr);
-		    pmcdLicense = 0;
-		}
-	    }
-	    else {
-		if (!pmcdLicense) {
-		    fprintf(stderr, "Note: PCP collector license appeared.\n");
-		    fputc('\n', stderr);
-		    pmcdLicense = PM_LIC_COL;
-		}
-	    }
-
 	    ResetBadHosts();
 	    ParseRestartAgents(configFileName);
-
 	}
 
 	if ( reload_ns ) {
@@ -932,7 +813,7 @@ ClientLoop(void)
 		    killer_sig == SIGINT ? "SIGINT" : "SIGTERM", killer_pid, killer_uid);
 #if DESPERATE
 		__pmNotifyErr(LOG_INFO, "Try to find process in ps output ...\n");
-		sprintf(buf, "sh -c \". /etc/pcp.env; ( ps \\$PCP_PS_ALL_FLAGS | \\$PCP_AWK_PROG 'NR==1 {print} \\$2==%d {print}' )\"", killer_pid);
+		sprintf(buf, "sh -c \". \\$PCP_DIR/etc/pcp.env; ( \\$PCP_PS_PROG \\$PCP_PS_ALL_FLAGS | \\$PCP_AWK_PROG 'NR==1 {print} \\$2==%d {print}' )\"", killer_pid);
 		system(buf);
 #endif
 	    }
@@ -957,7 +838,6 @@ ClientLoop(void)
 }
 
 #ifdef HAVE_SA_SIGINFO
-/*ARGSUSED*/
 void
 SigIntProc(int sig, siginfo_t *sip, void *x)
 {
@@ -969,7 +849,6 @@ SigIntProc(int sig, siginfo_t *sip, void *x)
     timeToDie = 1;
 }
 #else
-/*ARGSUSED*/
 void SigIntProc(int sig)
 {
     killer_sig = sig;
@@ -979,12 +858,13 @@ void SigIntProc(int sig)
 }
 #endif
 
-/*ARGSUSED*/
+#ifdef HAVE_SIGHUP
 void SigHupProc(int s)
 {
     signal(SIGHUP, SigHupProc);
     restart = 1;
 }
+#endif
 
 #if HAVE_TRACE_BACK_STACK
 /*
@@ -1028,7 +908,6 @@ void SigBad(int sig)
     fprintf(stderr, "\nDumping to core ...\n");
     fflush(stderr);
     abort();
-    /*NOTREACHED*/
 }
 
 int
@@ -1048,25 +927,8 @@ main(int argc, char *argv[])
 #endif
 
     umask(022);
+    __pmProcessDataSize(NULL);
     __pmSetInternalState(PM_STATE_PMCS);
-#if defined(HAVE_SBRK)
-    _pmcd_data = sbrk(0);
-#else
-    _pmcd_data = 0;
-#endif
-
-#ifdef MALLOC_AUDIT
-    _malloc_reset_();
-    atexit(_malloc_audit_);
-#endif
-
-#ifdef __host_mips
-    if ((sts = __pmCheckObjectStyle()) != 0) {
-	/* fatal. This pmcd binary does not match the running kernel. */
-	__pmNotifyErr(LOG_ERR, "pmcd: FATAL ERROR: %s\n", pmErrStr(sts));
-	exit(1);
-    }
-#endif
 
     /*
      * get optional stuff from environment ... PMCD_PORT ...
@@ -1087,7 +949,6 @@ main(int argc, char *argv[])
 		nport++;
 		if ((portlist = (int *)realloc(portlist, nport * sizeof(int))) == NULL) {
 		    __pmNoMem("pmcd: can't grow port list", nport * sizeof(int), PM_FATAL_ERR);
-		    /*NOTREACHED*/
 		}
 		portlist[nport-1] = port;
 	    }
@@ -1101,7 +962,9 @@ main(int argc, char *argv[])
 
     if (run_daemon) {
 	fflush(stderr);
+#ifndef IS_MINGW
 	StartDaemon();
+#endif
     }
 
 #ifdef HAVE_SA_SIGINFO
@@ -1113,8 +976,12 @@ main(int argc, char *argv[])
     signal(SIGINT, SigIntProc);
     signal(SIGTERM, SigIntProc);
 #endif
+#ifdef HAVE_SIGHUP
     signal(SIGHUP, SigHupProc);
+#endif
+#ifdef HAVE_SIGBUS
     signal(SIGBUS, SigBad);
+#endif
     signal(SIGSEGV, SigBad);
 
     /* seed random numbers for authorisation */
@@ -1123,16 +990,14 @@ main(int argc, char *argv[])
     if (nport == 0) {
 	/*
 	 * no ports from $PMCD_PORT, nor from -p, set up defaults
-	 * for compatibility this is SERVER_PORT,4321 but eventually
-	 * it will become just SERVER_PORT
+	 * for compatibility this used to be SERVER_PORT,4321 but
+	 * has now transitioned to just SERVER_PORT
 	 */
-	nport = 2;
+	nport = 1;
 	if ((portlist = (int *)realloc(portlist, nport * sizeof(int))) == NULL) {
 	    __pmNoMem("pmcd: can't grow port list", nport * sizeof(int), PM_FATAL_ERR);
-	    /*NOTREACHED*/
 	}
 	portlist[0] = SERVER_PORT;
-	portlist[1] = OLD_SERVER_PORT;
     }
 
     /*
@@ -1169,7 +1034,6 @@ main(int argc, char *argv[])
 		if (!AddRequestPort(intflist[i], portlist[n])) {
 		    fprintf(stderr, "pmcd: bad IP spec: -i %s\n", intflist[i]);
 		    exit(1);
-		    /*NOTREACHED*/
 		}
 	    }
 	}
@@ -1187,7 +1051,6 @@ main(int argc, char *argv[])
     if (nReqPortsOK == 0) {
 	__pmNotifyErr(LOG_ERR, "pmcd: can't open any request ports, exiting\n");
 	DontStart();
-	/*NOTREACHED*/
     }	
 
     __pmOpenLog("pmcd", logfile, stderr, &status);
@@ -1196,32 +1059,20 @@ main(int argc, char *argv[])
     close(fileno(stdout));
     dup(fileno(stderr));
 
-    if (__pmGetLicense(PM_LIC_COL, "pmcd", GET_LICENSE_SHOW_EXP) != PM_LIC_COL) {
-	/* no collector license, but continue */
-	fprintf(stderr, "Warning: No PCP collector license.\n");
-	fprintf(stderr, "         Connections will only be accepted from authorized clients.\n");
-	pmcdLicense = 0;
-    }
-    else
-	pmcdLicense = PM_LIC_COL;
-
     if ((sts = pmLoadNameSpace(pmnsfile)) < 0) {
 	fprintf(stderr, "Error: pmLoadNameSpace: %s\n", pmErrStr(sts));
 	DontStart();
-	/*NOTREACHED*/
     }
 
     if (ParseInitAgents(configFileName) < 0) {
 	/* error already reported in ParseInitAgents() */
 	DontStart();
-	/*NOTREACHED*/
     }
 
     if (nAgents <= 0) {
 	fprintf(stderr, "Error: No PMDAs found in the configuration file \"%s\"\n",
 		configFileName);
 	DontStart();
-	/*NOTREACHED*/
     }
 
     if (run_daemon) {
@@ -1234,7 +1085,6 @@ main(int argc, char *argv[])
 	if (pidfile == NULL) {
 	    fprintf(stderr, "Error: Cant open pidfile %s\n", pidpath);
 	    DontStart();
-	    /*NOTREACHED*/	
 	}
 	fprintf(pidfile, "%d", getpid());
 	fflush(pidfile);
@@ -1246,8 +1096,6 @@ main(int argc, char *argv[])
     __pmAccDumpHosts(stderr);
     fprintf(stderr, "\npmcd: PID = %u", (int)getpid());
     fprintf(stderr, ", PDU version = %u", PDU_VERSION);
-    if (pmcdLicense)
-	fprintf(stderr, ", pcpcol license");
     fputc('\n', stderr);
     fputs("pmcd request port(s):\n"
 	  "  sts fd  port  IP addr\n"
@@ -1266,7 +1114,6 @@ main(int argc, char *argv[])
 
     Shutdown();
     exit(0);
-    /* NOTREACHED */
 }
 
 /* The bad host list is a list of IP addresses for hosts that have had clients
@@ -1297,7 +1144,6 @@ AddBadHost(struct in_addr *hostId)
 	need = szBadHosts * (int)sizeof(badHost[0]);
 	if ((badHost = (struct in_addr *)malloc(need)) == NULL) {
 	    __pmNoMem("pmcd.AddBadHost", need, PM_FATAL_ERR);
-	    /*NOTREACHED*/
 	}
     }
     badHost[nBadHosts++].s_addr = hostId->s_addr;
