@@ -14,9 +14,6 @@
  * You should have received a copy of the GNU General Public License along
  * with this program; if not, write to the Free Software Foundation, Inc.,
  * 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
- * 
- * Contact information: Silicon Graphics, Inc., 1500 Crittenden Lane,
- * Mountain View, CA 94043, USA, or: http://www.sgi.com
  *
  * Cisco PMDA, based on generic driver for a daemon-based PMDA
  *  - cisco interfaces to monitor are named in the command line as
@@ -40,8 +37,6 @@
  *    options and applies for all occurrences of the hostname.
  */
 
-#ident "$Id: pmda.c,v 2.30 2004/06/15 09:39:44 kenmcd Exp $"
-
 #include <stdio.h>
 #include <sys/types.h>
 #include <sys/socket.h>
@@ -63,26 +58,21 @@ char		*username = NULL;	/* username */
 char		*passwd = NULL;		/* user-level password */
 int		port = 23;
 
+extern void	cisco_init(pmdaInterface *);
+extern void	cisco_done(void);
+
 int
 main(int argc, char **argv)
 {
     int			err = 0;
-#ifdef PARSE_ONLY
-    extern int		pmDebug;
-#endif
     char		*endnum;
     pmdaInterface	dispatch;
     int			n;
     int			i;
     int			c;
-    extern char		*optarg;
-    extern int		optind;
-    extern void		cisco_init(pmdaInterface *);
-    extern void		cisco_done(void);
     char		helptext[MAXPATHLEN];
 
-    /* trim cmd name of leading directory components */
-    pmProgname = basename(argv[0]);
+    __pmSetProgname(argv[0]);
 
 #ifdef PARSE_ONLY
     pmDebug = DBG_TRACE_APPL0 | DBG_TRACE_APPL1;
@@ -155,24 +145,15 @@ main(int argc, char **argv)
      */
     if ((_router = (pmdaInstid *)malloc(n_intf * sizeof(pmdaInstid))) == NULL) {
         __pmNoMem("main.router", n_intf * sizeof(pmdaInstid), PM_FATAL_ERR);
-        /*NOTREACHED*/
     }
     if ((intf = (intf_t *)malloc(n_intf * sizeof(intf_t))) == NULL) {
         __pmNoMem("main.intf", n_intf * sizeof(intf_t), PM_FATAL_ERR);
-        /*NOTREACHED*/
     }
     /* pre-allocated cisco[] to avoid realloc and ptr movement */
     if ((cisco = (cisco_t *)malloc(n_intf * sizeof(cisco_t))) == NULL) {
 	__pmNoMem("main.cisco", n_intf * sizeof(cisco_t), PM_FATAL_ERR);
-	/*NOTREACHED*/
     }
 
-#ifdef MALLOC_AUDIT
-    _persistent_(_router);
-    _persistent_(intf);
-    _persistent_(cisco);
-#endif
-
     indomtab[CISCO_INDOM].it_numinst = n_intf;
     indomtab[CISCO_INDOM].it_set = _router;
 
@@ -218,7 +199,6 @@ main(int argc, char **argv)
 	    intf[n].interface = (char *)malloc(strlen("Fast")+strlen(q)+1);
 	    if ((intf[n].interface = (char *)malloc(strlen("Fast")+strlen(q)+1)) == NULL) {
 		__pmNoMem("main.cisco", strlen("Fast")+strlen(q)+1, PM_FATAL_ERR);
-		/*NOTREACHED*/
 	    }
 	    strcpy(intf[n].interface, "Fast");
 	    strcat(intf[n].interface, q);
@@ -325,11 +305,6 @@ badintfspec:
     /* initialize */
     cisco_init(&dispatch);
 
-#ifdef MALLOC_AUDIT
-    _malloc_reset_();
-    atexit(_malloc_audit_);
-#endif
-
 #ifdef PARSE_ONLY
     for (i = 0; i < n_intf; i++)
 	intf[i].fetched = 0;
@@ -344,5 +319,4 @@ badintfspec:
 
     cisco_done();
     exit(0);
-    /*NOTREACHED*/
 }
