@@ -16,9 +16,6 @@
  * You should have received a copy of the GNU General Public License along
  * with this program; if not, write to the Free Software Foundation, Inc.,
  * 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
- * 
- * Contact information: Silicon Graphics, Inc., 1500 Crittenden Lane,
- * Mountain View, CA 94043, USA, or: http://www.sgi.com
  */
 #include <stdio.h>
 #include <stdlib.h>
@@ -1190,15 +1187,15 @@ darwin_fetch(int numpmid, pmID pmidlist[], pmResult **resp, pmdaExt *pmda)
 void 
 darwin_init(pmdaInterface *dp)
 {
-    if (dp->status != 0)
-	return;
-
     if (_isDSO) {
 	char helppath[MAXPATHLEN];
 	sprintf(helppath, "%s/pmdas/darwin/help", pmGetConfig("PCP_VAR_DIR"));
 	pmdaDSO(dp, PMDA_INTERFACE_3, "darwin DSO", helppath);
     }
 
+    if (dp->status != 0)
+	return;
+
     dp->version.two.instance = darwin_instance;
     dp->version.two.fetch = darwin_fetch;
     pmdaSetFetchCallBack(dp, darwin_fetchCallBack);
@@ -1236,20 +1233,17 @@ int
 main(int argc, char **argv)
 {
     int			errflag = 0;
-    char		*p;
     char		helppath[MAXPATHLEN];
 
-    for (p = pmProgname = argv[0]; *p; p++)
-	if (*p == '/') pmProgname = p+1;
-
     _isDSO = 0;
+    __pmSetProgname(argv[0]);
+
     sprintf(helppath, "%s/pmdas/darwin/help", pmGetConfig("PCP_VAR_DIR"));
     pmdaDaemon(&dispatch, PMDA_INTERFACE_3, pmProgname, DARWIN, "darwin.log",
 		helppath);
 
     if (pmdaGetOpt(argc, argv, "D:d:i:l:pu:?", &dispatch, &errflag) != EOF)
 	errflag++;
-
     if (errflag)
 	usage();
 
