@@ -14,13 +14,8 @@
  * You should have received a copy of the GNU General Public License along
  * with this program; if not, write to the Free Software Foundation, Inc.,
  * 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
- * 
- * Contact information: Silicon Graphics, Inc., 1500 Crittenden Lane,
- * Mountain View, CA 94043, USA, or: http://www.sgi.com
  */
 
-#ident "$Id: hotproc.c,v 1.48 2004/05/21 02:03:05 kenmcd Exp $"
-
 #include <unistd.h>
 #include <stdio.h>
 #include <syslog.h>
@@ -31,7 +26,6 @@
 #include <sys/stat.h>
 #include <dirent.h>
 #include <sys/types.h>
-#include <sys/times.h>
 #include <sys/sysmp.h>
 #include <sys/sysinfo.h>
 #include <sys/procfs.h>
@@ -39,9 +33,6 @@
 #include <sys/sysmacros.h>
 #include <pwd.h>
 #include <grp.h>
-#if defined(sgi)
-#include <bstring.h>
-#endif
 
 #include "pmapi.h"
 #include "impl.h"
@@ -83,7 +74,6 @@
 #define ACCUM_PMTYPE    PM_TYPE_U64  /* accum_t from types.h */
 #endif  /* _MIPS_SZLONG == 64 */
 
-extern int		errno;
 extern char *conf_buffer;
 extern char *conf_buffer_ptr;
 extern char *pred_buffer;
@@ -242,12 +232,10 @@ dump_proc_list(void)
 }
 
 static void
-dump_cputime(struct tms *pre, struct tms *post)
+dump_cputime(double pre_usr, double pre_sys, double post_usr, double post_sys)
 {
-  (void)fprintf(stderr, "CPU Time: user = %f, sys = %f\n",
-          ((post->tms_utime - pre->tms_utime)/ (double)CLK_TCK),
-          ((post->tms_stime - pre->tms_stime)/ (double)CLK_TCK));
-
+  fprintf(stderr, "CPU Time: user = %f, sys = %f\n",
+          post_usr - pre_usr, post_sys - pre_sys);
 }
 
 static void
@@ -533,8 +521,8 @@ refresh_proc_list(void)
 
 #ifdef PCP_DEBUG
     double curr_time;	/* for current time */
-    struct tms pre_tms;
-    struct tms post_tms;
+    double pre_usr, pre_sys;
+    double post_usr, post_sys;
 #endif
 
     /* switch current and previous */
@@ -547,10 +535,10 @@ refresh_proc_list(void)
 
 #ifdef PCP_DEBUG
     if (pmDebug & DBG_TRACE_APPL0) {
-	(void)gettimeofday(&ts);
+	gettimeofday(&ts);
 	curr_time = utime2double(ts);
-        (void)fprintf(stderr, "refresh_proc_list():\n");
-        (void)times(&pre_tms); 
+        fprintf(stderr, "refresh_proc_list():\n");
+        __pmProcessRunTimes(&pre_usr, &pre_sys); 
     }
 #endif
 
@@ -812,11 +800,11 @@ refresh_proc_list(void)
 
 #ifdef PCP_DEBUG
     if (pmDebug & DBG_TRACE_APPL0) {
-        (void)times(&post_tms); 
+        __pmProcessRunTimes(&post_usr, &post_sys); 
         dump_proc_list();
-        (void)fprintf(stderr, "refresh_proc_list: duration = %f secs; ", 
+        fprintf(stderr, "refresh_proc_list: duration = %f secs; ", 
                 refresh_time[current] - curr_time);
-        dump_cputime(&pre_tms, &post_tms);
+        dump_cputime(pre_usr, pre_sys, post_usr, post_sys);
         dump_active_list();
     }
 #endif
@@ -837,7 +825,6 @@ restart_proc_list(void)
     return sts;
 }
 
-/*ARGSUSED0*/
 static void
 timer_callback(int afid, void *data)
 {
@@ -849,7 +836,6 @@ timer_callback(int afid, void *data)
 }
 
 
-/*ARGSUSED4*/
 static int
 hotproc_instance(pmInDom indom, int inst, char *name, __pmInResult **result, pmdaExt *pmda)
 {
@@ -945,7 +931,6 @@ hotproc_instance(pmInDom indom, int inst, char *name, __pmInResult **result, pmd
     return sts;
 }
 
-/*ARGSUSED2*/
 static int
 hotproc_desc(pmID pmid, pmDesc *desc, pmdaExt *pmda)
 {
@@ -1484,7 +1469,6 @@ get_options(int argc, char *argv[], pmdaInterface *dispatch)
 
     if (err || optind != argc -1) {
     	usage();
-	/*NOTREACHED*/
     }
 
     configfile = argv[optind];
@@ -1509,12 +1493,7 @@ main(int argc, char **argv)
     FILE		*conf;
     char		mypath[MAXPATHLEN];
 
-    /* trim cmd name of leading directory components */
-    pmProgname = argv[0];
-    for (p = pmProgname; *p; p++) {
-	if (*p == '/')
-	    pmProgname = p+1;
-    }
+    __pmSetProgname(argv[0]);
 
     refresh_delta.tv_sec = 10;
     refresh_delta.tv_usec = 0;
@@ -1571,5 +1550,4 @@ main(int argc, char **argv)
     }
 
     exit(0);
-    /*NOTREACHED*/
 }
