@@ -18,18 +18,15 @@
  * 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
  */
 
-#include <sys/types.h>
-#include <sys/stat.h>
-#include <sys/wait.h>
-#include <errno.h>
-#include <stdio.h>
-#include <string.h>
-#include <unistd.h>
+#include "jstat.h"
 #include <ctype.h>
-#include <signal.h>
-#include <syslog.h>
+#include <sys/stat.h>
+#if defined(HAVE_PTHREAD_H)
 #include <pthread.h>
-#include "./jstat.h"
+#endif
+#if defined(HAVE_SYS_WAIT_H)
+#include <sys/wait.h>
+#endif
 
 jstat_t		*jstat;
 int		jstat_hertz = 1000;
@@ -646,7 +643,7 @@ main(int argc, char **argv)
     int			c;
     char		helptext[MAXPATHLEN];
 
-    pmProgname = basename(argv[0]);
+    __pmSetProgname(argv[0]);
     snprintf(helptext, sizeof(helptext), "%s/jstat/help",
 		pmGetConfig("PCP_PMDAS_DIR"));
     pmdaDaemon(&dispatch, PMDA_INTERFACE_3, pmProgname, JSTAT,
