@@ -1,6 +1,6 @@
 /*
- * Copyright (c) 2005 Silicon Graphics, Inc.  All Rights Reserved.
- * 
+ * Copyright (c) 2005,2007-2008 Silicon Graphics, Inc.  All Rights Reserved.
+ *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
  * Free Software Foundation; either version 2 of the License, or (at your
@@ -14,14 +14,8 @@
  * You should have received a copy of the GNU General Public License along
  * with this program; if not, write to the Free Software Foundation, Inc.,
  * 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
- * 
- * Contact information: Silicon Graphics, Inc., 1500 Crittenden Lane,
- * Mountain View, CA 94043, USA, or: http://www.sgi.com
- *
  */
 
-#ident "$Id: indom.h,v 1.2 2006/10/30 04:52:30 kimbrr Exp $"
-
 #ifndef _INDOM_H
 #define _INDOM_H
 
@@ -38,8 +32,11 @@
 #define PARTITIONS_INDOM 	10
 #define SCSI_INDOM		11
 #define SLAB_INDOM		12
-#define IB_INDOM		13
-#define NET_INET_INDOM		14
+#define IB_INDOM		13	/* deprecated: do not re-use */
+#define NFS4_CLI_INDOM		14
+#define NFS4_SVR_INDOM		15
+#define QUOTA_PRJ_INDOM		16
+#define NET_INET_INDOM		17
 
 #define INDOM(x) (indomtab[x].it_indom)
 extern pmdaIndom indomtab[];
