@@ -16,25 +16,15 @@
  * You should have received a copy of the GNU General Public License along
  * with this program; if not, write to the Free Software Foundation, Inc.,
  * 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
- * 
- * Contact information: Silicon Graphics, Inc., 1500 Crittenden Lane,
- * Mountain View, CA 94043, USA, or: http://www.sgi.com
  *
  * Copyright (c) 2001 Gilly Ran (gilly@exanet.com) for the
  * portions of the code supporting the Alpha platform.
  * All rights reserved.
  */
 
-#ident "$Id: proc_cpuinfo.c,v 1.15 2005/08/11 03:26:21 markgw Exp $"
-
-#include <stdlib.h>
-#include <stdio.h>
-#include <errno.h>
-#include <dirent.h>
 #include <ctype.h>
-#include <sys/types.h>
+#include <dirent.h>
 #include <sys/stat.h>
-
 #include "pmapi.h"
 #include "impl.h"
 #include "pmda.h"
