@@ -16,18 +16,9 @@
  * You should have received a copy of the GNU General Public License along
  * with this program; if not, write to the Free Software Foundation, Inc.,
  * 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
- * 
- * Contact information: Silicon Graphics, Inc., 1500 Crittenden Lane,
- * Mountain View, CA 94043, USA, or: http://www.sgi.com
  */
 
-#ident "$Id: proc_slabinfo.c,v 1.5 2006/06/30 05:47:11 makc Exp $"
-
-#include <stdio.h>
-#include <errno.h>
-#include <string.h>
 #include <ctype.h>
-
 #include "pmapi.h"
 #include "impl.h"
 #include "pmda.h"
