@@ -18,11 +18,6 @@
  * You should have received a copy of the GNU General Public License along
  * with this program; if not, write to the Free Software Foundation, Inc.,
  * 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
- * 
- * Contact information: Silicon Graphics, Inc., 1500 Crittenden Lane,
- * Mountain View, CA 94043, USA, or: http://www.sgi.com
- * 
- * $Id: lmsensors.c,v 1.4 2004/06/24 06:15:36 kenmcd Exp $
  */ 
 
 #include <stdlib.h>
@@ -939,28 +934,21 @@ int
 main(int argc, char **argv)
 {
     int			err = 0;
-    int			c = 0;
     pmdaInterface	desc;
-    char		*p;
     char		mypath[MAXPATHLEN];
 
-    /* trim cmd name of leading directory components */
-    pmProgname = argv[0];
-    for (p = pmProgname; *p; p++) {
-	if (*p == '/')
-	    pmProgname = p+1;
-    }
+    __pmSetProgname(argv[0]);
 
     snprintf(mypath, sizeof(mypath),
 		"%s/lmsensors/help", pmGetConfig("PCP_PMDAS_DIR"));
     pmdaDaemon(&desc, PMDA_INTERFACE_2, pmProgname, LMSENSORS,
 		"lmsensors.log", mypath);
 
-    if ((c = pmdaGetOpt(argc, argv, "D:d:l:?", &desc, &err)) != EOF)
-    	err++;
+    if ((pmdaGetOpt(argc, argv, "D:d:l:?", &desc, &err)) != EOF)
+	err++;
    
     if (err)
-    	usage();
+	usage();
 
     pmdaOpenLog(&desc);
     lmsensors_init(&desc);
@@ -968,5 +956,4 @@ main(int argc, char **argv)
     pmdaMain(&desc);
 
     exit(0);
-    /*NOTREACHED*/
 }
