@@ -14,41 +14,17 @@
  * You should have received a copy of the GNU General Public License along
  * with this program; if not, write to the Free Software Foundation, Inc.,
  * 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
- * 
- * Contact information: Silicon Graphics, Inc., 1500 Crittenden Lane,
- * Mountain View, CA 94043, USA, or: http://www.sgi.com
  */
 
-#ident "$Id: pmcd.c,v 1.13 2006/07/17 02:23:19 makc Exp $"
-
-#include <unistd.h>
-#include <stdio.h>
-#include <syslog.h>
-#include <errno.h>
-#include <fcntl.h>
-#include <errno.h>
-#include <signal.h>
-#include <dirent.h>
-#include <ctype.h>
-#include <sys/types.h>
-#include <sys/stat.h>
-#include <sys/mman.h>
-#include <sys/param.h>
-#include <sys/socket.h>
-#include <netinet/in.h>
-#include <netdb.h>
-#include <time.h>
 #include "pmapi.h"
 #include "impl.h"
 #include "pmda.h"
 #include "pmcd/src/pmcd.h"
 #include "pmcd/src/client.h"
 #include "pmie/src/pmiestats.h"
-
-#if defined(IRIX6_5)
-#include <optional_sym.h>
-#else
-extern int              nAgents;        /* from pmcd/src/config.c */
+#include <sys/stat.h>
+#if defined(HAVE_SYS_MMAN_H)
+#include <sys/mman.h>
 #endif
 
 /*
@@ -67,16 +43,6 @@ extern int              nAgents;        /* from pmcd/src/config.c */
  */
 #define _TOTAL			16
 
-extern int		errno;
-extern unsigned int	__pmPDUCntIn[];
-extern unsigned int	__pmPDUCntOut[];
-extern int		pmDebug;	/* pmcd's debug flag */
-
-/* from pmcd's address space, not in headers */
-extern int		_pmcd_done;	/* pending request to terminate */
-extern char		*_pmcd_data;	/* base size of data */
-extern int		_pmcd_trace_nbufs;	/* number of trace buffers */
-
 /*
  * all metrics supported in this PMD - one table entry for each
  */
@@ -258,6 +224,9 @@ typedef struct {
     pid_t	pid;
     int		size;
     char	*name;
+#ifdef IS_MINGW
+    HANDLE	hdl;
+#endif
     void	*mmap;
 } pmie_t;
 static pmie_t		*pmies;
@@ -277,49 +246,6 @@ static struct {
 };
 static int	nbufsz = sizeof(bufinst) / sizeof(bufinst[0]);
 
-#if defined(HAVE_PROCFS_PINFO)
-#define PROCFS_INFO	"/proc/pinfo"	/* from proc pmda - proc.h */
-#elif defined(HAVE_PROCFS)
-#define PROCFS_INFO	"/proc"
-#elif !defined(IS_DARWIN)
-!bozo!
-#endif
-
-#if defined(HAVE_PROCFS_PINFO) || defined(HAVE_PROCFS)
-#define PROCFS_ENTRYLEN	20		/* from proc pmda - proc.h */
-#define PROCFS_PATHLEN	(sizeof(PROCFS_INFO)+PROCFS_ENTRYLEN)
-
-static int
-exists_process(pid_t pid)
-{
-    static char proc_buf[PROCFS_PATHLEN];
-
-    sprintf(proc_buf, "%s/%u", PROCFS_INFO, (int)pid);
-    return (access(proc_buf, F_OK) == 0);
-}
-
-#elif defined(IS_DARWIN)	/* No procfs on Mac OS X */
-#include <sys/sysctl.h>
-
-static int
-exists_process(pid_t pid)
-{
-    struct kinfo_proc kp;
-    size_t len = sizeof(kp);
-    int mib[4];
-
-    mib[0] = CTL_KERN;
-    mib[1] = KERN_PROC;
-    mib[2] = KERN_PROC_PID;
-    mib[3] = pid;
-    if (sysctl(mib, 4, &kp, &len, NULL, 0) == -1)
-	return 0;
-    return (len > 0);
-}
-#else
-!bozo!
-#endif
-
 /*
  * this routine is called at initialization to patch up any parts of the
  * desctab that cannot be statically initialized, and to optionally
@@ -373,7 +299,6 @@ init_tables(int dom)
 }
 
 
-/*ARGSUSED*/
 static int
 pmcd_profile(__pmProfile *prof, pmdaExt *pmda)
 {
@@ -388,7 +313,12 @@ remove_pmie_indom(void)
 
     for (n = 0; n < npmies; n++) {
 	free(pmies[n].name);
+#ifdef IS_MINGW
+	UnmapViewOfFile(pmies[n].mmap);
+	CloseHandle(pmies[n].hdl);
+#else /* POSIX */
 	munmap(pmies[n].mmap, pmies[n].size);
+#endif
     }
     free(pmies);
     pmies = NULL;
@@ -409,6 +339,9 @@ refresh_pmie_indom(void)
     void		*ptr;
     DIR			*pmiedir;
     int			fd;
+#ifdef IS_MINGW
+    HANDLE		hdl;
+#endif
 
     if (stat(PMIE_DIR, &statbuf) == 0) {
 #if defined(HAVE_ST_MTIME_WITH_E) && defined(HAVE_STAT_TIME_T)
@@ -441,7 +374,7 @@ refresh_pmie_indom(void)
 		pmiepid = (pid_t)strtoul(dp->d_name, &endp, 10);
 		if (*endp != '\0')	/* skips over "." and ".." here */
 		    continue;
-		if (!exists_process(pmiepid))
+		if (!__pmProcessExists(pmiepid))
 		    continue;
 		snprintf(fullpath, sizeof(fullpath), "%s/%s", PMIE_DIR, dp->d_name);
 		if (stat(fullpath, &statbuf) < 0) {
@@ -466,25 +399,49 @@ refresh_pmie_indom(void)
 		    free(endp);
 		    continue;
 		}
+#ifdef IS_MINGW
+		hdl = CreateFileMapping((HANDLE)_get_osfhandle(fd),
+				NULL, PAGE_READONLY, 0, statbuf.st_size, NULL);
+		if (hdl == INVALID_HANDLE_VALUE) {
+		    __pmNotifyErr(LOG_ERR, "pmcd pmda mapping of %s failed: %s",
+				fullpath, strerror(errno));
+		    free(endp);
+		    close(fd);
+		    continue;
+		}
+		ptr = MapViewOfFile(hdl, FILE_MAP_READ, 0, 0, statbuf.st_size);
+#else /* POSIX */
 		ptr = mmap(NULL, statbuf.st_size, PROT_READ, MAP_SHARED, fd, 0);
+#endif
 		close(fd);
 		if (ptr == MAP_FAILED) {
 		    __pmNotifyErr(LOG_ERR, "pmcd pmda mmap of %s failed: %s",
 				fullpath, strerror(errno));
+#ifdef IS_MINGW
+		    CloseHandle(hdl);
+#endif
 		    free(endp);
 		    continue;
 		}
 		else if (((pmiestats_t *)ptr)->version != 1) {
 		    __pmNotifyErr(LOG_WARNING, "incompatible pmie version: %s",
 				fullpath);
+#ifdef IS_MINGW
+		    UnmapViewOfFile(ptr);
+		    CloseHandle(hdl);
+#else
 		    munmap(ptr, statbuf.st_size);
+#endif
 		    free(endp);
 		    continue;
 		}
 		pmies[npmies].pid = pmiepid;
+		pmies[npmies].name = endp;
 		pmies[npmies].size = statbuf.st_size;
 		pmies[npmies].mmap = ptr;
-		pmies[npmies].name = endp;
+#ifdef IS_MINGW
+		pmies[npmies].hdl  = hdl;
+#endif
 		npmies++;
 	    }
 	    closedir(pmiedir);
@@ -653,7 +610,6 @@ pmcd_instance_pool(int inst, char *name, __pmInResult **result)
     return 0;
 }
 
-/*ARGSUSED*/
 static int
 pmcd_instance(pmInDom indom, int inst, char *name, __pmInResult **result, pmdaExt *pmda)
 {
@@ -912,7 +868,30 @@ vset_resize(pmResult *rp, int i, int onumval, int numval)
     return 0;
 }
 
-/*ARGSUSED*/
+static char *
+simabi()
+{
+#if defined(__linux__) 
+# if defined(__i386__)
+    return "ia32";
+# elif defined(__ia64__) || defined(__ia64)
+    return "ia64";
+# else
+    return SIM_ABI;	/* SIM_ABI is defined in the linux Makefile */
+# endif /* __linux__ */
+#elif defined(IS_SOLARIS) || defined(IS_INTERIX) || defined(IS_FREEBSD)
+    return "elf";
+#elif defined(IS_DARWIN)
+    return "Mach-O";
+#elif defined(IS_CYGWIN) || defined(IS_MINGW)
+    return "i386";
+#elif defined(IS_AIX)
+    return "powerpc";
+#else
+    !!! bozo : dont know which executable format pmcd should be!!!
+#endif
+}
+
 static int
 pmcd_fetch(int numpmid, pmID pmidlist[], pmResult **resp, pmdaExt *pmda)
 {
@@ -922,6 +901,7 @@ pmcd_fetch(int numpmid, pmID pmidlist[], pmResult **resp, pmdaExt *pmda)
     int			need;
     int			numval;
     int			valfmt;
+    unsigned long	datasize;
     static pmResult	*res = NULL;
     static int		maxnpmids = 0;
     static char		*hostname = NULL;
@@ -985,7 +965,8 @@ pmcd_fetch(int numpmid, pmID pmidlist[], pmResult **resp, pmdaExt *pmda)
 				atom.l = pmDebug;
 				break;
 			case 1:		/* datasize */
-				atom.ul = (int)((__psint_t)sbrk(0) - (__psint_t)_pmcd_data) / 1024;
+				__pmProcessDataSize(&datasize);
+				atom.ul = datasize;
 				break;
 			case 2:		/* numagents */
 				atom.ul = 0;
@@ -1003,51 +984,11 @@ pmcd_fetch(int numpmid, pmID pmidlist[], pmResult **resp, pmdaExt *pmda)
 				atom.ul = _pmcd_timeout;
 				break;
 			case 5:		/* timezone $TZ */
-#if defined(IRIX6_5)
-				if (_MIPS_SYMBOL_PRESENT(__pmTimezone))
-				    tz = __pmTimezone();
-				else
-				    tz = getenv("TZ");
-#else
 				tz = __pmTimezone();
-#endif
 				atom.cp = tz;
 				break;
 			case 6:		/* simabi (pmcd calling convention) */
-				atom.cp =
-#if defined(_MIPS_SIM)
-
-#if   _MIPS_SIM == _MIPS_SIM_ABI32
-				    "o32";
-#elif _MIPS_SIM == _MIPS_SIM_NABI32
-				    "n32";
-#elif _MIPS_SIM == _MIPS_SIM_ABI64
-				    "64";
-#else
-    !!! bozo : dont know which MIPS executable format pmcd should be!!!
-#endif
-
-#elif defined(__linux__) 
-#if defined(__i386__)
-				    "ia32";
-#elif defined(__ia64__) || defined(__ia64)
-				    "ia64";
-#else
-				    /* SIM_ABI is defined in the linux Makefile */
-				    SIM_ABI;
-#endif /* __linux__ */
-
-#elif defined(IS_SOLARIS) || defined(IS_INTERIX) || defined(IS_FREEBSD)
-				    "elf";
-#elif defined(IS_DARWIN)
-				    "Mach-O";
-#elif defined(IS_CYGWIN)
-				    "i386";
-#elif defined(IS_AIX)
-				    "powerpc";
-#else
-    !!! bozo : dont know which executable format pmcd should be!!!
-#endif
+				atom.cp = simabi();
 				break;
 			case 7:		/* version */
 				atom.cp = PCP_VERSION;
@@ -1098,15 +1039,8 @@ pmcd_fetch(int numpmid, pmID pmidlist[], pmResult **resp, pmdaExt *pmda)
 			case 15:	/* sighup ... always 0 */
 				atom.l = 0;
 				break;
-			case 16:	/* license */
-				/*
-				 * be careful about errors, and
-				 * strip the PM_LIC_PCP bit as this is
-				 * redundant
-				 */
-				j = __pmGetLicenseCap();
-				if (j < 0) j = 0;
-				atom.l = j & (~0x4);
+			case 16:	/* license - hysterical raisins */
+				atom.l = 0;
 				break;
 			case 17:	/* openfds */
 				atom.ul = (unsigned int)pmcd_hi_openfds;
@@ -1132,39 +1066,12 @@ pmcd_fetch(int numpmid, pmID pmidlist[], pmResult **resp, pmdaExt *pmda)
 				    vset->vlist[numval].inst = bufinst[j].inst;
 				    if (bufinst[j].inst < 1024) {
 					/* PoolAlloc pool */
-#if defined(IRIX6_5)
-					if (_MIPS_SYMBOL_PRESENT(__pmPoolCount))
-					    __pmPoolCount(bufinst[j].inst, &alloced, &free);
-					else
-					    alloced = free = -1;
-#else
 					__pmPoolCount(bufinst[j].inst, &alloced, &free);
-#endif
 				    }
 				    else {
 					/* PDUBuf pool */
 					int	xtra_alloced;
 					int	xtra_free;
-#if defined(IRIX6_5)
-					if (_MIPS_SYMBOL_PRESENT(__pmCountPDUBuf)) {
-					    __pmCountPDUBuf(bufinst[j].inst, &alloced, &free);
-					    if (bufinst[j].inst <= 8192) {
-						/*
-						 * adjust for larger buffers,
-						 * e.g. the 2K buffer count
-						 * also includes the 3K, 4K, ..
-						 * buffers, so subtract these,
-						 * which are reported as the
-						 * 2K+1 buffer count
-						 */
-						__pmCountPDUBuf(bufinst[j].inst + 1, &xtra_alloced, &xtra_free);
-						alloced -= xtra_alloced;
-						free -= xtra_free;
-					    }
-					}
-					else
-					    alloced = free = -1;
-#else
 					__pmCountPDUBuf(bufinst[j].inst, &alloced, &free);
 					/*
 					 * the 2K buffer count also includes
@@ -1175,7 +1082,6 @@ pmcd_fetch(int numpmid, pmID pmidlist[], pmResult **resp, pmdaExt *pmda)
 					__pmCountPDUBuf(bufinst[j].inst + 1024, &xtra_alloced, &xtra_free);
 					alloced -= xtra_alloced;
 					free -= xtra_free;
-#endif
 				    }
 				    if (pmidp->item == 18)
 					atom.l = alloced;
@@ -1413,7 +1319,6 @@ pmcd_fetch(int numpmid, pmID pmidlist[], pmResult **resp, pmdaExt *pmda)
     return 0;
 }
 
-/*ARGSUSED*/
 static int
 pmcd_desc(pmID pmid, pmDesc *desc, pmdaExt *pmda)
 {
@@ -1428,7 +1333,6 @@ pmcd_desc(pmID pmid, pmDesc *desc, pmdaExt *pmda)
     return PM_ERR_PMID;
 }
 
-/*ARGSUSED*/
 static int
 pmcd_store(pmResult *result, pmdaExt *pmda)
 {
@@ -1519,11 +1423,13 @@ pmcd_store(pmResult *result, pmdaExt *pmda)
 		}
 	    }
 	    else if (pmidp->item == 15) { /* pmcd.control.sighup */
+#ifdef HAVE_SIGHUP
 		/*
 		 * send myself SIGHUP
 		 */
 		__pmNotifyErr(LOG_INFO, "pmcd reset via pmcd.control.sighup");
-		kill(getpid(), SIGHUP);
+		raise(SIGHUP);
+#endif
 	    }
 	    else {
 		sts = PM_ERR_PMID;
@@ -1543,16 +1449,12 @@ pmcd_store(pmResult *result, pmdaExt *pmda)
 void
 pmcd_init(pmdaInterface *dp)
 {
-#ifdef __sgi
-    char * helppath = "/usr/pcp/pmdas/pmcd/help";
-#else
     char helppath[MAXPATHLEN];
  
-    snprintf(helppath, sizeof(helppath), "%s/pmdas/pmcd/help", pmGetConfig("PCP_VAR_DIR"));
-#endif
+    snprintf(helppath, sizeof(helppath), "%s/pmdas/pmcd/help",
+	 	pmGetConfig("PCP_VAR_DIR"));
     pmdaDSO(dp, PMDA_INTERFACE_2, "pmcd", helppath);
 
-
     dp->version.two.profile = pmcd_profile;
     dp->version.two.fetch = pmcd_fetch;
     dp->version.two.desc = pmcd_desc;
@@ -1562,8 +1464,6 @@ pmcd_init(pmdaInterface *dp)
     init_tables(dp->domain);
 
     pmdaInit(dp, NULL, 0, NULL, 0);
-
-    return;
 }
 
 #ifdef DEBUG_WITH_DBPMDA
