@@ -14,39 +14,16 @@
  * You should have received a copy of the GNU General Public License along
  * with this program; if not, write to the Free Software Foundation, Inc.,
  * 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
- * 
- * Contact information: Silicon Graphics, Inc., 1500 Crittenden Lane,
- * Mountain View, CA 94043, USA, or: http://www.sgi.com
- * 
  */
 
-#ident "$Id: sample.c,v 2.63 2006/06/30 05:47:11 makc Exp $"
-
-#include <unistd.h>
-#include <stdio.h>
-#include <syslog.h>
-#include <errno.h>
-#include <sys/param.h>
-#include <sys/types.h>
-#include <time.h>
-#include <fcntl.h>
-#include <errno.h>
-#include <sys/stat.h>
-#include <limits.h>
 #include "pmapi.h"
 #include "impl.h"
 #include "pmda.h"
+#include <limits.h>
+#include <sys/stat.h>
 #include "../domain.h"
-
 #ifdef HAVE_SYSINFO
-#if defined(sgi)
-#include <sys/sysmp.h>
 #include <sys/sysinfo.h>
-#elif defined(linux)
-#include <sys/sysinfo.h>
-#else
-bozo!  ... you claim to have sysinfo(), where is the .h file?
-#endif
 #else
 static struct sysinfo {
     char	dummy[64];
@@ -62,8 +39,6 @@ int	sample_done=0;	/* pending request to terminate, see sample_store() */
 int	need_mirage=0;	/* only do mirage glop is someone asks for it */
 int	need_dynamic=0;	/* only do dynamic glop is someone asks for it */
 
-extern int	errno;
-
 /* from pmda.c: simulate PMDA busy */
 extern int	limbo(void);
 
@@ -485,8 +460,6 @@ static __uint32_t	const_rate_gradient = 0;
 static __uint32_t	const_rate_value = 10485760;
 static struct timeval	const_rate_timestamp = {0,0};
 
-static char		*pmda_data;
-
 /* this needs to be visible in pmda.c */
 int			not_ready = 0;	/* sleep interval in seconds */
 
@@ -972,15 +945,10 @@ init_tables(int dom)
     _len35 = 2;
     _aggr35 = (char *)malloc(_len35);
     memcpy(_aggr35, "13", _len35);
-#ifdef MALLOC_AUDIT
-    _persistent_(_string);
-    _persistent_(_aggr34);
-    _persistent_(_aggr35);
-#endif
-	(void)redo_many();
+
+    (void)redo_many();
 }
 
-/*ARGSUSED2*/
 static int
 sample_profile(__pmProfile *prof, pmdaExt *ep)
 {
@@ -989,7 +957,6 @@ sample_profile(__pmProfile *prof, pmdaExt *ep)
     return 0;
 }
 
-/*ARGSUSED5*/
 static int
 sample_instance(pmInDom indom, int inst, char *name, __pmInResult **result, pmdaExt *ep)
 {
@@ -1114,10 +1081,6 @@ sample_instance(pmInDom indom, int inst, char *name, __pmInResult **result, pmda
     return 0;
 }
 
-#if defined(sgi)
-#include <sgidefs.h>
-#endif
-
 /*
  * high precision counter
  */
@@ -1145,7 +1108,6 @@ _pmHPCincr(pmHPC_t *ctr, __uint32_t val)
 
 static pmHPC_t	rapid_ctr;
 
-/*ARGSUSED4*/
 static int
 sample_fetch(int numpmid, pmID pmidlist[], pmResult **resp, pmdaExt *ep)
 {
@@ -1156,16 +1118,17 @@ sample_fetch(int numpmid, pmID pmidlist[], pmResult **resp, pmdaExt *ep)
     int		inst;
     int		numval;
     int		aggregate_len = 0;
-    static pmResult	*res = NULL;
-    static int		maxnpmids = 0;
+    static pmResult	*res;
+    static int		maxnpmids;
+    static int		nbyte;
+    __uint32_t		*ulp;
+    unsigned long	ul;
+    struct timeval	now;
     pmValueSet	*vset;
     pmDesc	*dp;
     __pmID_int	*pmidp;
-    __uint32_t	*ulp;
     pmAtomValue	atom;
     int		type;
-    struct timeval	now;
-    static int	nbyte = 0;
 
     _recv_pdu++;
     _xmit_pdu++;
@@ -1429,14 +1392,8 @@ doit:
 			sivb->vtype = PM_TYPE_AGGREGATE;
 		    }
 
-
 #ifdef HAVE_SYSINFO
-#ifdef sgi
-		    sysmp(MP_SAGET, MPSA_SINFO, (struct sysinfo *)sivb->vbuf, 
-			  sizeof(struct sysinfo));
-#else
-                    sysinfo((struct sysinfo *)sivb->vbuf);
-#endif
+		    sysinfo((struct sysinfo *)sivb->vbuf);
 #else
 		    strncpy((char *)sivb->vbuf, si.dummy, sizeof(struct sysinfo));
 #endif
@@ -1794,7 +1751,8 @@ doit:
 		    atom.ul = *ulp;
 		    break;
 		case 91:	/* datasize */
-		    atom.ul = (int)((__psint_t)sbrk(0) - (__psint_t)pmda_data) / 1024;
+		    __pmProcessDataSize(&ul);
+		    atom.ul = ul;
 		    break;
 		case 1023: /* bigid */
 		    atom.l = 4194303;
@@ -1818,7 +1776,6 @@ done:
     return 0;
 }
 
-/*ARGSUSED3*/
 static int
 sample_desc(pmID pmid, pmDesc *desc, pmdaExt *ep)
 {
@@ -1857,7 +1814,6 @@ doit:
     return PM_ERR_PMID;
 }
 
-/*ARGSUSED4*/
 static int
 sample_text(int ident, int type, char **buffer, pmdaExt *ep)
 {
@@ -1897,7 +1853,6 @@ doit:
     return sts;
 }
 
-/*ARGSUSED2*/
 static int
 sample_store(pmResult *result, pmdaExt *ep)
 {
@@ -2083,16 +2038,16 @@ sample_store(pmResult *result, pmdaExt *ep)
 
 void sample_init(pmdaInterface *dp)
 {
-
-    char	helppath[MAXPATHLEN];
-
-    /* base of data segment */
-    pmda_data = sbrk(0);
+    char helppath[MAXPATHLEN];
 
     if (_isDSO) {
-	snprintf(helppath, sizeof(helppath), "%s/pmdas/sample/dsohelp", pmGetConfig("PCP_VAR_DIR"));
+	snprintf(helppath, sizeof(helppath), "%s/pmdas/sample/dsohelp",
+			pmGetConfig("PCP_VAR_DIR"));
 	pmdaDSO(dp, PMDA_INTERFACE_2, "sample DSO", helppath);
     }
+    else {
+	__pmProcessDataSize(NULL);
+    }
 
     if (dp->status != 0)
 	return;
