@@ -16,32 +16,17 @@
  * You should have received a copy of the GNU General Public License along
  * with this program; if not, write to the Free Software Foundation, Inc.,
  * 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
- * 
- * Contact information: Silicon Graphics, Inc., 1500 Crittenden Lane,
- * Mountain View, CA 94043, USA, or: http://www.sgi.com
  */
 
-#ident "$Id: pmda.c,v 2.23 2004/06/20 22:38:25 kenmcd Exp $"
-
-#include "pmapi.h"
-
-#include "./weblog.h"
-#include <stdio.h>
-/*
- * see comment in weblog.h re: NON_POSIX_REGEX
- */
+#include "weblog.h"
+#include "domain.h"
+#if defined(HAVE_REGEX_H)
 #include <regex.h>
-#include <sys/socket.h>
+#endif
+#if defined(HAVE_SYS_WAIT_H)
 #include <sys/wait.h>
-#include <netinet/in.h>
-#include <netinet/tcp.h>
-#include <sys/un.h>
-#include <netdb.h>
-#include <signal.h>
-#include <string.h>
-#include <errno.h>
-
-#ifdef HAVE_SCHED_H
+#endif
+#if defined(HAVE_SCHED_H)
 #include <sched.h>
 #endif
 
@@ -55,8 +40,6 @@
 int sproc (void (*entry) (void *), int flags, void *arg);
 #endif
 
-#include "domain.h"
-
 /* path to the configuration file */
 static char	*configFileName = (char*)0;
 
@@ -96,9 +79,6 @@ WebRegex	*wl_regexTable = (WebRegex*)0;
 /* instance table of web servers */
 pmdaInstid	*wl_serverInst = (pmdaInstid*)0;
 
-/* pmAPI hack to piggy back requestes from PMCD */
-extern int _pm_moreinput;
-
 /* list of sprocs spawned from the main process */
 WebSproc	*wl_sproc;
 
@@ -148,9 +128,6 @@ logmessage(int priority, const char *format, ...)
     buffer[0] = '\0';
     time(&now);
 
-#if defined(sgi)
-    priority = LOG_PRI(priority);
-#endif
     switch (priority) {
         case LOG_EMERG :
             level = "Emergency";
@@ -374,7 +351,6 @@ receivePDUs(pmdaInterface *dispatch)
 
 	if (__pmdaMainPDU(dispatch) < 0){
 	    exit(1);
-	    /*NOTREACHED*/
 	}
 
 	if (interval == 0) {
@@ -388,7 +364,6 @@ receivePDUs(pmdaInterface *dispatch)
  * Catch an SPROC dying, report what we know, and exit
  * -- when main exits, other sprocs will get SIGHUP and exit quietly
  */
-/*ARGSUSED0*/
 static void
 onchld(int dummy)
 {
@@ -457,10 +432,6 @@ onchld(int dummy)
 int
 main(int argc, char **argv)
 {
-    extern char		*optarg;
-    extern int		optind;
-    extern int		pmDebug;
-
     WebServer		*server = (WebServer *)0;
     WebSproc		*proc = (WebSproc *)0;
 
@@ -468,7 +439,6 @@ main(int argc, char **argv)
     char		buf1[FILENAME_MAX];
     char		buf2[FILENAME_MAX];
     char		emess[120];
-    char		*p;
     char		*pstart, *pend;
     char		argsDone, argFound;
     char		*err_msg;
@@ -498,12 +468,7 @@ main(int argc, char **argv)
     double		startTime;
 #endif
 
-    /* trim cmd name of leading directory components */
-    pmProgname = argv[0];
-    for (p = pmProgname; *p; p++) {
-	if (*p == '/')
-	    pmProgname = p+1;
-    }
+    __pmSetProgname(argv[0]);
 
 #ifdef PCP_DEBUG
     gettimeofday(&start, NULL);
@@ -568,7 +533,6 @@ main(int argc, char **argv)
 
     if (err || optind != argc-1) {
     	usage();
-	/*NOTREACHED*/
     }
 
     line = 0;
@@ -578,7 +542,6 @@ main(int argc, char **argv)
     if (configFile == (FILE*)0) {
 	fprintf(stderr, "Unable to open config file %s\n", configFileName);
     	usage();
-	/*NOTREACHED*/
     }
 
     if (checkOnly == 0) {
@@ -633,7 +596,6 @@ main(int argc, char **argv)
 		    __pmNoMem("main.wl_regexInst", 
 			     (wl_numRegex + 1) * sizeof(WebRegex),
 			     PM_FATAL_ERR);
-		    /*NOTREACHED*/
 		}
 	    }
 
@@ -754,7 +716,6 @@ main(int argc, char **argv)
 		__pmNoMem("main.wl_regex", 
 			  sizeof(*wl_regexTable[wl_numRegex].regex),
 			  PM_FATAL_ERR);
-		/*NOTREACHED*/
 	    }
 
 	    if (regcomp(wl_regexTable[wl_numRegex].regex, buf1, REG_EXTENDED) != 0) {
@@ -785,7 +746,6 @@ main(int argc, char **argv)
 		    __pmNoMem("main.wl_regexInst", 
 			     (wl_numRegex + 1) * sizeof(WebRegex),
 			     PM_FATAL_ERR);
-		    /*NOTREACHED*/
 		}
 	    }
 
@@ -869,7 +829,6 @@ main(int argc, char **argv)
 		    __pmNoMem("main.wl_serverInst", 
 			     (wl_numServers + 1) * sizeof(pmdaInstid),
 			     PM_FATAL_ERR);
-		    /*NOTREACHED*/
 		}
 
 		wl_servers = (WebServer*)realloc(wl_servers,
@@ -878,7 +837,6 @@ main(int argc, char **argv)
 		    __pmNoMem("main.wl_servers", 
 			     (wl_numServers + 1) * sizeof(WebServer),
 			     PM_FATAL_ERR);
-		    /*NOTREACHED*/
 		}
 	    }
 
@@ -1101,7 +1059,6 @@ main(int argc, char **argv)
 	__pmNoMem("main.wl_sproc", 
 		  (wl_numSprocs+1) * sizeof(WebSproc),
 		  PM_FATAL_ERR);
-	/*NOTREACHED*/
     }
 
 
