@@ -15,13 +15,10 @@
 # You should have received a copy of the GNU General Public License along
 # with this program; if not, write to the Free Software Foundation, Inc.,
 # 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
-# 
-# Contact information: Silicon Graphics, Inc., 1500 Crittenden Lane,
-# Mountain View, CA 94043, USA, or: http://www.sgi.com
 #
 
 # Get standard environment
-. /etc/pcp.env
+. $PCP_DIR/etc/pcp.env
 
 # Setup some default paths 
 
@@ -58,7 +55,6 @@ esac
 #			  "copy"  - copy the files
 #			  "skip"  - do not create URLs for this server
 #
-# $Id: server.sh,v 2.44 2004/05/20 02:12:57 kenmcd Exp $
 
 do_logs=false
 do_files=false
