@@ -14,27 +14,13 @@
  * You should have received a copy of the GNU General Public License along
  * with this program; if not, write to the Free Software Foundation, Inc.,
  * 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
- * 
- * Contact information: Silicon Graphics, Inc., 1500 Crittenden Lane,
- * Mountain View, CA 94043, USA, or: http://www.sgi.com
  */
 
-#ident "$Id: pmdumplog.c,v 1.5 2004/06/16 23:33:34 nathans Exp $"
-
-#include <stdio.h>
-#include <sys/types.h>
-#include <sys/stat.h>
-#include <sys/param.h>
-#include <ctype.h>
-#include <string.h>
-#include <errno.h>
-#include <syslog.h>
-#include <time.h>
-#include <limits.h>
 #include "pmapi.h"
 #include "impl.h"
-
-extern int	errno;
+#include <ctype.h>
+#include <limits.h>
+#include <sys/stat.h>
 
 static struct timeval	tv;
 static int		numpmid;
@@ -304,9 +290,10 @@ rawdump(FILE *f)
     int		sts;
 
     old = ftell(f);
-    fseek(f, 0, SEEK_SET);
+    fseek(f, (long)0, SEEK_SET);
 
     while ((sts = fread(&len, 1, sizeof(len), f)) == sizeof(len)) {
+	len = ntohl(len);
 	printf("Dump ... record len: %d @ offset: %ld", len, ftell(f) - sizeof(len));
 	len -= 2 * sizeof(len);
 	for (i = 0; i < len; i++) {
@@ -317,7 +304,7 @@ rawdump(FILE *f)
 	    }
 	    if (i % 32 == 0) putchar('\n');
 	    if (i % 4 == 0) putchar(' ');
-	    printf("%02x", check &0xff);
+	    printf("%02x", check & 0xff);
 	}
 	putchar('\n');
 	if ((sts = fread(&check, 1, sizeof(check), f)) != sizeof(check)) {
@@ -325,6 +312,7 @@ rawdump(FILE *f)
 		printf("Unexpected EOF\n");
 	    break;
 	}
+	check = ntohl(check);
 	len += 2 * sizeof(len);
 	if (check != len) {
 	    printf("Trailer botch: %d != %d\n", check, len);
@@ -388,16 +376,8 @@ main(int argc, char *argv[])
     char		timebuf[32];		/* for pmCtime result + .xxx */
     double		current;
     double		done;
-    extern char		*optarg;
-    extern int		optind;
-    extern int		pmDebug;
 
-    /* trim cmd name of leading directory components */
-    pmProgname = argv[0];
-    for (p = pmProgname; *p; p++) {
-	if (*p == '/')
-	    pmProgname = p+1;
-    }
+    __pmSetProgname(argv[0]);
 
     while ((c = getopt(argc, argv, "aD:dilLmn:rS:sT:tv:Z:z?")) != EOF) {
 	switch (c) {
@@ -708,5 +688,4 @@ main(int argc, char *argv[])
     }
 
     exit(0);
-    /*NOTREACHED*/
 }
