@@ -1,5 +1,4 @@
 #! /bin/sh
-#Tag 0x00010D13
 #
 # Copyright (c) 1998-2000,2003 Silicon Graphics, Inc.  All Rights Reserved.
 # 
@@ -17,17 +16,12 @@
 # with this program; if not, write to the Free Software Foundation, Inc.,
 # 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 # 
-# Contact information: Silicon Graphics, Inc., 1500 Crittenden Lane,
-# Mountain View, CA 94043, USA, or: http://www.sgi.com
-# 
-# $Id: pmie_check.sh,v 1.9 2005/01/19 00:04:20 kenmcd Exp $
-#
 # Administrative script to check pmie processes are alive, and restart
 # them as required.
 #
 
 # Get standard environment
-. /etc/pcp.env
+. $PCP_DIR/etc/pcp.env
 
 PMIE=pmie
 
@@ -256,38 +250,6 @@ _check_pmie_version()
 You seem to have mixed versions in your Performance Co-Pilot (PCP)
 installation, such that pmie(1) is incompatible with pmie_check(1).
 EOF
-	if [ "$PCP_PLATFORM" = "irix" ]
-	then
-	    #
-	    # The following only makes sense on IRIX
-	    #
-	    echo
-	    showfiles pcp\* \
-	    | $PCP_AWK_PROG '/bin\/pmie$/ {print $4}' >$tmp.subsys
-
-	    if [ -s $tmp.subsys ]
-	    then
-		echo "Currently $binary is installed from these subsystem(s):"
-		echo
-		versions `cat $tmp.subsys` </dev/null
-		echo
-	    else
-		echo "The current installation history does not identify the subsystem(s)"
-		echo "where $binary was installed from."
-		echo
-	    fi
-
-	    case `uname -r`
-	    in
-		6.5*)
-		    echo "Please upgrade pcp_eoe from the IRIX 6.5.5 (or later) distribution."
-		    ;;
-		*)
-		    echo "Please upgrade pcp_eoe from the PCP 2.1 (or later) distribution."
-		    ;;
-	    esac
-	fi
-
 	status=1
 	exit
     fi
@@ -529,6 +491,18 @@ NR == 3	{ printf "p_pmcd_host=\"%s\"\n", $0; next }
 	fi
     done
 
+    if $VERY_VERBOSE
+    then
+	if [ -z "$pid" ]
+	then
+	    echo "No current pmie process exists for:"
+	else
+	    echo "Found pmie process $pid monitoring:"
+	fi
+	echo "    host = $fqdn"
+	echo "    log file = $logfile"
+    fi
+
     if [ -z "$pid" -a $START_PMIE = true ]
     then
 	configfile=`echo $args | sed -n -e 's/^/ /' -e 's/[ 	][ 	]*/ /g' -e 's/-c /-c/' -e 's/.* -c\([^ ]*\).*/\1/p'`
