@@ -1,5 +1,4 @@
 #! /bin/sh
-#Tag 0x00010D13
 #
 # Copyright (c) 1995-2000,2003 Silicon Graphics, Inc.  All Rights Reserved.
 # Portions Copyright (c) 2007 Aconex.  All Rights Reserved.
@@ -18,14 +17,11 @@
 # with this program; if not, write to the Free Software Foundation, Inc.,
 # 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 #
-# Contact information: Silicon Graphics, Inc., 1500 Crittenden Lane,
-# Mountain View, CA 94043, USA, or: http://www.sgi.com
-#
 # Example daily administrative script for pmie logfiles
 #
 
 # Get standard environment
-. /etc/pcp.env
+. $PCP_DIR/etc/pcp.env
 
 # Get the portable PCP rc script functions
 if [ -f $PCP_SHARE_DIR/lib/rc-proc.sh ] ; then
@@ -493,7 +489,8 @@ then
     do
 	[ -f $file ] && logs="$logs $file"
     done
-    grep -v ' OK ' $logs | $MAIL -s "PMIE summary for $LOCALHOSTNAME" $MAILME
+    egrep -v '( OK | OK$|^$)' $logs | \
+	$MAIL -s "PMIE summary for $LOCALHOSTNAME" $MAILME
     rm -f $tmp.mail
 fi
 
