@@ -17,13 +17,8 @@
  * You should have received a copy of the GNU General Public License along
  * with this program; if not, write to the Free Software Foundation, Inc.,
  * 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
- * 
- * Contact information: Silicon Graphics, Inc., 1500 Crittenden Lane,
- * Mountain View, CA 94043, USA, or: http://www.sgi.com
  */
 
-#ident "$Id: dstruct.c,v 1.11 2007/02/20 00:13:43 kimbrr Exp $"
-
 #include <stdio.h>
 #include <stdlib.h>
 #include <ctype.h>
@@ -84,7 +79,6 @@ int		isdaemon = 0;			/* run as a daemon */
 int		agent = 0;			/* secret agent mode? */
 int		applet = 0;			/* applet mode? */
 int		dowrap = 0;			/* counter wrap? default no */
-int		licensed = 0;			/* pmie licensed? default no */
 pmiestats_t	*perf;				/* live performance data */
 pmiestats_t	instrument;			/* used if no mmap (archive) */
 
@@ -305,7 +299,6 @@ alloc(size_t size)
 
     if ((p = malloc(size)) == NULL) {
 	__pmNoMem("pmie.alloc", size, PM_FATAL_ERR);
-	/*NOTREACHED*/
     }
     return p;
 }
@@ -318,7 +311,6 @@ zalloc(size_t size)
 
     if ((p = calloc(1, size)) == NULL) {
 	__pmNoMem("pmie.zalloc", size, PM_FATAL_ERR);
-	/*NOTREACHED*/
     }
     return p;
 }
@@ -331,7 +323,6 @@ aalloc(size_t align, size_t size)
 
     if ((p = memalign(align, size)) == NULL) {
 	__pmNoMem("pmie.aalloc", size, PM_FATAL_ERR);
-	/*NOTREACHED*/
     }
     return p;
 }
@@ -344,7 +335,6 @@ ralloc(void *p, size_t size)
 
     if ((q = realloc(p, size)) == NULL) {
 	__pmNoMem("pmie.ralloc", size, PM_FATAL_ERR);
-	/*NOTREACHED*/
     }
     return q;
 }
@@ -356,7 +346,6 @@ sdup(char *p)
 
     if ((q = strdup(p)) == NULL) {
 	__pmNoMem("pmie.sdup", strlen(p), PM_FATAL_ERR);
-	/*NOTREACHED*/
     }
     return q;
 }
@@ -420,18 +409,6 @@ newHost(Task *owner, Symbol name)
 {
     Host *h = (Host *) zalloc(sizeof(Host));
 
-    if (!licensed && !archives) {
-	static char	*first_name = NULL;
-	if (first_name == NULL)
-	    first_name = sdup(symName(name));
-	else if (strcmp(symName(name), first_name) != 0) {
-	    fprintf(stderr, "Error: %s unlicensed - cannot create multiple host contexts without a valid\n"
-			    "       PCP Collector or Monitor license\n"
-			    "       (hosts \"%s\" and \"%s\")\n",
-			    pmProgname, first_name, symName(name));
-	    exit(1);
-	}
-    }
     h->name = symCopy(name);
     h->task = owner;
     return h;
