@@ -17,13 +17,8 @@
  * You should have received a copy of the GNU General Public License along
  * with this program; if not, write to the Free Software Foundation, Inc.,
  * 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
- * 
- * Contact information: Silicon Graphics, Inc., 1500 Crittenden Lane,
- * Mountain View, CA 94043, USA, or: http://www.sgi.com
  */
 
-#ident "$Id: eval.c,v 1.4 2007/02/20 00:13:43 kimbrr Exp $"
-
 #include <limits.h>
 #include <sys/syslog.h>
 #include "dstruct.h"
