@@ -17,13 +17,8 @@
  * You should have received a copy of the GNU General Public License along
  * with this program; if not, write to the Free Software Foundation, Inc.,
  * 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
- * 
- * Contact information: Silicon Graphics, Inc., 1500 Crittenden Lane,
- * Mountain View, CA 94043, USA, or: http://www.sgi.com
  */
 
-#ident "$Id: pmie.c,v 1.15 2007/02/20 00:13:43 kimbrr Exp $"
-
 /*
  * pmie debug flags:
  *	APPL0	- lexical scanning
@@ -378,7 +373,6 @@ startmonitor(void)
  * signal handling
  ***********************************************************************/
 
-/*ARGSUSED*/
 static void
 sigintproc(int sig)
 {
@@ -388,7 +382,6 @@ sigintproc(int sig)
     exit(1);
 }
 
-/*ARGSUSED*/
 static void
 sigbye(int sig)
 {
@@ -413,7 +406,6 @@ remap_stdout_stderr(void)
 			pmProgname, j, i, fileno(stderr));
 }
 
-/*ARGSUSED*/
 static void
 sighupproc(int sig)
 {
@@ -485,8 +477,6 @@ getargs(int argc, char *argv[])
     int			bflag = 0;
     Archive		*a;
     struct timeval	tv, tv1, tv2;
-    extern char		*optarg;
-    extern int		optind;
     extern int		showTimeFlag;
     extern int		errs;		/* syntax errors from syntax.c */
 
@@ -517,7 +507,6 @@ getargs(int argc, char *argv[])
 		a->fname = subopt;
 		if (!initArchive(a)) {
 		    exit(1);
-		    /*NOTREACHED*/
 		}
 		if (subopts == NULL) break;
 	    }
@@ -722,12 +711,6 @@ getargs(int argc, char *argv[])
     if (bflag || isdaemon)
 	remap_stdout_stderr();
 
-    if (__pmGetLicense(PM_LIC_MON, pmProgname,
-			GET_LICENSE_SHOW_EXP) == PM_LIC_MON ||
-	__pmGetLicense(PM_LIC_COL, pmProgname,
-			GET_LICENSE_SHOW_EXP) == PM_LIC_COL)
-	licensed = 1;
-
     if (dfltConn == 0) {
 	/* default case, no -a or -h */
 	dfltConn = PM_CONTEXT_HOST;
@@ -953,19 +936,9 @@ interact(void)
 int
 main(int argc, char **argv)
 {
-    char	*p;
-
-#ifdef __sgi
-    __pmSetAuthClient();
-#endif
-
+    __pmSetProgname(argv[0]);
     setlinebuf(stdout);
 
-    /* trim cmd name of leading directory components */
-    for (p = pmProgname = argv[0]; *p; p++)
-	if (*p == '/')
-	    pmProgname = p+1;
-
     /* PCP_COUNTER_WRAP in environment enables "counter wrap" logic */
     if (getenv("PCP_COUNTER_WRAP") != NULL)
 	dowrap = 1;
@@ -977,5 +950,4 @@ main(int argc, char **argv)
     else
 	run();
     exit(0);
-    /*NOTREACHED*/
 }
