@@ -17,33 +17,21 @@
  * with this program; if not, write to the Free Software Foundation, Inc.,
  * 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
  * 
- * Contact information: Silicon Graphics, Inc., 1500 Crittenden Lane,
- * Mountain View, CA 94043, USA, or: http://www.sgi.com
- * 
  * The analysis of how to organize the fetching of metrics (pragmatics),
  * and any other parts of the inference engine sensitive to details of
  * the PMAPI access are kept in this source file.
  */
 
-#ident "$Id: pragmatics.c,v 1.5 2004/06/20 22:38:25 kenmcd Exp $"
-
-#include <stdlib.h>
-#include <stdio.h>
-#include <sys/errno.h>
-#include <sys/syslog.h>
+#include <math.h>
 #include <ctype.h>
-#include <string.h>
-
 #include "pmapi.h"
 #include "impl.h"
 #include "dstruct.h"
 #include "eval.h"
 #include "pragmatics.h"
-
 #if defined(HAVE_IEEEFP_H)
 #include <ieeefp.h>
 #endif
-#include <math.h>
 
 int	dfltConn;	/* default context type */
 
@@ -84,12 +72,6 @@ newContext(char *host)
     Archive	*a;
     int		sts = -1;
 
-    if (!licensed && archives) {
-	fprintf(stderr, "Error: %s unlicensed - cannot create an archive "
-			"context without a valid PCP\n"
-			"       Collector or Monitor license.", pmProgname);
-	exit(1);
-    }
     if (archives) {
 	a = archives;
 	while (a) {	/* find archive for host */
