@@ -17,28 +17,18 @@
  * You should have received a copy of the GNU General Public License along
  * with this program; if not, write to the Free Software Foundation, Inc.,
  * 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
- * 
- * Contact information: Silicon Graphics, Inc., 1500 Crittenden Lane,
- * Mountain View, CA 94043, USA, or: http://www.sgi.com
  */
 
-#ident "$Id: show.c,v 1.5 2007/02/20 00:13:43 kimbrr Exp $"
-
-#include <stdio.h>
-#include <time.h>
+#include <math.h>
 #include <ctype.h>
-#include <string.h>
-
 #include "show.h"
 #include "impl.h"
 #include "dstruct.h"
 #include "lexicon.h"
 #include "pragmatics.h"
-
 #if defined(HAVE_IEEEFP_H)
 #include <ieeefp.h>
 #endif
-#include <math.h>
 
 /***********************************************************************
  * local declarations
