@@ -14,24 +14,11 @@
  * You should have received a copy of the GNU General Public License along
  * with this program; if not, write to the Free Software Foundation, Inc.,
  * 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
- * 
- * Contact information: Silicon Graphics, Inc., 1500 Crittenden Lane,
- * Mountain View, CA 94043, USA, or: http://www.sgi.com
  */
 
-#ident "$Id: actions.c,v 1.5 2006/05/02 05:57:28 makc Exp $"
-
-#include <stdio.h>
-#include <errno.h>
-#include <unistd.h>
-
 #include "pmapi.h"
 #include "impl.h"
-#include "./pmlc.h"
-
-#if defined(IRIX6_5)
-#include <optional_sym.h>
-#endif
+#include "pmlc.h"
 
 /* for the pmlogger/PMCD we currently have a connection to */
 static int	logger_fd = -1;			/* file desc pmlogger */
@@ -60,17 +47,11 @@ ConnectPMCD(void)
 {
     int			sts;
     __pmPDU		*pb;
-    __pmIPC		*ipc;
 
     if (src_ctx >= 0)
 	return src_ctx;
 
-    if ((sts = __pmFdLookupIPC(logger_fd, &ipc)) < 0) {
-	fprintf(stderr, "Logger connection badly initialised.\n");
-	return sts;
-    }
-
-    if (ipc->version >= LOG_PDU_VERSION2) {
+    if (__pmVersionIPC(logger_fd) >= LOG_PDU_VERSION2) {
 	__pmLoggerStatus	*lsp;
 #ifdef PCP_DEBUG
 	if (pmDebug & DBG_TRACE_PDU)
@@ -99,51 +80,6 @@ ConnectPMCD(void)
 	} 
 	srchost = strdup(lsp->ls_fqdn);
     }
-#ifdef HAVE_V1_SUPPORT
-    else {
-	int			subtype, vlen;
-	__pmLoggerStatus_v1	*lsp_v1;
-
-#ifdef PCP_DEBUG
-	if (pmDebug & DBG_TRACE_PDU)
-	    fprintf(stderr, "pmlc: sending version 1 datax status request\n");
-#endif
-	if ((sts = __pmSendDataX(logger_fd, PDU_BINARY, PMLC_PDU_STATUS_REQ,
-				0, NULL)) < 0) {
-	    fprintf(stderr, "Error sending request to pmlogger: ");
-	    if (still_connected(sts))
-		fprintf(stderr, "%s\n", pmErrStr(sts));
-	    return sts;
-	}
-	if ((sts = __pmGetPDU(logger_fd, PDU_BINARY, TIMEOUT_NEVER, &pb)) <= 0) {
-	    if (sts == 0)
-		/* end of file! */
-		sts = PM_ERR_IPC;
-	    fprintf(stderr, "Error receiving response from pmlogger: ");
-	    if (still_connected(sts))
-		fprintf(stderr, "%s\n", pmErrStr(sts));
-	    return sts;
-	}
-	if ((sts = __pmDecodeDataX(pb, PDU_BINARY, &subtype,
-			      &vlen, (void **)&lsp_v1)) < 0) {
-	    fprintf(stderr, "Error decoding response from pmlogger: ");
-	    if (still_connected(sts))
-		fprintf(stderr, "%s\n", pmErrStr(sts));
-	    goto done;
-	}
-	if (subtype != PMLC_PDU_STATUS || vlen != sizeof(__pmLoggerStatus_v1)) {
-	    fprintf(stderr, "Incorrect data from pmlogger (version mismatch?)\n"
-#ifdef PCP_DEBUG
-		"subtype=%d vlen=%d (expected %d)\n",
-		subtype, vlen, sizeof(__pmLoggerStatus_v1)
-#endif
-		);
-	    sts = PM_ERR_IPC;
-	    goto done;
-	}
-	srchost = strdup(lsp_v1->ls_hostname);
-    }
-#endif /* HAVE_V1_SUPPORT */
 
     if ((sts = pmNewContext(PM_CONTEXT_HOST, srchost)) < 0) {
 	/* no PMCD connection, we can't do anything, give up */
@@ -188,7 +124,6 @@ ConnectLogger(char *hostname, int *pid, int *port)
 	logger_fd = sts;
 	if ((lasthost = strdup(hostname)) == NULL) {
 	    __pmNoMem("Error copying host name", strlen(hostname), PM_FATAL_ERR);
-	    /*NOTREACHED*/
 	}
 	return 0;
     }
@@ -604,17 +539,11 @@ void Status(int pid, int primary)
     char		timenowbuf[TZBUFSZ];
     int			sts;
     __pmPDU		*pb;
-    __pmIPC		*ipc;
 
     if (!connected())
 	return;
 
-    if (__pmFdLookupIPC(logger_fd, &ipc) < 0) {
-	fprintf(stderr, "Logger connection badly initialised.\n");
-	return;
-    }
-
-    if (ipc->version >= LOG_PDU_VERSION2) {
+    if (__pmVersionIPC(logger_fd) >= LOG_PDU_VERSION2) {
 #ifdef PCP_DEBUG
 	if (pmDebug & DBG_TRACE_PDU)
 	    fprintf(stderr, "pmlc: sending version 2 status request\n");
@@ -649,70 +578,12 @@ void Status(int pid, int primary)
 	vol = lsp->ls_vol;
 	size = lsp->ls_size;
     }
-#ifdef HAVE_V1_SUPPORT
-    else {
-	int	subtype, vlen;
-	__pmLoggerStatus_v1	*lsp_v1;
-
-#ifdef PCP_DEBUG
-	if (pmDebug & DBG_TRACE_PDU)
-	    fprintf(stderr, "pmlc: sending version 1 datax status request\n");
-#endif
-	if ((sts = __pmSendDataX(logger_fd, PDU_BINARY, PMLC_PDU_STATUS_REQ,
-			    0, NULL)) < 0) {
-	    fprintf(stderr, "Error sending request to pmlogger: ");
-	    if (still_connected(sts))
-		fprintf(stderr, "%s\n", pmErrStr(sts));
-	    return;
-	}
-	if ((sts = __pmGetPDU(logger_fd, PDU_BINARY, TIMEOUT_NEVER, &pb)) <= 0) {
-	    if (sts == 0)
-		/* end of file! */
-		sts = PM_ERR_IPC;
-	    fprintf(stderr, "Error receiving response from pmlogger: ");
-	    if (still_connected(sts))
-		fprintf(stderr, "%s\n", pmErrStr(sts));
-	    return;
-	}
-	if ((sts = __pmDecodeDataX(pb, PDU_BINARY, &subtype,
-			      &vlen, (void **)&lsp_v1)) < 0) {
-	    fprintf(stderr, "Error decoding response from pmlogger: ");
-	    if (still_connected(sts))
-		fprintf(stderr, "%s\n", pmErrStr(sts));
-	    return;
-	}
-	if (subtype != PMLC_PDU_STATUS || vlen != sizeof(__pmLoggerStatus_v1)) {
-	    fprintf(stderr, "Incorrect data from pmlogger (version mismatch?)\n"
-#ifdef PCP_DEBUG
-		    "subtype=%d vlen=%d (expected %d)\n",
-		    subtype, vlen, sizeof(__pmLoggerStatus_v1)
-#endif
-		    );
-	    goto done;
-	}
-	tzlogger = lsp_v1->ls_tzlogger;
-	start = &lsp_v1->ls_start;
-	last = &lsp_v1->ls_last;
-	timenow = &lsp_v1->ls_timenow;
-	hostname = lsp_v1->ls_hostname;
-	state = lsp_v1->ls_state;
-	vol = lsp_v1->ls_vol;
-	size = lsp_v1->ls_size;
-    }
-#endif /* HAVE_V1_SUPPORT */
 
     if (tzchange) {
 	switch (tztype) {
 	    case TZ_LOCAL:
 		if (localtz == -1) {
-#if defined(IRIX6_5)
-                    if (_MIPS_SYMBOL_PRESENT(__pmTimezone))
-                        str = __pmTimezone();
-                    else
-                        str = getenv("TZ");
-#else
                     str = __pmTimezone();
-#endif
 		    if (str != NULL)
 			ltzstr = str;
 		    localtz = pmNewZone(ltzstr);
@@ -750,7 +621,7 @@ void Status(int pid, int primary)
 	printf("[%d]", pid);
     printf(" on host %s is logging metrics from host %s\n",
 	lasthost, hostname);
-    if (ipc->version >= LOG_PDU_VERSION2)
+    if (__pmVersionIPC(logger_fd) >= LOG_PDU_VERSION2)
 	printf("PMCD host        %s\n", lsp->ls_fqdn);
     if (state == PM_LOG_STATE_NEW) {
 	puts("logging hasn't started yet");
@@ -774,17 +645,11 @@ Sync(void)
 {
     int			sts;
     __pmPDU		*pb;
-    __pmIPC		*ipc;
 
     if (!connected())
 	return;
 
-    if (__pmFdLookupIPC(logger_fd, &ipc) < 0) {
-	fprintf(stderr, "Logger connection badly initialised.\n");
-	return;
-    }
-
-    if (ipc->version >= LOG_PDU_VERSION2) {
+    if (__pmVersionIPC(logger_fd) >= LOG_PDU_VERSION2) {
 #ifdef PCP_DEBUG
 	if (pmDebug & DBG_TRACE_PDU)
 	    fprintf(stderr, "pmlc: sending version 2 sync request\n");
@@ -796,21 +661,6 @@ Sync(void)
 	    return;
 	}
     }
-#ifdef HAVE_V1_SUPPORT
-    else {
-#ifdef PCP_DEBUG
-	if (pmDebug & DBG_TRACE_PDU)
-	    fprintf(stderr, "pmlc: sending version 1 datax sync request\n");
-#endif
-	if ((sts = __pmSendDataX(logger_fd, PDU_BINARY, PMLC_PDU_SYNC,
-			    0, NULL)) < 0) {
-	    fprintf(stderr, "Error sending request to pmlogger: ");
-	    if (still_connected(sts))
-		fprintf(stderr, "%s\n", pmErrStr(sts));
-	    return;
-	}
-    }
-#endif /* HAVE_V1_SUPPORT */
 
     if ((sts = __pmGetPDU(logger_fd, PDU_BINARY, TIMEOUT_NEVER, &pb)) != PDU_ERROR) {
 	if (sts == 0)
@@ -838,17 +688,11 @@ NewVolume(void)
 {
     int			sts;
     __pmPDU		*pb;
-    __pmIPC		*ipc;
 
     if (!connected())
 	return;
 
-    if (__pmFdLookupIPC(logger_fd, &ipc) < 0) {
-	fprintf(stderr, "Logger connection badly initialised.\n");
-	return;
-    }
-
-    if (ipc->version >= LOG_PDU_VERSION2) {
+    if (__pmVersionIPC(logger_fd) >= LOG_PDU_VERSION2) {
 #ifdef PCP_DEBUG
 	if (pmDebug & DBG_TRACE_PDU)
 	    fprintf(stderr, "pmlc: sending version 2 newvol request\n");
@@ -860,22 +704,6 @@ NewVolume(void)
 	    return;
 	}
     }
-#ifdef HAVE_V1_SUPPORT
-    else {
-#ifdef PCP_DEBUG
-	if (pmDebug & DBG_TRACE_PDU)
-	    fprintf(stderr, "pmlc: sending version 1 datax newvol request\n");
-#endif
-	if ((sts = __pmSendDataX(logger_fd, PDU_BINARY, PMLC_PDU_NEWVOLUME,
-			    0, NULL)) < 0) {
-	    fprintf(stderr, "Error sending request to pmlogger: ");
-	    if (still_connected(sts))
-		fprintf(stderr, "%s\n", pmErrStr(sts));
-	    return;
-	}
-    }
-
-#endif /* HAVE_V1_SUPPORT */
 
     if ((sts = __pmGetPDU(logger_fd, PDU_BINARY, TIMEOUT_NEVER, &pb)) != PDU_ERROR) {
 	if (sts == 0)
