@@ -14,20 +14,11 @@
  * You should have received a copy of the GNU General Public License along
  * with this program; if not, write to the Free Software Foundation, Inc.,
  * 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
- * 
- * Contact information: Silicon Graphics, Inc., 1500 Crittenden Lane,
- * Mountain View, CA 94043, USA, or: http://www.sgi.com
  */
 
-#ident "$Id: callback.c,v 1.5 2004/12/06 00:56:58 kenmcd Exp $"
-
-#include <stdio.h>
-#include <string.h>
-#include <errno.h>
-#include <sys/time.h>
 #include "pmapi.h"
 #include "impl.h"
-#include "./logger.h"
+#include "logger.h"
 
 /*
  * pro tem, we have a single context with the pmcd providing the
@@ -163,7 +154,6 @@ setavail(pmResult *resp)
 	    if (php == (pmidhist_t *)0) {
 		__pmNoMem("setavail: new pmid hist entry calloc",
 			 sizeof(pmidhist_t), PM_FATAL_ERR);
-		/*NOTREACHED*/
 	    }
 	    php->ph_pmid = pmid;
 	    php->ph_indom = ((optreq_t *)hp->data)->r_desc->indom;
@@ -176,7 +166,6 @@ setavail(pmResult *resp)
 	    if (ihp == (insthist_t *)0) {
 		__pmNoMem("setavail: inst list calloc",
 			 vsp->numval * sizeof(insthist_t), PM_FATAL_ERR);
-		/*NOTREACHED*/
 	    }
 	    php->ph_instlist = ihp;
 	    for (j = 0; j < vsp->numval; j++, ihp++) {
@@ -186,7 +175,6 @@ setavail(pmResult *resp)
 	    if ((j = __pmHashAdd(pmid, (void *)php, &hist_hash)) < 0) {
 		extern void die(char *, int);
 		die("setavail: __pmHashAdd(hist_hash)", j);
-		/*NOTREACHED*/
 	    }
 	    
 	    return;
@@ -212,7 +200,6 @@ setavail(pmResult *resp)
 		php->ph_instlist = (insthist_t *)realloc(php->ph_instlist, need);
 		if (php->ph_instlist == (insthist_t *)0) {
 		    __pmNoMem("setavail: inst list realloc", need, PM_FATAL_ERR);
-		    /*NOTREACHED*/
 		}
 		ihp = &php->ph_instlist[k];
 		ihp->ih_inst = inst;
@@ -363,7 +350,6 @@ log_callback(int afid, void *data)
 	if (acp == (AFctl_t *)0) {
 	    __pmNoMem("log_callback: new AFctl_t entry calloc",
 		     sizeof(AFctl_t), PM_FATAL_ERR);
-	    /*NOTREACHED*/
 	}
 	acp->ac_afid = afid;
 	acp->ac_next = achead;
@@ -405,7 +391,6 @@ log_callback(int afid, void *data)
 		if (lfp == (lastfetch_t *)0) {
 		    __pmNoMem("log_callback: new lastfetch_t entry calloc",
 			     sizeof(lastfetch_t), PM_FATAL_ERR);
-		    /*NOTREACHED*/
 		}
 		lfp->lf_next = acp->ac_fetch;
 		acp->ac_fetch = lfp;
@@ -431,7 +416,6 @@ log_callback(int afid, void *data)
 		fprintf(stderr, "callback: disconnecting because myFetch failed: %s\n", pmErrStr(sts));
 #endif
 	    disconnect(sts);
-	    /*NOTREACHED*/
 	}
 #ifdef PCP_DEBUG
 	if (pmDebug & DBG_TRACE_APPL2)
@@ -723,7 +707,6 @@ putmark(void)
 	int		numpmid;	/* zero PMIDs to follow */
 	__pmPDU		tail;
     } mark;
-    extern int	errno;
 
     if (last_stamp.tv_sec == 0 && last_stamp.tv_usec == 0)
 	/* no earlier pmResult, no point adding a mark record */
