@@ -14,33 +14,14 @@
  * You should have received a copy of the GNU General Public License along
  * with this program; if not, write to the Free Software Foundation, Inc.,
  * 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
- * 
- * Contact information: Silicon Graphics, Inc., 1500 Crittenden Lane,
- * Mountain View, CA 94043, USA, or: http://www.sgi.com
  */
 
-#ident "$Id: pmlogger.c,v 1.7 2004/12/06 00:56:58 kenmcd Exp $"
-
-#include <stdio.h>
-#include <unistd.h>
-#include <stdlib.h>
 #include <ctype.h>
-#include <string.h>
-#include <errno.h>
-#include <time.h>
 #include <limits.h>
-#include <sys/types.h>
 #include <sys/stat.h>
-#include <fcntl.h>
-#include <syslog.h>
-#if defined(sgi)
-#include <bstring.h>
-#endif
-
 #include "pmapi.h"
 #include "impl.h"
-
-#include "./logger.h"
+#include "logger.h"
 
 char		*configfile = NULL;
 __pmLogCtl	logctl;
@@ -80,8 +61,6 @@ static char	*rsc_prog = "<unknown>";
 static char	*folio_name = "<unknown>";
 static char	*dialog_title = "PCP Archive Recording Session";
 
-extern int	errno;
-
 /*
  * flush stdio buffers
  */
@@ -122,14 +101,12 @@ run_done(int sts, char *msg)
     exit(sts);
 }
 
-/*ARGSUSED*/
 static void
 run_done_callback(int i, void *j)
 {
   run_done(0, NULL);
 }
 
-/*ARGSUSED*/
 static void
 vol_switch_callback(int i, void *j)
 {
@@ -465,7 +442,6 @@ failed:
 
     if (cmd == 'Q' || (cmd == 'X' && strcmp(lbuf, "Yes") == 0)) {
 	run_done(0, "Recording session terminated");
-	/*NOTREACHED*/
     }
 
     if (cmd != '?') {
@@ -491,24 +467,12 @@ main(int argc, char **argv)
     int			i;
     task_t		*tp;
     optcost_t		ocp;
-    extern char		*optarg;
-    extern int		optind;
-    extern int		pmDebug;
     extern void		init_ports(void);
     fd_set		readyfds;
     char		*p;
     char		*runtime = NULL;
 
-#ifdef __sgi
-    __pmSetAuthClient();
-#endif
-
-    /* trim cmd name of leading directory components */
-    pmProgname = argv[0];
-    for (p = pmProgname; *p; p++) {
-	if (*p == '/')
-	    pmProgname = p+1;
-    }
+    __pmSetProgname(argv[0]);
 
     /*
      * Warning:
@@ -528,7 +492,6 @@ main(int argc, char **argv)
 		int sz = strlen(vardir)+strlen("/config/pmlogger/")+strlen(optarg)+1;
 		if ( (configfile = (char *)malloc(sz)) == NULL ) {
 		    __pmNoMem("config file name", sz, PM_FATAL_ERR);
-		    /*NOTREACHED*/
 		}
 		sprintf(configfile, "%s/config/pmlogger/%s", vardir, optarg);
 		if (access(configfile, F_OK) != 0) {
@@ -786,11 +749,7 @@ Options:\n\
 	pmID		pmid;
 	pmResult	*resp;
 
-#if defined(sgi)
-	gettimeofday(&epoch, NULL, NULL);
-#else
 	gettimeofday(&epoch, NULL);
-#endif
 	sts = pmUseContext(ctx);
 	if (sts >= 0)
 	    sts = pmLookupName(1, &name, &pmid);
@@ -845,13 +804,6 @@ Options:\n\
 
     fprintf(stderr, "Archive basename: %s\n", archBase);
 
-#ifdef MALLOC_AUDIT
-    _malloc_reset_();
-#if defined(HAVE_ATEXIT)
-    atexit(_malloc_audit_);
-#endif
-#endif
-
     /* detach yourself from the launching process */
     setpgid(getpid(), 0);
 
@@ -873,11 +825,6 @@ Options:\n\
     parse_done = 1;	/* enable callback processing */
     __pmAFunblock();
 
-#if defined(__NUTC__)
-    /* kick-start the AF itimer for the "log on once" case */
-    kill(getpid(), SIGALRM);
-#endif
-
     for ( ; ; ) {
 	int		nready;
 	extern int	control_req(void);
@@ -931,14 +878,12 @@ Options:\n\
 		    if (sts < 0)
 			fprintf(stderr, "Error: __pmGetPDU: %s\n", pmErrStr(sts));
 		    disconnect(sts);
-		    /*NOTREACHED*/
 		}
 		else {
 		    php = (__pmPDUHdr *)pb;
 		    fprintf(stderr, "Error: Unsolicited %s PDU from PMCD\n",
 			__pmPDUTypeStr(php->type));
 		    disconnect(PM_ERR_IPC);
-		    /*NOTREACHED*/
 		}
 	    }
 	    if (rsc_fd >= 0 && FD_ISSET(rsc_fd, &readyfds)) {
@@ -1021,7 +966,6 @@ Options:\n\
 	    perror("select");
     }
 
-    /*NOTREACHED*/
 }
 
 
