@@ -14,15 +14,9 @@
  * You should have received a copy of the GNU General Public License along
  * with this program; if not, write to the Free Software Foundation, Inc.,
  * 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
- * 
- * Contact information: Silicon Graphics, Inc., 1500 Crittenden Lane,
- * Mountain View, CA 94043, USA, or: http://www.sgi.com
  */
 
-#ident "$Id: pmlogsummary.c,v 1.31 2004/06/15 09:39:44 kenmcd Exp $"
-
 #include <math.h>
-#include <stdio.h>
 #include <stdarg.h>
 #include <limits.h>
 #include "pmapi.h"
@@ -897,7 +891,6 @@ main(int argc, char *argv[])
     char		*startstr = NULL;
     char		*endstr = NULL;
     char		*msg = NULL;
-    char		*p;
     int			errflag = 0;
     int			lflag = 0;		/* no label by default */
     pmResult		*result;
@@ -906,13 +899,8 @@ main(int argc, char *argv[])
     int			zflag = 0;		/* for -z */
     char 		*tz = NULL;		/* for -Z timezone */
     char		timebuf[32];		/* for pmCtime result + .xxx */
-    extern char		*optarg;
-    extern int		optind;
-    extern int		pmDebug;
 
-    for (p = pmProgname = argv[0]; *p; p++)
-	if (*p == '/')
-	    pmProgname = p+1;
+    __pmSetProgname(argv[0]);
 
     while ((c = getopt(argc, argv, "abB:D:fFiIlmMNn:p:rsS:T:xyzZ:?")) != EOF) {
 	switch (c) {
@@ -1127,11 +1115,6 @@ main(int argc, char *argv[])
 	exit(1);
     }
 
-#ifdef MALLOC_AUDIT
-    _malloc_reset_();
-    atexit(_malloc_audit_);
-#endif
-
     if (lflag == 1) {
 	char	       *ddmm;
 	char	       *yr;
@@ -1221,5 +1204,4 @@ main(int argc, char *argv[])
     }
 
     exit(exitstatus);
-    /*NOTREACHED*/
 }
