@@ -18,26 +18,13 @@
  * You should have received a copy of the GNU General Public License along
  * with this program; if not, write to the Free Software Foundation, Inc.,
  * 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
- * 
- * Contact information: Silicon Graphics, Inc., 1500 Crittenden Lane,
- * Mountain View, CA 94043, USA, or: http://www.sgi.com
  */
 
-#ident "$Id: pmnscomp.c,v 1.5 2006/06/27 09:09:16 makc Exp $"
-
-#include <stdio.h>
-#include <unistd.h>
-#include <stddef.h>
 #include <ctype.h>
-#include <signal.h>
-#include <errno.h>
-#include <sys/types.h>
 #include <sys/stat.h>
 #include "pmapi.h"
 #include "impl.h"
 
-extern int	errno;
-
 static int	nodecnt;	/* number of nodes */
 static int	leafcnt;	/* number of leaf nodes */
 static int	symbsize;	/* aggregate string table size */
@@ -109,7 +96,6 @@ nodemap(__pmnsNode *p)
     printf("%s: fatal error, cannot map node addr " PRINTF_P_PFX "%p\n", pmProgname, p);
     dumpmap();
     exit(1);
-    /*NOTREACHED*/
 }
 
 static void
@@ -174,7 +160,6 @@ pass2(__pmnsNode *p)
     i++;
 }
 
-/*ARGSUSED*/
 static void
 pass3(__pmnsNode *p)
 {
@@ -233,17 +218,8 @@ main(int argc, char **argv)
     __int32_t	tmp;
     __int32_t	sum;
     long	startsum;
-    extern char	*optarg;
-    extern int	optind;
-    extern int	pmDebug;
-    char	*p;
 
-    /* trim command name of leading directory components */
-    pmProgname = argv[0];
-    for (p = pmProgname; *p; p++) {
-	if (*p == '/')
-	    pmProgname = p+1;
-    }
+    __pmSetProgname(argv[0]);
 
     while ((c = getopt(argc, argv, "dD:fn:v:?")) != EOF) {
 	switch (c) {
@@ -277,17 +253,10 @@ main(int argc, char **argv)
 		fprintf(stderr, "%s: -v requires numeric argument\n", pmProgname);
 		errflag++;
 	    }
-#ifdef BUILDTOOL
 	    if (version < 0 || version > 2) {
 		fprintf(stderr, "%s: version must be 0, 1 or 2\n", pmProgname);
 		errflag++;
 	    }
-#else
-	    if (version < 0 || version > 1) {
-		fprintf(stderr, "%s: version must be 0 or 1\n", pmProgname);
-		errflag++;
-	    }
-#endif
 	    break;
 
 	case '?':
@@ -378,16 +347,8 @@ Options:\n\
 				 nodecnt * sizeof(_nodetab[0]) +
 				 symbsize +
 				 nodecnt * sizeof(_map[0]), PM_FATAL_ERR);
-	    /*NOTREACHED*/
     }
 
-#ifdef MALLOC_AUDIT
-    _persistent_(_htab);
-    _persistent_(_nodetab);
-    _persistent_(symp);
-    _persistent_(_map);
-#endif
-
     i = 0;
     traverse(root, pass2);
 
@@ -406,11 +367,13 @@ Options:\n\
     traverse(root, pass3);
 
     /*
-     * from here on, ignore SIGINT, SIGHUP and SIGTERM to protect
+     * from here on, ignore SIGHUP, SIGINT and SIGTERM to protect
      * the integrity of the new ouput file
      */
-    signal(SIGINT, SIG_IGN);
+#if defined(HAVE_SIGHUP)
     signal(SIGHUP, SIG_IGN);
+#endif
+    signal(SIGINT, SIG_IGN);
     signal(SIGTERM, SIG_IGN);
 
     if ((outf = fopen(argv[optind], "w+")) == NULL) {
@@ -572,17 +535,17 @@ Options:\n\
 			putchar('\n');
 		    printf("htab32[%3d]", j);
 		}
-		printf(" %5d", ntohl(_htab32[j]));
+		printf(" %5d", (int)ntohl(_htab32[j]));
 	    }
 	    printf("\n\n32-bit Node Table\n");
 	    for (j = 0; j < nodecnt; j++) {
 		if (j % 20 == 0)
 		    printf("             Parent   Next  First   Hash Symbol           PMID\n");
 		printf("node32[%4d] %6d %6d %6d %6d %-16.16s",
-		    j, ntohl(_nodetab32[j].parent), 
-		       ntohl(_nodetab32[j].next), 
-	               ntohl(_nodetab32[j].first),
-		       ntohl(_nodetab32[j].hash), 
+		    j, (int)ntohl(_nodetab32[j].parent), 
+		       (int)ntohl(_nodetab32[j].next), 
+	               (int)ntohl(_nodetab32[j].first),
+		       (int)ntohl(_nodetab32[j].hash), 
 		       _symbol+ntohl(_nodetab32[j].name));
 		if (htonl(_nodetab32[j].first) == -1)
 		    printf(" %s", pmIDStr(__htonpmID(_nodetab32[j].pmid)));
@@ -660,18 +623,4 @@ Options:\n\
 	htabcnt, leafcnt, nodecnt - leafcnt, symbsize);
 
     exit(0);
-    /*NOTREACHED*/
 }
-
-#ifdef BUILDTOOL
-/*
- * redefine __pmGetLicenseCap(), to avoid PCP license hassles in the
- * build environment
- */
-
-int
-__pmGetLicenseCap(void)
-{
-    return PM_LIC_PCP | PM_LIC_COL | PM_LIC_MON;
-}
-#endif
