@@ -14,23 +14,12 @@
  * You should have received a copy of the GNU General Public License along
  * with this program; if not, write to the Free Software Foundation, Inc.,
  * 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
- * 
- * Contact information: Silicon Graphics, Inc., 1500 Crittenden Lane,
- * Mountain View, CA 94043, USA, or: http://www.sgi.com
  */
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <unistd.h>
-#include <errno.h>
-#include <ctype.h>
-#include <string.h>
-#include <limits.h>
-
 #include "pmapi.h"
 #include "impl.h"
 #include "pmda.h"
-
+#include <ctype.h>
 #include <sys/ioctl.h>
 #ifdef HAVE_SYS_TERMIOS_H
 #include <sys/termios.h>
@@ -298,7 +287,7 @@ main(int argc, char *argv[])
     float period;
 
     setlinebuf(stdout);
-    pmProgname = basename(argv[0]);
+    __pmSetProgname(argv[0]);
 
     namecnt = 0;
     if ( argc > 2 ) {
@@ -772,15 +761,7 @@ main(int argc, char *argv[])
 	}
 
 	if ( ctxType != PM_CONTEXT_ARCHIVE  || pauseFlag ) {
-#ifdef HAVE_NANOSLEEP
 	    nanosleep (&sleeptime, NULL);
-#else
-#ifdef HAVE_USLEEP
-	    usleep((useconds_t)(sleeptime.tv_sec * 1e6 + (sleeptime.tv_nsec + 5e2) / 1e3));
-#else
-	    sleep((unsigned int)(sleeptime.tv_sec + (sleeptime.tv_nsec + 5e8) / 1e9));
-#endif
-#endif
 	}
 
 	for ( j=0; j < ctxCnt; j++ ) {
