@@ -17,30 +17,13 @@
  * You should have received a copy of the GNU General Public License along
  * with this program; if not, write to the Free Software Foundation, Inc.,
  * 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
- * 
- * Contact information: Silicon Graphics, Inc., 1500 Crittenden Lane,
- * Mountain View, CA 94043, USA, or: http://www.sgi.com
  */
 
-#ident "$Id: pmval.c,v 1.12 2007/02/20 00:08:32 kimbrr Exp $"
-
-#include <stdio.h>
-#include <errno.h>
-#include <stdlib.h>		/* getopt, malloc, qsort and friends */
-#include <sys/time.h>		/* timeval and friends */
-#include <limits.h>		/* CLK_TCK */
-#include <sys/types.h>
-#include <sys/stat.h>
-#include <math.h>		/* pow */
-
+#include <math.h>
 #include "pmapi.h"
 #include "impl.h"
 
-#if defined(__sgi)
-#define HAVE_PMTIME 1
-#if defined(IRIX6_5)
-#include <optional_sym.h>
-#endif
+#if defined(HAVE_PMTIME)
 static void talk_to_pmtime(int *);
 #elif defined(HAVE_KMTIME)
 #include "kmtime.h"
@@ -301,7 +284,6 @@ initinsts(Context *x)
 	    ip = (int *)malloc(n * sizeof(int));
 	    if (ip == NULL) {
 		__pmNoMem("pmval.ip", n * sizeof(int), PM_FATAL_ERR);
-		/*NOTREACHED*/
 	    }
 	    x->iids = ip;
 	    for (i = 0; i < n; i++) {
@@ -343,7 +325,6 @@ initinsts(Context *x)
 	pp = (InstPair *)malloc(n * sizeof(InstPair));
 	if (pp == NULL) {
 	    __pmNoMem("pmval.pp", n * sizeof(InstPair), PM_FATAL_ERR);
-	    /*NOTREACHED*/
 	}
 	x->ipairs = pp;
 	for (i = 0; i < n; i++) {
@@ -546,7 +527,6 @@ howide(int type)
 	fprintf(stderr, "pmval: unknown performance metric value type\n");
 	exit(EXIT_FAILURE);
     }
-    /*NOTREACHED*/
 }
 
 /*
@@ -1020,18 +1000,12 @@ getargs(int		argc,		/* in - command line argument count */
         long		*smpls,		/* out - number of samples */
 	int		*cols)		/* out - output column width */
 {
-    extern char	*optarg;
-    extern int	optind;
-    extern int	errno;
     int		c;
-
     char        *subopt;
-
     long	d;
     int		errflag = 0;
     int         i;
     int		src = 0;
-
     char	*host = local;
     int		sts;
     char        *endnum;
@@ -1051,10 +1025,6 @@ getargs(int		argc,		/* in - command line argument count */
     struct stat	statbuf;
 #endif
 
-#ifdef __sgi
-    __pmSetAuthClient();
-#endif
-
     /* fill in default values */
     cntxt->iall = 1;
     cntxt->inum = 0;
@@ -1129,7 +1099,6 @@ getargs(int		argc,		/* in - command line argument count */
 		    (char **)realloc(cntxt->inames, i * (sizeof (char *)));
 		if (cntxt->inames == NULL) {
 		    __pmNoMem("pmval.ip", i * sizeof(char *), PM_FATAL_ERR);
-		    /*NOTREACHED*/
 		}
 		*(cntxt->inames + i - 1) = subopt;
 		subopt = getinstance(NULL);
@@ -1247,7 +1216,6 @@ getargs(int		argc,		/* in - command line argument count */
 	case '?':
 	    fprintf(stderr, usage, pmProgname);
 	    exit(EXIT_FAILURE);
-	    /* NOTREACHED */
 
 	default:
 	    errflag++;
@@ -1285,10 +1253,13 @@ getargs(int		argc,		/* in - command line argument count */
 	exit(EXIT_FAILURE);
     }
 
-    if (msp->isarch) {
+    if (msp->isarch == 1) {
 	archive = msp->source;
 	ahtype = PM_CONTEXT_ARCHIVE;
     }
+    else if (msp->isarch == 2) {
+	ahtype = PM_CONTEXT_LOCAL;
+    }
 
     if (ahtype != PM_CONTEXT_ARCHIVE) {
 	if (pauseFlag) {
@@ -1321,19 +1292,8 @@ getargs(int		argc,		/* in - command line argument count */
 	cntxt->inames = &msp->inst[0];
     }
 
-    /* open connection to host */
-    if (msp->isarch == 0) {
-	if ((sts = pmNewContext(PM_CONTEXT_HOST, msp->source)) < 0) {
-	    fprintf(stderr, "%s: Cannot connect to PMCD on host \"%s\": %s\n",
-		pmProgname, msp->source, pmErrStr(sts));
-	    exit(EXIT_FAILURE);
-	}
-	cntxt->host = msp->source;
-	gettimeofday(&logStart, NULL);
-    }
-
-    /* open connection to archive */
-    else {
+    if (msp->isarch == 1) {
+	/* open connection to archive */
 	if ((sts = pmNewContext(PM_CONTEXT_ARCHIVE, msp->source)) < 0) {
 	    fprintf(stderr, "%s: Cannot open archive \"%s\": %s\n",
 		pmProgname, msp->source, pmErrStr(sts));
@@ -1351,6 +1311,20 @@ getargs(int		argc,		/* in - command line argument count */
 	    exit(EXIT_FAILURE);
 	}
     }
+    else {
+	/* open connection to host or local context */
+	if ((sts = pmNewContext(ahtype, msp->source)) < 0) {
+	    if (ahtype == PM_CONTEXT_HOST)
+		fprintf(stderr, "%s: Cannot connect to PMCD on host \"%s\": %s\n",
+		    pmProgname, msp->source, pmErrStr(sts));
+	    else
+		fprintf(stderr, "%s: Cannot establish local context: %s\n",
+		    pmProgname, pmErrStr(sts));
+	    exit(EXIT_FAILURE);
+	}
+	cntxt->host = msp->source;
+	gettimeofday(&logStart, NULL);
+    }
 
     if (zflag) {
 	if ((tzh = pmNewContextZone()) < 0) {
@@ -1407,7 +1381,7 @@ getargs(int		argc,		/* in - command line argument count */
 	/* set up pmtime control */
 	int		mode;
 
-	if (msp->isarch)
+	if (msp->isarch == 1)
 	    mode = PM_TCTL_MODE_ARCHIVE;
 	else
 	    mode = PM_TCTL_MODE_HOST;
@@ -1423,7 +1397,7 @@ getargs(int		argc,		/* in - command line argument count */
 
 	getXTBintervalFromTimeval(&pmtime.delta, &pmtime.vcrmode, delta);
 
-	if (msp->isarch) {
+	if (msp->isarch == 1) {
 	    pmtime.position = *posn;
 	    pmtime.start = first;
 	    pmtime.finish = last;
@@ -1431,15 +1405,8 @@ getargs(int		argc,		/* in - command line argument count */
 	else
 	    gettimeofday(&pmtime.position, NULL);
 	if (rpt_tz == NULL) {
-#if defined(IRIX6_5)
-            if (_MIPS_SYMBOL_PRESENT(__pmTimezone))
-                rpt_tz = __pmTimezone();
-            else
-                rpt_tz = getenv("TZ");
-#else
             rpt_tz = __pmTimezone();
-#endif
-	    if (msp->isarch) {
+	    if (msp->isarch == 1) {
 		if ((sts = pmNewZone(rpt_tz)) < 0) {
 		    fprintf(stderr, "%s: Cannot set timezone to \"%s\": %s\n",
 			pmProgname, rpt_tz, pmErrStr(sts));
@@ -1468,7 +1435,7 @@ getargs(int		argc,		/* in - command line argument count */
 	kmtime->length = sizeof(kmTime);
 	kmtime->command = KM_TCTL_SET;
 	kmtime->delta = *delta;
-	if (msp->isarch) {
+	if (msp->isarch == 1) {
 	    kmtime->source = KM_SOURCE_ARCHIVE;
 	    kmtime->position = *posn;
 	    kmtime->start = first;
@@ -1479,7 +1446,7 @@ getargs(int		argc,		/* in - command line argument count */
 	}
 	if (rpt_tz == NULL) {
 	    rpt_tz = __pmTimezone();
-	    if (msp->isarch) {
+	    if (msp->isarch == 1) {
 		if ((sts = pmNewZone(rpt_tz)) < 0) {
 		    fprintf(stderr, "%s: Cannot set timezone to \"%s\": %s\n",
 			pmProgname, rpt_tz, pmErrStr(sts));
@@ -1509,7 +1476,7 @@ getargs(int		argc,		/* in - command line argument count */
     }
     else
 #endif
-	if (msp->isarch) {
+	if (msp->isarch == 1) {
 	    /* archive, and no time control, go it alone */
 	    int tmp_ival;
 	    int tmp_mode;
@@ -1538,22 +1505,15 @@ main(int argc, char *argv[])
     Context	    cntxt;		/* performance metric description */
     pmResult	    *rslt1;		/* current values */
     pmResult	    *rslt2;		/* previous values */
-    char	    *p;
     int		    first = 1;		/* need first sample */
     int		    forever;
     int		    idx1;
     int		    idx2;
     int		    no_values = 0;
 
-    /* trim command name of leading directory components */
-    pmProgname = argv[0];
-    for (p = pmProgname; *p; p++) {
-	if (*p == '/')
-	    pmProgname = p+1;
-    }
+    __pmSetProgname(argv[0]);
     setlinebuf(stdout);
 
-
     getargs(argc, argv, &cntxt, &now, &delta, &smpls, &cols);
     forever = (smpls == ALL_SAMPLES || gui);
     initapi(&cntxt);
@@ -1669,7 +1629,6 @@ main(int argc, char *argv[])
     }
 
     exit(first == 0);
-    /*NOTREACHED*/
 }
 
 #ifdef HAVE_PMTIME
